@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                           *
+ *   hanna_k@fmgirl.com                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,6 +26,7 @@
 
 #include <qdom.h>
 #include <qfile.h>
+#include <QTextStream>
 #include <klocale.h>
 #include <ksavefile.h>
 #include <qfileinfo.h>
@@ -79,13 +80,13 @@ void Budget::clear() {
 }
 QString Budget::loadFile(QString filename, QString &errors) {
 	QFile file(filename);
-	if(!file.open(IO_ReadOnly) ) {
+	if(!file.open(QIODevice::ReadOnly) ) {
 		return i18n("Couldn't open %1 for reading").arg(filename);
 	} else if(!file.size()) {
 		return QString::null;
 	}
 	QTextStream fstream(&file);
-	fstream.setEncoding(QTextStream::UnicodeUTF8);
+	fstream.setCodec("UTF-8");
 	QDomDocument doc;
 	QString errorMsg;
 	int errorLine = 0, errorCol;
@@ -242,8 +243,8 @@ QString Budget::loadFile(QString filename, QString &errors) {
 					SplitTransaction *split = new SplitTransaction(this, &e, &valid);
 					if(valid) {
 						splitTransactions.append(split);
-						QValueVector<Transaction*>::size_type c = split->splits.count();
-						for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+						QVector<Transaction*>::size_type c = split->splits.count();
+						for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 							Transaction *trans = split->splits[i];
 							switch(trans->type()) {
 								case TRANSACTION_TYPE_TRANSFER: {
@@ -359,47 +360,49 @@ QString Budget::loadFile(QString filename, QString &errors) {
 
 	bool had_line = false;
 	if(account_errors > 0) {
-		errors += i18n("Unable to load 1 account.", "Unable to load %n accounts.", account_errors);
+		errors += i18np("Unable to load 1 account.", "Unable to load %n accounts.", account_errors);
 		had_line = true;
 	}
 	if(category_errors > 0) {
 		if(had_line) errors += "\n";
-		errors += i18n("Unable to load 1 category.", "Unable to load %n categories.", category_errors);
+		errors += i18np("Unable to load 1 category.", "Unable to load %n categories.", category_errors);
 		had_line = true;
 	}
 	if(security_errors > 0) {
 		if(had_line) errors += "\n";
-		errors += i18n("Unable to load 1 security.", "Unable to load %n securities.", security_errors);
+		errors += i18np("Unable to load 1 security.", "Unable to load %n securities.", security_errors);
 		had_line = true;
 	}
 	if(transaction_errors > 0) {
 		if(had_line) errors += "\n";
-		errors += i18n("Unable to load 1 transaction.", "Unable to load %n transactions.", transaction_errors);
+		errors += i18np("Unable to load 1 transaction.", "Unable to load %n transactions.", transaction_errors);
 		had_line = true;
 	}
 	file.close();
 	return QString::null;
 }
 
-QString Budget::saveFile(QString filename, mode_t perms) {
+QString Budget::saveFile(QString filename, mode_t) {
 	
 	QFileInfo info(filename);
 	if(info.isDir()) {
 		return i18n("File is a directory");
 	}
 
-	KSaveFile ofile(filename, (int) perms);
-	if(ofile.status()) {
+	KSaveFile ofile(filename);
+	ofile.open();
+	ofile.setPermissions((QFile::Permissions) 0x0600);
+	if(!ofile.isOpen()) {
 		ofile.abort();
 		return i18n("Couldn't open file for writing");
 	}
 
-	QTextStream &outf = *ofile.textStream();
-	outf.setEncoding(QTextStream::UnicodeUTF8);
+	QTextStream outf(&ofile);
+	outf.setCodec("UTF-8");
 	QDomDocument doc("EqonomizeDoc");
 	doc.appendChild(doc.createProcessingInstruction("xml", "version=\"1.0\" encoding=\"UTF-8\""));
 	QDomElement root = doc.createElement("EqonomizeDoc");
-	root.setAttribute("version", VERSION);
+	root.setAttribute("version", "0.5");
 	doc.appendChild(root);
 
 	int id = 1;
@@ -539,14 +542,13 @@ QString Budget::saveFile(QString filename, mode_t perms) {
 
 	outf << doc.toString();
 
-	if(ofile.status()) {
+	if(ofile.error() != QFile::NoError) {
 		ofile.abort();
 		return i18n("Error while writing file; file was not saved");
 	}
-
-	ofile.close();
-	if(ofile.status()) {
-		return i18n("Error after saving file; data may not have been saved");
+	
+	if(!ofile.finalize()) {
+		return i18n("Error while writing file; file was not saved");
 	}
 
 	return QString::null;
@@ -617,14 +619,14 @@ void Budget::removeTransaction(Transaction *trans, bool keep) {
 }
 void Budget::addSplitTransaction(SplitTransaction *split) {
 	splitTransactions.inSort(split);
-	QValueVector<Transaction*>::size_type c = split->splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = split->splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		addTransaction(split->splits[i]);
 	}
 }
 void Budget::removeSplitTransaction(SplitTransaction *split, bool keep) {
-	QValueVector<Transaction*>::size_type c = split->splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = split->splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		Transaction *trans = split->splits[i];
 		transactions.removeRef(trans);
 		switch(trans->type()) {
