@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,6 +32,9 @@
 #include <qobject.h>
 #include <qlayout.h>
 #include <qlayout.h>
+#include <QHBoxLayout>
+#include <QResizeEvent>
+#include <QVBoxLayout>
 #include <kglobal.h>
 #include <klocale.h>
 #include <qmap.h>
@@ -41,8 +44,9 @@
 #include <kstdguiitem.h>
 #include <kcombobox.h>
 #include <qlabel.h>
+#include <QLineEdit>
 #include <kio/netaccess.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <ksavefile.h>
 #include <kfiledialog.h>
 #include <kurl.h>
@@ -53,26 +57,30 @@
 #include <kiconloader.h>
 #include <kconfig.h>
 #include <qgroupbox.h>
-#include <qbuttongroup.h>
 #include <qradiobutton.h>
-#include <qcanvas.h>
-#include <qwmatrix.h>
+#include <QGraphicsView>
+#include <QGraphicsScene>
+#include <QGraphicsSimpleTextItem>
+#include <QGraphicsEllipseItem>
+#include <QGraphicsLineItem>
+#include <QGraphicsRectItem>
+#include <qmatrix.h>
 #include <qpainter.h>
-#include <kprinter.h>
+#include <qprinter.h>
+#include <QPrintDialog>
 #include <qpixmap.h>
 #include <qimage.h>
-#include <kbuttonbox.h>
-#include <kdialogbase.h>
+#include <QImageWriter>
+#include <KDialogButtonBox>
+#include <kdialog.h>
 
 #include <math.h>
 
 extern double monthsBetweenDates(const QDate &date1, const QDate &date2);
-extern QDate addMonths(const QDate &date, int nmonths);
-extern QDate addYears(const QDate &date, int nyears);
 
 CategoriesComparisonChart::CategoriesComparisonChart(Budget *budg, QWidget *parent) : QWidget(parent), budget(budg) {
 
-	setWFlags(getWFlags() | Qt::WDestructiveClose);
+	setAttribute(Qt::WA_DeleteOnClose, true);
 
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 
@@ -86,66 +94,70 @@ CategoriesComparisonChart::CategoriesComparisonChart(Budget *budg, QWidget *pare
 		trans = budget->transactions.next();
 	}
 	to_date = QDate::currentDate();
-	from_date = calSys->addDays(addYears(to_date, -1), 1);
+	from_date = calSys->addDays(calSys->addYears(to_date, -1), 1);
 	if(first_date.isNull()) {
 		from_date = to_date;
 	} else if(from_date < first_date) {
 		from_date = first_date;
 	}
 	
-	QVBoxLayout *layout = new QVBoxLayout(this, 6, 6);
+	QVBoxLayout *layout = new QVBoxLayout(this);
+	layout->setContentsMargins(0, 0, 0, 0);
 
-	KButtonBox *buttons = new KButtonBox(this);
-	buttons->addStretch(1);
-	saveButton = buttons->addButton(KStdGuiItem::saveAs());
-	printButton = buttons->addButton(KStdGuiItem::print());
-	buttons->layout();
+	KDialogButtonBox *buttons = new KDialogButtonBox(this);
+	saveButton = buttons->addButton(KStandardGuiItem::saveAs(), QDialogButtonBox::ActionRole);
+	printButton = buttons->addButton(KStandardGuiItem::print(), QDialogButtonBox::ActionRole);
 	layout->addWidget(buttons);
 
-	canvas = NULL;
-	view = new QCanvasView(this);
+	scene = NULL;
+	view = new QGraphicsView(this);
+	view->setRenderHint(QPainter::Antialiasing, true);
+	view->setRenderHint(QPainter::HighQualityAntialiasing, true);
 	layout->addWidget(view);
 
-	QGroupBox *settingsGroup = new QGroupBox(1, Qt::Horizontal, i18n("Options"), this);
-	QWidget *settingsWidget = new QWidget(settingsGroup);
-	QVBoxLayout *settingsLayout = new QVBoxLayout(settingsWidget, 0, 6);
+	QGroupBox *settingsWidget = new QGroupBox(i18n("Options"), this);
+	QVBoxLayout *settingsLayout = new QVBoxLayout(settingsWidget);
 
-	QHBoxLayout *choicesLayout = new QHBoxLayout(settingsLayout);
+	QHBoxLayout *choicesLayout = new QHBoxLayout();
+	settingsLayout->addLayout(choicesLayout);
 	fromButton = new QCheckBox(i18n("From"), settingsWidget);
 	fromButton->setChecked(true);
 	choicesLayout->addWidget(fromButton);
 	fromEdit = new KDateEdit(settingsWidget);
+	fromEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	fromEdit->setDate(from_date);
 	choicesLayout->addWidget(fromEdit);
 	choicesLayout->addWidget(new QLabel(i18n("To"), settingsWidget));
 	toEdit = new KDateEdit(settingsWidget);
+	toEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	toEdit->setDate(to_date);
 	choicesLayout->addWidget(toEdit);
-	prevYearButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("2leftarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	prevYearButton = new KPushButton(KIcon("arrow-left-double"), "", settingsWidget);
 	choicesLayout->addWidget(prevYearButton);
-	prevMonthButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("1leftarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	prevMonthButton = new KPushButton(KIcon("arrow-left"), "", settingsWidget);
 	choicesLayout->addWidget(prevMonthButton);
-	nextMonthButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("1rightarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	nextMonthButton = new KPushButton(KIcon("arrow-right"), "", settingsWidget);
 	choicesLayout->addWidget(nextMonthButton);
-	nextYearButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("2rightarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	nextYearButton = new KPushButton(KIcon("arrow-right-double"), "", settingsWidget);
 	choicesLayout->addWidget(nextYearButton);
 	choicesLayout->addStretch(1);
 
-	QHBoxLayout *typeLayout = new QHBoxLayout(settingsLayout);
+	QHBoxLayout *typeLayout = new QHBoxLayout();
+	settingsLayout->addLayout(typeLayout);
 	typeLayout->addWidget(new QLabel(i18n("Source:"), settingsWidget));
 	sourceCombo = new KComboBox(settingsWidget);
 	sourceCombo->setEditable(false);
-	sourceCombo->insertItem(i18n("All Expenses"));
-	sourceCombo->insertItem(i18n("All Incomes"));
-	sourceCombo->insertItem(i18n("All Accounts"));
+	sourceCombo->addItem(i18n("All Expenses"));
+	sourceCombo->addItem(i18n("All Incomes"));
+	sourceCombo->addItem(i18n("All Accounts"));
 	Account *account = budget->expensesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Expenses: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Expenses: %1").arg(account->name()));
 		account = budget->expensesAccounts.next();
 	}
 	account = budget->incomesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Incomes: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Incomes: %1").arg(account->name()));
 		account = budget->incomesAccounts.next();
 	}
 	typeLayout->addWidget(sourceCombo);
@@ -153,7 +165,7 @@ CategoriesComparisonChart::CategoriesComparisonChart(Budget *budg, QWidget *pare
 
 	current_account = NULL;
 
-	layout->addWidget(settingsGroup);
+	layout->addWidget(settingsWidget);
 
 	connect(sourceCombo, SIGNAL(activated(int)), this, SLOT(sourceChanged(int)));
 	connect(prevMonthButton, SIGNAL(clicked()), this, SLOT(prevMonth()));
@@ -178,7 +190,8 @@ void CategoriesComparisonChart::sourceChanged(int index) {
 	updateDisplay();
 }
 void CategoriesComparisonChart::saveConfig() {
-	((KDialogBase*) parent())->saveDialogSize(*kapp->config(), "Categories Comparison Chart");
+	KConfigGroup config = KGlobal::config()->group("Categories Comparison Chart");
+	((KDialog*) parent())->saveDialogSize(config);
 }
 void CategoriesComparisonChart::toChanged(const QDate &date) {
 	bool error = false;
@@ -234,13 +247,13 @@ void CategoriesComparisonChart::prevMonth() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addMonths(from_date, -1);
+	from_date = calSys->addMonths(from_date, -1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addMonths(to_date, -1);
+		to_date = calSys->addMonths(to_date, -1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addMonths(to_date, -1);
+		to_date = calSys->addMonths(to_date, -1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -251,13 +264,13 @@ void CategoriesComparisonChart::nextMonth() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addMonths(from_date, 1);
+	from_date = calSys->addMonths(from_date, 1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addMonths(to_date, 1);
+		to_date = calSys->addMonths(to_date, 1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addMonths(to_date, 1);
+		to_date = calSys->addMonths(to_date, 1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -268,13 +281,13 @@ void CategoriesComparisonChart::prevYear() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addYears(from_date, -1);
+	from_date = calSys->addYears(from_date, -1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addYears(to_date, -1);
+		to_date = calSys->addYears(to_date, -1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addYears(to_date, -1);
+		to_date = calSys->addYears(to_date, -1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -285,13 +298,13 @@ void CategoriesComparisonChart::nextYear() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addYears(from_date, 1);
+	from_date = calSys->addYears(from_date, 1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addYears(to_date, 1);
+		to_date = calSys->addYears(to_date, 1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addYears(to_date, 1);
+		to_date = calSys->addYears(to_date, 1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -300,14 +313,14 @@ void CategoriesComparisonChart::nextYear() {
 }
 
 void CategoriesComparisonChart::save() {
-	if(!canvas) return;
-	KFileDialog *dialog = new KFileDialog(QString::null, QString::null, this, NULL, true);
+	if(!scene) return;
+	KFileDialog *dialog = new KFileDialog(KUrl(), QString::null, this);
 	QStringList filter;
 	filter << "image/png";
-	if(QImageIO::outputFormats().contains("GIF")) {
+	if(QImageWriter::supportedImageFormats().contains("GIF")) {
 		filter << "image/gif";
 	}
-	if(QImageIO::outputFormats().contains("JPEG")) {
+	if(QImageWriter::supportedImageFormats().contains("JPEG")) {
 		filter << "image/jpeg";
 	}
 	filter << "image/x-bmp";
@@ -318,7 +331,7 @@ void CategoriesComparisonChart::save() {
 	dialog->setOperationMode(KFileDialog::Saving);
 	dialog->setMode(KFile::File);
 	if(dialog->exec() != QDialog::Accepted) {dialog->deleteLater(); return;}
-	KURL url = dialog->selectedURL();
+	KUrl url = dialog->selectedUrl();
 	QString current_filter = dialog->currentFilter();
 	dialog->deleteLater();
 	if(url.isEmpty() && url.isValid()) return;
@@ -331,57 +344,74 @@ void CategoriesComparisonChart::save() {
 			KMessageBox::error(this, i18n("You selected a directory!"));
 			return;
 		}
-		KSaveFile ofile(url.path(), 0660);
-		if(ofile.status()) {
+		KSaveFile ofile(url.path());
+		ofile.open();
+		ofile.setPermissions((QFile::Permissions) 0x0660);
+		if(!ofile.isOpen()) {
 			ofile.abort();
 			KMessageBox::error(this, i18n("Couldn't open file for writing."));
 			return;
 		}
-		QPixmap pixmap(min_width, min_height);
-		QPainter p(&pixmap);
-		canvas->drawArea(QRect(0, 0, min_width, min_height), &p);
-		if(current_filter == "image/png") {pixmap.save(ofile.file(), "PNG");}
-		else if(current_filter == "image/x-bmp") {pixmap.save(ofile.file(), "BMP");}
-		else if(current_filter == "image/x-xbm") {pixmap.save(ofile.file(), "XBM");}
-		else if(current_filter == "image/x-xpm") {pixmap.save(ofile.file(), "XPM");}
-		else if(current_filter == "image/x-portable-pixmap") {pixmap.save(ofile.file(), "PPM");}
-		else if(current_filter == "image/gif") {pixmap.save(ofile.file(), "GIF");}
-		else if(current_filter == "image/jpeg") {pixmap.save(ofile.file(), "JPEG");}
-		if(ofile.status()) {
-			ofile.abort();
+		QRectF rect = scene->sceneRect();
+		rect.setX(0);
+		rect.setY(0);
+		rect.setRight(rect.right() + 20);
+		rect.setBottom(rect.bottom() + 20);
+		QPixmap pixmap((int) ceil(rect.width()), (int) ceil(rect.height()));
+		QPainter p(&pixmap);	
+		p.setRenderHint(QPainter::Antialiasing, true);
+		scene->render(&p, QRectF(), rect);
+		if(current_filter == "image/png") {pixmap.save(&ofile, "PNG");}
+		else if(current_filter == "image/x-bmp") {pixmap.save(&ofile, "BMP");}
+		else if(current_filter == "image/x-xbm") {pixmap.save(&ofile, "XBM");}
+		else if(current_filter == "image/x-xpm") {pixmap.save(&ofile, "XPM");}
+		else if(current_filter == "image/x-portable-pixmap") {pixmap.save(&ofile, "PPM");}
+		else if(current_filter == "image/gif") {pixmap.save(&ofile, "GIF");}
+		else if(current_filter == "image/jpeg") {pixmap.save(&ofile, "JPEG");}
+		if(!ofile.finalize()) {
 			KMessageBox::error(this, i18n("Error while writing file; file was not saved."));
 			return;
 		}
-		ofile.close();
-		if(ofile.status()) {
-			KMessageBox::error(this, i18n("Error after saving file; data may not have been saved."));
-			return;
-		}
 		return;
 	}
 
-	KTempFile tf;
-	tf.setAutoDelete(true);
-	QPixmap pixmap(min_width, min_height);
-	QPainter p(&pixmap);
-	canvas->drawArea(QRect(0, 0, min_width, min_height), &p);
-	if(current_filter == "image/png") {pixmap.save(tf.file(), "PNG");}
-	else if(current_filter == "image/x-bmp") {pixmap.save(tf.file(), "BMP");}
-	else if(current_filter == "image/x-xbm") {pixmap.save(tf.file(), "XBM");}
-	else if(current_filter == "image/x-xpm") {pixmap.save(tf.file(), "XPM");}
-	else if(current_filter == "image/x-portable-pixmap") {pixmap.save(tf.file(), "PPM");}
-	else if(current_filter == "image/gif") {pixmap.save(tf.file(), "GIF");}
-	else if(current_filter == "image/jpeg") {pixmap.save(tf.file(), "JPEG");}
-	KIO::NetAccess::upload(tf.name(), url, this);
+	KTemporaryFile tf;
+	tf.open();
+	tf.setAutoRemove(true);
+	QRectF rect = scene->sceneRect();
+	rect.setX(0);
+	rect.setY(0);
+	rect.setRight(rect.right() + 20);
+	rect.setBottom(rect.bottom() + 20);
+	QPixmap pixmap((int) ceil(rect.width()), (int) ceil(rect.height()));
+	QPainter p(&pixmap);	
+	p.setRenderHint(QPainter::Antialiasing, true);
+	scene->render(&p, QRectF(), rect);
+	if(current_filter == "image/png") {pixmap.save(&tf, "PNG");}
+	else if(current_filter == "image/x-bmp") {pixmap.save(&tf, "BMP");}
+	else if(current_filter == "image/x-xbm") {pixmap.save(&tf, "XBM");}
+	else if(current_filter == "image/x-xpm") {pixmap.save(&tf, "XPM");}
+	else if(current_filter == "image/x-portable-pixmap") {pixmap.save(&tf, "PPM");}
+	else if(current_filter == "image/gif") {pixmap.save(&tf, "GIF");}
+	else if(current_filter == "image/jpeg") {pixmap.save(&tf, "JPEG");}
+	KIO::NetAccess::upload(tf.fileName(), url, this);
 	
 }
 
 void CategoriesComparisonChart::print() {
-	if(!canvas) return;
-	KPrinter pr;
-	if(pr.setup(this)) {
+	if(!scene) return;
+	QPrinter pr;
+	QPrintDialog *dialog = new QPrintDialog(&pr, this);
+	if(dialog->exec() == QDialog::Accepted) {
 		QPainter p(&pr);
-		canvas->drawArea(QRect(0, 0, min_width, min_height), &p);
+		p.setRenderHint(QPainter::Antialiasing, true);
+		QRectF rect = scene->sceneRect();
+		rect.setX(0);
+		rect.setY(0);
+		rect.setRight(rect.right() + 20);
+		rect.setBottom(rect.bottom() + 20);
+		scene->render(&p, QRectF(), rect);
+		p.end();
 	}
 }
 QColor getColor(int index) {
@@ -408,7 +438,7 @@ QBrush getBrush(int index) {
 		case 1: {brush.setStyle(Qt::HorPattern); break;}
 		case 2: {brush.setStyle(Qt::VerPattern); break;}
 		case 3: {brush.setStyle(Qt::Dense5Pattern); break;}
-		case 4: {brush.setStyle(Qt::DiagCrossPattern); break;}
+		case 4: {brush.setStyle(Qt::CrossPattern); break;}
 		default: {}
 	}
 	brush.setColor(getColor(index % 12));
@@ -426,7 +456,7 @@ void CategoriesComparisonChart::updateDisplay() {
 	current_account = NULL;
 	
 	AccountType type;
-	switch(sourceCombo->currentItem()) {
+	switch(sourceCombo->currentIndex()) {
 		case 0: {
 			type = ACCOUNT_TYPE_EXPENSES;
 			Account *account = budget->expensesAccounts.first();
@@ -466,7 +496,7 @@ void CategoriesComparisonChart::updateDisplay() {
 		}
 		default: {
 			type = ACCOUNT_TYPE_EXPENSES;
-			int i = sourceCombo->currentItem() - 3;
+			int i = sourceCombo->currentIndex() - 3;
 			if(i < (int) budget->expensesAccounts.count()) current_account = budget->expensesAccounts.at(i);
 			else current_account = budget->incomesAccounts.at(i - budget->expensesAccounts.count());
 			if(current_account) {
@@ -657,9 +687,9 @@ void CategoriesComparisonChart::updateDisplay() {
 	/*int days = first_date.daysTo(to_date) + 1;
 	double months = monthsBetweenDates(first_date, to_date), years = yearsBetweenDates(first_date, to_date);*/
 
-	QCanvas *oldcanvas = canvas;
-	canvas = new QCanvas(this);
-	canvas->setBackgroundColor(Qt::white);
+	QGraphicsScene *oldscene = scene;
+	scene = new QGraphicsScene(this);
+	scene->setBackgroundBrush(Qt::white);
 	
 	QFont legend_font = font();
 	QFontMetrics fm(legend_font);
@@ -699,7 +729,7 @@ void CategoriesComparisonChart::updateDisplay() {
 			} else {
 				legend_string = it_desc.key();
 			}
-			legend_value = it_desc.data();
+			legend_value = it_desc.value();
 		} else {
 			legend_string = account->name();
 			legend_value = values[account];
@@ -712,18 +742,18 @@ void CategoriesComparisonChart::updateDisplay() {
 		} else {
 			legend_value = round(legend_value);
 		}
-		QCanvasText *legend_text = new QCanvasText(QString("%1 (%2\%)").arg(legend_string).arg(KGlobal::locale()->formatNumber(legend_value, deci)), legend_font, canvas);
-		
+		QGraphicsSimpleTextItem *legend_text = new QGraphicsSimpleTextItem(QString("%1 (%2\%)").arg(legend_string).arg(KGlobal::locale()->formatNumber(legend_value, deci)));		
 		int index_bak = index;
 		if(b_empty) index = n - 1;
 		if(legend_text->boundingRect().width() > text_width) text_width = legend_text->boundingRect().width();
-		legend_text->setColor(Qt::black);
-		legend_text->move(legend_x + 10 + fh + 5, margin + 10 + (fh + 5) * index);
-		legend_text->show();
+		legend_text->setFont(legend_font);
+		legend_text->setBrush(Qt::black);
+		legend_text->setPos(legend_x + 10 + fh + 5, margin + 10 + (fh + 5) * index);
+		scene->addItem(legend_text);
 		
 		if(current_account) {
-			if(it_desc.data() < 0.0) {
-				value -= it_desc.data();
+			if(it_desc.value() < 0.0) {
+				value -= it_desc.value();
 				*it_desc = 0.0;
 			}
 		} else {
@@ -758,23 +788,26 @@ void CategoriesComparisonChart::updateDisplay() {
 	double current_value = 0.0;
 	int prev_end = 0;
 	while((current_account && it_desc != it_desc_end) || account) {
-		if(current_account) current_value += it_desc.data();
+		if(current_account) current_value += it_desc.value();
 		else current_value += values[account];
 		int next_end = (int) lround((current_value * 360 * 16) / value);
 		int length = (next_end - prev_end);
-		QCanvasEllipse *ellipse = new QCanvasEllipse(diameter, diameter, prev_end, length, canvas);
+		QGraphicsEllipseItem *ellipse = new QGraphicsEllipseItem(-diameter/ 2.0, -diameter/ 2.0, diameter, diameter);
+		ellipse->setStartAngle(prev_end);
+		ellipse->setSpanAngle(length);
 		prev_end = next_end;
 		bool b_empty = false;
 		if(current_account && it_desc.key().isEmpty()) {b_empty = true;}
 		int index_bak = index;
 		if(b_empty) index = n - 1;
+		ellipse->setPen(Qt::NoPen);
 		ellipse->setBrush(getBrush(index));
-		ellipse->move(diameter / 2 + margin, diameter / 2 + margin);
-		ellipse->show();
-		QCanvasRectangle *legend_box = new QCanvasRectangle(legend_x + 10, margin + 10 + (fh + 5) * index, fh, fh, canvas);
+		ellipse->setPos(diameter / 2 + margin, diameter / 2 + margin);
+		scene->addItem(ellipse);
+		QGraphicsRectItem *legend_box = new QGraphicsRectItem(legend_x + 10, margin + 10 + (fh + 5) * index, fh, fh);
 		legend_box->setPen(QPen(Qt::black));
 		legend_box->setBrush(getBrush(index));
-		legend_box->show();
+		scene->addItem(legend_box);
 		if(current_account) {
 			++it_desc;
 		} else if(type == ACCOUNT_TYPE_ASSETS) {
@@ -786,49 +819,29 @@ void CategoriesComparisonChart::updateDisplay() {
 		else index++;
 	}
 
-	QCanvasRectangle *legend_outline = new QCanvasRectangle(legend_x, margin, 10 + fh + 5 + text_width + 10, 10 + ((fh + 5) * n) + 5, canvas);
+	QGraphicsRectItem *legend_outline = new QGraphicsRectItem(legend_x, margin, 10 + fh + 5 + text_width + 10, 10 + ((fh + 5) * n) + 5);
 	legend_outline->setPen(QPen(Qt::black));
-	legend_outline->show();
+	scene->addItem(legend_outline);
 
-	double ratio = (double) view->visibleWidth() / (double) view->visibleHeight();
-	min_width = (int) ceil(legend_outline->x() + legend_outline->width() + margin);
-	min_height = (int) ceil(legend_outline->y() + legend_outline->height() + margin);
-	if(min_height < diameter + margin * 2) min_height = diameter + margin * 2;
-	int height, width;
-	if(floor(min_height * ratio) < min_width) {
-		height = (int) floor(min_width / ratio);
-		width = min_width;
-	} else {
-		height = min_height;
-		width = (int) floor(min_height * ratio);
-	}
-	canvas->resize(width, height);
-	canvas->update();
-	QWMatrix mx;
-	mx.scale((double) view->visibleWidth() / (double) width, (double) view->visibleHeight() / (double) height);
-	view->setWorldMatrix(mx);
-	view->setCanvas(canvas);
-	if(oldcanvas) {
-		delete oldcanvas;
+	QRectF rect = scene->sceneRect();
+	rect.setX(0);
+	rect.setY(0);
+	rect.setRight(rect.right() + 20);
+	rect.setBottom(rect.bottom() + 20);
+	scene->setSceneRect(rect);
+	scene->update();	
+	view->setScene(scene);
+	view->fitInView(scene->sceneRect(), Qt::KeepAspectRatio);
+	if(oldscene) {
+		delete oldscene;
 	}
 	
 }
 
-void CategoriesComparisonChart::resizeEvent(QResizeEvent*) {
-	if(canvas) {
-		double ratio = (double) view->visibleWidth() / (double) view->visibleHeight();
-		int height, width;
-		if(floor(min_height * ratio) < min_width) {
-			height = (int) floor(min_width / ratio);
-			width = min_width;
-		} else {
-			height = min_height;
-			width = (int) floor(min_height * ratio);
-		}
-		canvas->resize(width, height);
-		QWMatrix mx;
-		mx.scale((double) view->visibleWidth() / (double) width, (double) view->visibleHeight() / (double) height);
-		view->setWorldMatrix(mx);
+void CategoriesComparisonChart::resizeEvent(QResizeEvent *e) {
+	QWidget::resizeEvent(e);
+	if(scene) {
+		view->fitInView(scene->sceneRect(), Qt::KeepAspectRatio);	
 	}
 }
 
@@ -836,31 +849,31 @@ void CategoriesComparisonChart::updateTransactions() {
 	updateDisplay();
 }
 void CategoriesComparisonChart::updateAccounts() {
-	int curindex = sourceCombo->currentItem();
+	int curindex = sourceCombo->currentIndex();
 	if(curindex > 2) {
 		curindex = 0;
 	}
 	sourceCombo->blockSignals(true);
 	sourceCombo->clear();
-	sourceCombo->insertItem(i18n("All Expenses"));
-	sourceCombo->insertItem(i18n("All Incomes"));
-	sourceCombo->insertItem(i18n("All Accounts"));
+	sourceCombo->addItem(i18n("All Expenses"));
+	sourceCombo->addItem(i18n("All Incomes"));
+	sourceCombo->addItem(i18n("All Accounts"));
 	int i = 3;
 	Account *account = budget->expensesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Expenses: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Expenses: %1").arg(account->name()));
 		if(account == current_account) curindex = i;
 		account = budget->expensesAccounts.next();
 		i++;
 	}
 	account = budget->incomesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Incomes: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Incomes: %1").arg(account->name()));
 		if(account == current_account) curindex = i;
 		account = budget->incomesAccounts.next();
 		i++;
 	}
-	if(curindex < sourceCombo->count()) sourceCombo->setCurrentItem(curindex);
+	if(curindex < sourceCombo->count()) sourceCombo->setCurrentIndex(curindex);
 	sourceCombo->blockSignals(false);
 	updateDisplay();
 }
