@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,14 +23,15 @@
 
 #include <qwidget.h>
 #include <qdatetime.h>
+#include <QResizeEvent>
 
 class Budget;
 class Account;
 class QPushButton;
 class KDateEdit;
 class QCheckBox;
-class QCanvas;
-class QCanvasView;
+class QGraphicsScene;
+class QGraphicsView;
 class QButtonGroup;
 class QComboBox;
 
@@ -53,14 +54,11 @@ class CategoriesComparisonChart : public QWidget {
 		KDateEdit *fromEdit, *toEdit;
 		QPushButton *nextYearButton, *prevYearButton, *nextMonthButton, *prevMonthButton;
 		QPushButton *saveButton, *printButton;
-		QCanvas *canvas;
-		QCanvasView *view;
+		QGraphicsScene *scene;
+		QGraphicsView *view;
 		QButtonGroup *typeGroup;
 		QComboBox *sourceCombo;
 
-		int min_width;
-		int min_height;
-
 		void resizeEvent(QResizeEvent*);
 
 	public slots:
