@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,6 +30,12 @@
 #include "recurrence.h"
 
 #include <qobject.h>
+#include <QTextStream>
+#include <QLineEdit>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QTextStream>
+#include <QVBoxLayout>
 #include <khtml_part.h>
 #include <khtmlview.h>
 #include <qlayout.h>
@@ -44,7 +50,7 @@
 #include <kcombobox.h>
 #include <qlabel.h>
 #include <kio/netaccess.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <ksavefile.h>
 #include <kfiledialog.h>
 #include <kurl.h>
@@ -55,22 +61,20 @@
 #include <kiconloader.h>
 #include <kconfig.h>
 #include <qgroupbox.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
-#include <kbuttonbox.h>
+#include <QButtonGroup>
+#include <KDialogButtonBox>
 
 #include <math.h>
 
 extern QString htmlize_string(QString str);
 extern double monthsBetweenDates(const QDate &date1, const QDate &date2);
 extern double yearsBetweenDates(const QDate &date1, const QDate &date2);
-extern QDate addMonths(const QDate &date, int nmonths);
-extern QDate addYears(const QDate &date, int nyears);
 
 CategoriesComparisonReport::CategoriesComparisonReport(Budget *budg, QWidget *parent, bool extra_parameters) : QWidget(parent), budget(budg), b_extra(extra_parameters) {
 
-	setWFlags(getWFlags() | Qt::WDestructiveClose);
+	setAttribute(Qt::WA_DeleteOnClose, true);
 
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 
@@ -84,46 +88,43 @@ CategoriesComparisonReport::CategoriesComparisonReport(Budget *budg, QWidget *pa
 		trans = budget->transactions.next();
 	}
 	to_date = QDate::currentDate();
-	from_date = calSys->addDays(addYears(to_date, -1), 1);
+	from_date = calSys->addDays(calSys->addYears(to_date, -1), 1);
 	if(first_date.isNull()) {
 		from_date = to_date;
 	} else if(from_date < first_date) {
 		from_date = first_date;
 	}
 	
-	QVBoxLayout *layout = new QVBoxLayout(this, 6, 6);
+	QVBoxLayout *layout = new QVBoxLayout(this);
+	layout->setContentsMargins(0, 0, 0, 0);
 
-	KButtonBox *buttons = new KButtonBox(this);
-	buttons->addStretch(1);
-	saveButton = buttons->addButton(KStdGuiItem::saveAs());
-	printButton = buttons->addButton(KStdGuiItem::print());
-	buttons->layout();
+	KDialogButtonBox *buttons = new KDialogButtonBox(this);
+	saveButton = buttons->addButton(KStandardGuiItem::saveAs(), QDialogButtonBox::ActionRole);
+	printButton = buttons->addButton(KStandardGuiItem::print(), QDialogButtonBox::ActionRole);
 	layout->addWidget(buttons);
 	
 	htmlpart = new KHTMLPart(this);
 	layout->addWidget(htmlpart->view());
 
-	KConfig *config = kapp->config();
-	config->setGroup("Categories Comparison Report");
+	KConfigGroup config = KGlobal::config()->group("Categories Comparison Report");
 
-	QGroupBox *settingsGroup = new QGroupBox(1, Qt::Horizontal, i18n("Options"), this);
-	QWidget *settingsWidget = new QWidget(settingsGroup);
-	QGridLayout *settingsLayout = new QGridLayout(settingsWidget, 3, 2, 0, 6);
+	QGroupBox *settingsWidget = new QGroupBox(i18n("Options"), this);
+	QGridLayout *settingsLayout = new QGridLayout(settingsWidget);
 
 	settingsLayout->addWidget(new QLabel(i18n("Source:"), settingsWidget), 0, 0);
 	QHBoxLayout *sourceLayout = new QHBoxLayout();
 	settingsLayout->addLayout(sourceLayout, 0, 1);
 	sourceCombo = new KComboBox(settingsWidget);
 	sourceCombo->setEditable(false);
-	sourceCombo->insertItem(i18n("All Categories"));
+	sourceCombo->addItem(i18n("All Categories"));
 	Account *account = budget->expensesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Expenses: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Expenses: %1").arg(account->name()));
 		account = budget->expensesAccounts.next();
 	}
 	account = budget->incomesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Incomes: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Incomes: %1").arg(account->name()));
 		account = budget->incomesAccounts.next();
 	}
 	sourceLayout->addWidget(sourceCombo);
@@ -131,18 +132,18 @@ CategoriesComparisonReport::CategoriesComparisonReport(Budget *budg, QWidget *pa
 	payeeDescriptionWidget = NULL;
 	if(b_extra) {
 		payeeDescriptionWidget = new QWidget(settingsWidget);
-		QHBoxLayout *payeeLayout = new QHBoxLayout(payeeDescriptionWidget, 0, 6);
+		QHBoxLayout *payeeLayout = new QHBoxLayout(payeeDescriptionWidget);
 		//payeeLayout->addWidget(new QLabel(i18n("Divide on:"), payeeDescriptionWidget));
-		QButtonGroup *group = new QButtonGroup();
+		QButtonGroup *group = new QButtonGroup(this);
 		descriptionButton = new QRadioButton(i18n("Descriptions for"), payeeDescriptionWidget);
 		descriptionButton->setChecked(true);
-		group->insert(descriptionButton);
+		group->addButton(descriptionButton);
 		payeeLayout->addWidget(descriptionButton);
 		payeeCombo = new KComboBox(payeeDescriptionWidget);
 		payeeCombo->setEditable(false);
 		payeeLayout->addWidget(payeeCombo);
 		payeeButton = new QRadioButton(i18n("Payees/payers for"), payeeDescriptionWidget);
-		group->insert(payeeButton);
+		group->addButton(payeeButton);
 		payeeLayout->addWidget(payeeButton);
 		descriptionCombo = new KComboBox(payeeDescriptionWidget);
 		descriptionCombo->setEditable(false);
@@ -164,19 +165,21 @@ CategoriesComparisonReport::CategoriesComparisonReport(Budget *budg, QWidget *pa
 	fromButton->setChecked(true);
 	choicesLayout->addWidget(fromButton);
 	fromEdit = new KDateEdit(settingsWidget);
+	fromEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	fromEdit->setDate(from_date);
 	choicesLayout->addWidget(fromEdit);
 	choicesLayout->addWidget(new QLabel(i18n("To"), settingsWidget));
 	toEdit = new KDateEdit(settingsWidget);
+	toEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	toEdit->setDate(to_date);
 	choicesLayout->addWidget(toEdit);
-	prevYearButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("2leftarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	prevYearButton = new KPushButton(KIcon("arrow-left-double"), "", settingsWidget);
 	choicesLayout->addWidget(prevYearButton);
-	prevMonthButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("1leftarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	prevMonthButton = new KPushButton(KIcon("arrow-left"), "", settingsWidget);
 	choicesLayout->addWidget(prevMonthButton);
-	nextMonthButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("1rightarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	nextMonthButton = new KPushButton(KIcon("arrow-right"), "", settingsWidget);
 	choicesLayout->addWidget(nextMonthButton);
-	nextYearButton = new KPushButton(KApplication::kApplication()->iconLoader()->loadIconSet("2rightarrow", KIcon::Small, KIcon::SizeSmall), "", settingsWidget);
+	nextYearButton = new KPushButton(KIcon("arrow-right-double"), "", settingsWidget);
 	choicesLayout->addWidget(nextYearButton);
 	choicesLayout->addStretch(1);
 
@@ -184,26 +187,26 @@ CategoriesComparisonReport::CategoriesComparisonReport(Budget *budg, QWidget *pa
 	QHBoxLayout *enabledLayout = new QHBoxLayout();
 	settingsLayout->addLayout(enabledLayout, 2, 1);
 	valueButton = new QCheckBox(i18n("Value"), settingsWidget);
-	valueButton->setChecked(config->readBoolEntry("valueEnabled", true));
+	valueButton->setChecked(config.readEntry("valueEnabled", true));
 	enabledLayout->addWidget(valueButton);
 	dailyButton = new QCheckBox(i18n("Daily"), settingsWidget);
-	dailyButton->setChecked(config->readBoolEntry("dailyAverageEnabled", true));
+	dailyButton->setChecked(config.readEntry("dailyAverageEnabled", true));
 	enabledLayout->addWidget(dailyButton);
 	monthlyButton = new QCheckBox(i18n("Monthly"), settingsWidget);
-	monthlyButton->setChecked(config->readBoolEntry("monthlyAverageEnabled", true));
+	monthlyButton->setChecked(config.readEntry("monthlyAverageEnabled", true));
 	enabledLayout->addWidget(monthlyButton);
 	yearlyButton = new QCheckBox(i18n("Yearly"), settingsWidget);
-	yearlyButton->setChecked(config->readBoolEntry("yearlyEnabled", false));
+	yearlyButton->setChecked(config.readEntry("yearlyEnabled", false));
 	enabledLayout->addWidget(yearlyButton);
 	countButton = new QCheckBox(i18n("Quantity"), settingsWidget);
-	countButton->setChecked(config->readBoolEntry("transactionCountEnabled", true));
+	countButton->setChecked(config.readEntry("transactionCountEnabled", true));
 	enabledLayout->addWidget(countButton);
 	perButton = new QCheckBox(i18n("Average value"), settingsWidget);
-	perButton->setChecked(config->readBoolEntry("valuePerTransactionEnabled", false));
+	perButton->setChecked(config.readEntry("valuePerTransactionEnabled", false));
 	enabledLayout->addWidget(perButton);
 	enabledLayout->addStretch(1);
 
-	layout->addWidget(settingsGroup);
+	layout->addWidget(settingsWidget);
 
 	if(b_extra) {
 		connect(payeeButton, SIGNAL(toggled(bool)), this, SLOT(payeeToggled(bool)));
@@ -272,9 +275,9 @@ void CategoriesComparisonReport::sourceChanged(int i) {
 			if(i < (int) budget->expensesAccounts.count()) current_account = budget->expensesAccounts.at(i);
 			else current_account = budget->incomesAccounts.at(i - budget->expensesAccounts.count());
 			if(current_account) {
-				descriptionCombo->insertItem(i18n("All descriptions"));
-				if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->insertItem(i18n("All payees"));
-				else payeeCombo->insertItem(i18n("All payers"));
+				descriptionCombo->addItem(i18n("All descriptions"));
+				if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->addItem(i18n("All payees"));
+				else payeeCombo->addItem(i18n("All payers"));
 				has_empty_description = false;
 				has_empty_payee = false;
 				QMap<QString, bool> descriptions, payees;
@@ -295,16 +298,16 @@ void CategoriesComparisonReport::sourceChanged(int i) {
 				}
 				QMap<QString, bool>::iterator it_e = descriptions.end();
 				for(QMap<QString, bool>::iterator it = descriptions.begin(); it != it_e; ++it) {
-					descriptionCombo->insertItem(it.key());
+					descriptionCombo->addItem(it.key());
 				}
-				if(has_empty_description) descriptionCombo->insertItem(i18n("No description"));
+				if(has_empty_description) descriptionCombo->addItem(i18n("No description"));
 				QMap<QString, bool>::iterator it2_e = payees.end();
 				for(QMap<QString, bool>::iterator it2 = payees.begin(); it2 != it2_e; ++it2) {
-					payeeCombo->insertItem(it2.key());
+					payeeCombo->addItem(it2.key());
 				}
 				if(has_empty_payee) {
-					if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->insertItem(i18n("No payee"));
-					else payeeCombo->insertItem(i18n("No payer"));
+					if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->addItem(i18n("No payee"));
+					else payeeCombo->addItem(i18n("No payer"));
 				}
 			} else {
 				payeeDescriptionWidget->setEnabled(false);
@@ -316,15 +319,14 @@ void CategoriesComparisonReport::sourceChanged(int i) {
 	updateDisplay();
 }
 void CategoriesComparisonReport::saveConfig() {
-	KConfig *config = kapp->config();
-	((KDialogBase*) parent())->saveDialogSize(*config, "Categories Comparison Report");
-	config->setGroup("Categories Comparison Report");
-	config->writeEntry("valueEnabled", valueButton->isChecked());
-	config->writeEntry("dailyAverageEnabled", dailyButton->isChecked());
-	config->writeEntry("monthlyAverageEnabled", monthlyButton->isChecked());
-	config->writeEntry("yearlyAverageEnabled", yearlyButton->isChecked());
-	config->writeEntry("transactionCountEnabled", countButton->isChecked());
-	config->writeEntry("valuePerTransactionEnabled", perButton->isChecked());
+	KConfigGroup config = KGlobal::config()->group("Categories Comparison Report");
+	((KDialog*) parent())->saveDialogSize(config);
+	config.writeEntry("valueEnabled", valueButton->isChecked());
+	config.writeEntry("dailyAverageEnabled", dailyButton->isChecked());
+	config.writeEntry("monthlyAverageEnabled", monthlyButton->isChecked());
+	config.writeEntry("yearlyAverageEnabled", yearlyButton->isChecked());
+	config.writeEntry("transactionCountEnabled", countButton->isChecked());
+	config.writeEntry("valuePerTransactionEnabled", perButton->isChecked());
 }
 void CategoriesComparisonReport::toChanged(const QDate &date) {
 	bool error = false;
@@ -380,13 +382,13 @@ void CategoriesComparisonReport::prevMonth() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addMonths(from_date, -1);
+	from_date = calSys->addMonths(from_date, -1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addMonths(to_date, -1);
+		to_date = calSys->addMonths(to_date, -1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addMonths(to_date, -1);
+		to_date = calSys->addMonths(to_date, -1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -397,13 +399,13 @@ void CategoriesComparisonReport::nextMonth() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addMonths(from_date, 1);
+	from_date = calSys->addMonths(from_date, 1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addMonths(to_date, 1);
+		to_date = calSys->addMonths(to_date, 1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addMonths(to_date, 1);
+		to_date = calSys->addMonths(to_date, 1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -414,13 +416,13 @@ void CategoriesComparisonReport::prevYear() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addYears(from_date, -1);
+	from_date = calSys->addYears(from_date, -1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addYears(to_date, -1);
+		to_date = calSys->addYears(to_date, -1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addYears(to_date, -1);
+		to_date = calSys->addYears(to_date, -1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -431,13 +433,13 @@ void CategoriesComparisonReport::nextYear() {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	fromEdit->blockSignals(true);
 	toEdit->blockSignals(true);
-	from_date = addYears(from_date, 1);
+	from_date = calSys->addYears(from_date, 1);
 	fromEdit->setDate(from_date);
 	if(calSys->day(to_date) == calSys->daysInMonth(to_date)) {
-		to_date = addYears(to_date, 1);
+		to_date = calSys->addYears(to_date, 1);
 		calSys->setYMD(to_date, calSys->year(to_date), calSys->month(to_date), calSys->daysInMonth(to_date));
 	} else {
-		to_date = addYears(to_date, 1);
+		to_date = calSys->addYears(to_date, 1);
 	}
 	toEdit->setDate(to_date);
 	fromEdit->blockSignals(false);
@@ -446,14 +448,14 @@ void CategoriesComparisonReport::nextYear() {
 }
 
 void CategoriesComparisonReport::save() {
-	KFileDialog *dialog = new KFileDialog(QString::null, QString::null, this, NULL, true);
+	KFileDialog *dialog = new KFileDialog(KUrl(), QString::null, this);
 	QStringList filter;
 	filter << "text/html";
 	dialog->setMimeFilter(filter, "text/html");
 	dialog->setOperationMode(KFileDialog::Saving);
 	dialog->setMode(KFile::File);
 	if(dialog->exec() != QDialog::Accepted) {dialog->deleteLater(); return;}
-	KURL url = dialog->selectedURL();
+	KUrl url = dialog->selectedUrl();
 	dialog->deleteLater();
 	if(url.isEmpty() && url.isValid()) return;
 	if(url.isLocalFile()) {
@@ -465,34 +467,31 @@ void CategoriesComparisonReport::save() {
 			KMessageBox::error(this, i18n("You selected a directory!"));
 			return;
 		}
-		KSaveFile ofile(url.path(), 0660);
-		if(ofile.status()) {
+		KSaveFile ofile(url.path());
+		ofile.open();
+		ofile.setPermissions((QFile::Permissions) 0x0660);
+		if(!ofile.isOpen()) {
 			ofile.abort();
 			KMessageBox::error(this, i18n("Couldn't open file for writing."));
 			return;
 		}
-		QTextStream &outf = *ofile.textStream();
-		outf.setEncoding(QTextStream::UnicodeUTF8);
+		QTextStream outf(&ofile);
+		outf.setCodec("UTF-8");
 		outf << source;
-		if(ofile.status()) {
-			ofile.abort();
+		if(!ofile.finalize()) {
 			KMessageBox::error(this, i18n("Error while writing file; file was not saved."));
 			return;
 		}
-		ofile.close();
-		if(ofile.status()) {
-			KMessageBox::error(this, i18n("Error after saving file; data may not have been saved."));
-			return;
-		}
 		return;
 	}
 
-	KTempFile tf;
-	tf.setAutoDelete(true);
-	QTextStream &outf = *tf.textStream();
-	outf.setEncoding(QTextStream::UnicodeUTF8);
+	KTemporaryFile tf;
+	tf.open();
+	tf.setAutoRemove(true);
+	QTextStream outf(&tf);
+	outf.setCodec("UTF-8");
 	outf << source;
-	KIO::NetAccess::upload(tf.name(), url, this);
+	KIO::NetAccess::upload(tf.fileName(), url, this);
 	
 }
 
@@ -529,7 +528,7 @@ void CategoriesComparisonReport::updateDisplay() {
 	
 	int i_source = 0;
 	AccountType type = ACCOUNT_TYPE_EXPENSES;
-	switch(sourceCombo->currentItem()) {
+	switch(sourceCombo->currentIndex()) {
 		case 0: {
 			Account *account = budget->expensesAccounts.first();
 			while(account) {
@@ -546,28 +545,28 @@ void CategoriesComparisonReport::updateDisplay() {
 			break;
 		}
 		default: {
-			int i = sourceCombo->currentItem() - 1;
+			int i = sourceCombo->currentIndex() - 1;
 			if(i < (int) budget->expensesAccounts.count()) current_account = budget->expensesAccounts.at(i);
 			else current_account = budget->incomesAccounts.at(i - budget->expensesAccounts.count());
 			if(current_account) {
 				type = current_account->type();
 				if(b_extra) {
-					if(has_empty_description) descriptionCombo->changeItem("", descriptionCombo->count() - 1);
-					if(has_empty_payee) payeeCombo->changeItem("", payeeCombo->count() - 1);
+					if(has_empty_description) descriptionCombo->setItemText(descriptionCombo->count() - 1, "");
+					if(has_empty_payee) payeeCombo->setItemText(payeeCombo->count() - 1, "");
 					if(descriptionButton->isChecked()) {
-						int p_index = payeeCombo->currentItem();
+						int p_index = payeeCombo->currentIndex();
 						if(p_index == 0)  {
 							i_source = 1;
 						} else {
-							current_payee = payeeCombo->text(p_index);
+							current_payee = payeeCombo->itemText(p_index);
 							i_source = 3;
 						}
 					} else {
-						int d_index = descriptionCombo->currentItem();
+						int d_index = descriptionCombo->currentIndex();
 						if(d_index == 0)  {
 							i_source = 2;
 						} else {
-							current_description = descriptionCombo->text(d_index);
+							current_description = descriptionCombo->itemText(d_index);
 							i_source = 4;
 						}
 					}
@@ -758,7 +757,7 @@ void CategoriesComparisonReport::updateDisplay() {
 	} else {
 		title = i18n("Incomes & Expenses");
 	}
-	QTextOStream outf(&source);
+	QTextStream outf(&source, QIODevice::WriteOnly);
 	outf << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">" << '\n';
 	outf << "<html>" << '\n';
 	outf << "\t<head>" << '\n';
@@ -769,8 +768,8 @@ void CategoriesComparisonReport::updateDisplay() {
 	outf << "\t\t<meta name=\"GENERATOR\" content=\"Eqonomize!\">" << '\n';
 	outf << "\t</head>" << '\n';
 	outf << "\t<body>" << '\n';
-	if(fromButton->isChecked()) outf << "\t\t<h2>" << i18n("html format; %1: title; %2: from date; %3: to date", "%1 (%2&ndash;%3)").arg(htmlize_string(title)).arg(htmlize_string(KGlobal::locale()->formatDate(first_date, true))).arg(htmlize_string(KGlobal::locale()->formatDate(to_date, true))) << "</h2>" << '\n';
-	else outf << "\t\t<h2>" << i18n("html format; %1: title; %2: to date", "%1 (to %2)").arg(htmlize_string(title)).arg(htmlize_string(KGlobal::locale()->formatDate(to_date, true))) << "</h2>" << '\n';
+	if(fromButton->isChecked()) outf << "\t\t<h2>" << i18nc("html format; %1: title; %2: from date; %3: to date", "%1 (%2&ndash;%3)").arg(htmlize_string(title)).arg(htmlize_string(KGlobal::locale()->formatDate(first_date, KLocale::ShortDate))).arg(htmlize_string(KGlobal::locale()->formatDate(to_date, KLocale::ShortDate))) << "</h2>" << '\n';
+	else outf << "\t\t<h2>" << i18nc("html format; %1: title; %2: to date", "%1 (to %2)").arg(htmlize_string(title)).arg(htmlize_string(KGlobal::locale()->formatDate(to_date, KLocale::ShortDate))) << "</h2>" << '\n';
 	outf << "\t\t<table width=\"100%\" border=\"0\" cellspacing=\"0\" cellpadding=\"5\">" << '\n';
 	outf << "\t\t\t<thead align=\"left\">" << '\n';
 	outf << "\t\t\t\t<tr>" << '\n';
@@ -803,7 +802,7 @@ void CategoriesComparisonReport::updateDisplay() {
 	if(current_account) {
 		QMap<QString, double>::iterator it_e = desc_counts.end();
 		for(QMap<QString, double>::iterator it = desc_counts.begin(); it != it_e; ++it) {
-			if(modf(it.data(), &intpart) != 0.0) {
+			if(modf(it.value(), &intpart) != 0.0) {
 				i_count_frac = 2;
 				break;
 			}
@@ -841,12 +840,12 @@ void CategoriesComparisonReport::updateDisplay() {
 			} else {
 				outf << "\t\t\t\t\t<td align=\"left\" style=\"border-right: thin solid\">" << htmlize_string(it.key()) << "</td>";
 			}
-			if(enabled[0]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.data())) << "</td>";
-			if(enabled[1]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.data() / days)) << "</td>";
-			if(enabled[2]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.data() / months)) << "</td>";
-			if(enabled[3]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.data() / years)) << "</td>";
-			if(enabled[4]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatNumber(itc.data(), i_count_frac)) << "</td>";
-			if(enabled[5]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(itc.data() == 0.0 ? 0.0 : (it.data() / itc.data()))) << "</td>";
+			if(enabled[0]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.value())) << "</td>";
+			if(enabled[1]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.value() / days)) << "</td>";
+			if(enabled[2]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.value() / months)) << "</td>";
+			if(enabled[3]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(it.value() / years)) << "</td>";
+			if(enabled[4]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatNumber(itc.value(), i_count_frac)) << "</td>";
+			if(enabled[5]) outf << "<td nowrap align=\"right\">" << htmlize_string(KGlobal::locale()->formatMoney(itc.value() == 0.0 ? 0.0 : (it.value() / itc.value()))) << "</td>";
 			outf << "\n";
 			outf << "\t\t\t\t</tr>" << '\n';
 		}
@@ -928,10 +927,10 @@ void CategoriesComparisonReport::updateDisplay() {
 	htmlpart->write(source);
 	htmlpart->end();
 	if(current_account && b_extra) {
-		if(has_empty_description) descriptionCombo->changeItem(i18n("No description"), descriptionCombo->count() - 1);
+		if(has_empty_description) descriptionCombo->setItemText(descriptionCombo->count() - 1, i18n("No description"));
 		if(has_empty_payee) {
-			if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->changeItem(i18n("No payee"), payeeCombo->count() - 1);
-			else payeeCombo->changeItem(i18n("No payer"), payeeCombo->count() - 1);
+			if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->setItemText(payeeCombo->count() - 1, i18n("No payee"));
+			else payeeCombo->setItemText(payeeCombo->count() - 1, i18n("No payer"));
 		}
 	}
 }
@@ -939,15 +938,15 @@ void CategoriesComparisonReport::updateDisplay() {
 void CategoriesComparisonReport::updateTransactions() {
 	if(b_extra && current_account) {
 		int curindex_d = 0, curindex_p = 0;
-		bool restore_d = (descriptionCombo->currentItem() > 0);
-		bool restore_p = (payeeCombo->currentItem() > 0);
+		bool restore_d = (descriptionCombo->currentIndex() > 0);
+		bool restore_p = (payeeCombo->currentIndex() > 0);
 		payeeCombo->blockSignals(true);
 		descriptionCombo->blockSignals(true);
 		payeeCombo->clear();
 		descriptionCombo->clear();
-		descriptionCombo->insertItem(i18n("All descriptions"));
-		if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->insertItem(i18n("All payees"));
-		else payeeCombo->insertItem(i18n("All payers"));
+		descriptionCombo->addItem(i18n("All descriptions"));
+		if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->addItem(i18n("All payees"));
+		else payeeCombo->addItem(i18n("All payers"));
 		has_empty_description = false;
 		has_empty_payee = false;
 		QMap<QString, bool> descriptions, payees;
@@ -970,35 +969,35 @@ void CategoriesComparisonReport::updateTransactions() {
 		QMap<QString, bool>::iterator it_e = descriptions.end();
 		for(QMap<QString, bool>::iterator it = descriptions.begin(); it != it_e; ++it) {
 			if(restore_d && it.key() == current_description) {curindex_d = i;}
-			descriptionCombo->insertItem(it.key());
+			descriptionCombo->addItem(it.key());
 			i++;
 		}
 		if(has_empty_description) {
 			if(restore_d && current_description.isEmpty()) curindex_d = i;
-			descriptionCombo->insertItem(i18n("No description"));
+			descriptionCombo->addItem(i18n("No description"));
 		}
 		if(curindex_d < descriptionCombo->count()) {
-			descriptionCombo->setCurrentItem(curindex_d);
+			descriptionCombo->setCurrentIndex(curindex_d);
 		}
-		if(descriptionCombo->currentItem() == 0) {
+		if(descriptionCombo->currentIndex() == 0) {
 			current_description = "";
 		}
 		i = 1;
 		QMap<QString, bool>::iterator it2_e = payees.end();
 		for(QMap<QString, bool>::iterator it2 = payees.begin(); it2 != it2_e; ++it2) {
 			if(restore_p && it2.key() == current_payee) {curindex_p = i;}
-			payeeCombo->insertItem(it2.key());
+			payeeCombo->addItem(it2.key());
 			i++;
 		}
 		if(has_empty_payee) {
 			if(restore_p && current_payee.isEmpty()) curindex_p = i;
-			if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->insertItem(i18n("No payee"));
-			else payeeCombo->insertItem(i18n("No payer"));
+			if(current_account->type() == ACCOUNT_TYPE_EXPENSES) payeeCombo->addItem(i18n("No payee"));
+			else payeeCombo->addItem(i18n("No payer"));
 		}
 		if(curindex_p < payeeCombo->count()) {
-			payeeCombo->setCurrentItem(curindex_d);
+			payeeCombo->setCurrentIndex(curindex_d);
 		}
-		if(payeeCombo->currentItem() == 0) {
+		if(payeeCombo->currentIndex() == 0) {
 			current_payee = "";
 		}
 		payeeCombo->blockSignals(false);
@@ -1010,23 +1009,23 @@ void CategoriesComparisonReport::updateAccounts() {
 	int curindex = 0;
 	sourceCombo->blockSignals(true);
 	sourceCombo->clear();
-	sourceCombo->insertItem(i18n("All Categories"));
+	sourceCombo->addItem(i18n("All Categories"));
 	int i = 1;
 	Account *account = budget->expensesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Expenses: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Expenses: %1").arg(account->name()));
 		if(account == current_account) curindex = i;
 		account = budget->expensesAccounts.next();
 		i++;
 	}
 	account = budget->incomesAccounts.first();
 	while(account) {
-		sourceCombo->insertItem(i18n("Incomes: %1").arg(account->name()));
+		sourceCombo->addItem(i18n("Incomes: %1").arg(account->name()));
 		if(account == current_account) curindex = i;
 		account = budget->incomesAccounts.next();
 		i++;
 	}
-	if(curindex < sourceCombo->count()) sourceCombo->setCurrentItem(curindex);
+	if(curindex < sourceCombo->count()) sourceCombo->setCurrentIndex(curindex);
 	sourceCombo->blockSignals(false);
 	if(curindex == 0 && b_extra) {
 		sourceChanged(curindex);
