@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,46 +25,115 @@
 #include "editsplitdialog.h"
 #include "transactioneditwidget.h"
 #include "budget.h"
+#include "eqonomize.h"
 
 #include <kglobal.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <qlayout.h>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QMenu>
+#include <QVBoxLayout>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include "kdateedit.h"
 #include <qlabel.h>
-#include <kbuttonbox.h>
+#include <KDialogButtonBox>
 #include <kpushbutton.h>
-#include <klistview.h>
+#include <QTreeWidget>
 #include <kdeversion.h>
 #include <kiconloader.h>
 #include <kapplication.h>
 
-class SplitListViewItem : public KListViewItem {
+class SplitListViewItem : public QTreeWidgetItem {
 	protected:
 		Transaction *o_trans;
+		bool b_deposit;
 	public:
-		SplitListViewItem(Transaction *trans, QListView *parent, QString, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null);
-		int compare(QListViewItem *i, int col, bool ascending) const;
+		SplitListViewItem(Transaction *trans, bool deposit);
+		bool operator<(const QTreeWidgetItem&) const;
 		Transaction *transaction() const;
+		bool isDeposit() const;
+		void setTransaction(Transaction *trans, bool deposit);
 };
 
-SplitListViewItem::SplitListViewItem(Transaction *trans, QListView *parent, QString s1, QString s2, QString s3, QString s4, QString s5, QString s6, QString s7, QString s8) : KListViewItem(parent, s1, s2, s3, s4, s5, s6, s7, s8), o_trans(trans) {}
-int SplitListViewItem::compare(QListViewItem *i, int col, bool ascending) const {
-	return QListViewItem::compare(i, col, ascending);
+SplitListViewItem::SplitListViewItem(Transaction *trans, bool deposit) : QTreeWidgetItem() {
+	setTransaction(trans, deposit);
+	setTextAlignment(3, Qt::AlignRight);
+	setTextAlignment(4, Qt::AlignRight);
+}
+bool SplitListViewItem::operator<(const QTreeWidgetItem &i_pre) const {
+	int col = 0;
+	if(treeWidget()) col = treeWidget()->sortColumn();
+	SplitListViewItem *i = (SplitListViewItem*) &i_pre;
+	if(col == 3) {
+		double value1 = 0.0;
+		double value2 = 0.0;
+		if(b_deposit && o_trans->value() < 0.0) value1 = -o_trans->value();
+		else if(!b_deposit && o_trans->value() >= 0.0) value1 = o_trans->value();
+		if(i->isDeposit() && i->transaction()->value() < 0.0) value2 = -i->transaction()->value();
+		else if(!i->isDeposit() && i->transaction()->value() >= 0.0) value2 = i->transaction()->value();
+		return value1 < value2;
+	} else if(col == 4) {
+		double value1 = 0.0;
+		double value2 = 0.0;
+		if(!b_deposit && o_trans->value() < 0.0) value1 = -o_trans->value();
+		else if(b_deposit && o_trans->value() >= 0.0) value1 = o_trans->value();
+		if(!i->isDeposit() && i->transaction()->value() < 0.0) value2 = -i->transaction()->value();
+		else if(i->isDeposit() && i->transaction()->value() >= 0.0) value2 = i->transaction()->value();
+		return value1 < value2;
+	}
+	return QTreeWidgetItem::operator<(i_pre);
 }
 Transaction *SplitListViewItem::transaction() const {
 	return o_trans;
 }
+bool SplitListViewItem::isDeposit() const {
+	return b_deposit;
+}
+void SplitListViewItem::setTransaction(Transaction *trans, bool deposit) {
+	o_trans = trans;
+	b_deposit = deposit;
+	Budget *budget = trans->budget();
+	double value = trans->value();
+	setText(1, trans->description());
+	setText(2, deposit ? trans->fromAccount()->name() : trans->toAccount()->name());
+	if(deposit) setText(3, value >= 0.0 ? QString::null : KGlobal::locale()->formatMoney(-value));
+	else setText(3, value < 0.0 ? QString::null : KGlobal::locale()->formatMoney(value));
+	if(!deposit) setText(4, value >= 0.0 ? QString::null : KGlobal::locale()->formatMoney(-value));
+	else setText(4, value < 0.0 ? QString::null : KGlobal::locale()->formatMoney(value));
+	if(trans->type() == TRANSACTION_TYPE_INCOME) {
+		if(((Income*) trans)->security()) setText(0, i18n("Dividend"));
+		else if(value >= 0) setText(0, i18n("Income"));
+		else setText(0, i18n("Repayment"));
+	} else if(trans->type() == TRANSACTION_TYPE_EXPENSE) {
+		if(value >= 0) setText(0, i18n("Expense"));
+		else setText(0, i18n("Refund"));
+	} else if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) {
+		setText(0, i18n("Security Buy"));
+	} else if(trans->type() == TRANSACTION_TYPE_SECURITY_SELL) {
+		setText(0, i18n("Security Sell"));
+	} else if(trans->toAccount() == budget->balancingAccount || trans->fromAccount() == budget->balancingAccount) {
+		setText(0, i18n("Balancing"));
+	} else {
+		setText(0, i18n("Transfer"));
+	}
+}
 
-EditSplitDialog::EditSplitDialog(Budget *budg, QWidget *parent, AssetsAccount *default_account, bool extra_parameters) : KDialogBase(parent, 0, true, i18n("Split Transaction"), Ok | Cancel, Ok, true), budget(budg), b_extra(extra_parameters) {
+EditSplitDialog::EditSplitDialog(Budget *budg, QWidget *parent, AssetsAccount *default_account, bool extra_parameters) : KDialog(parent, 0), budget(budg), b_extra(extra_parameters) {
 
+	setCaption(i18n("Split Transaction"));	
+	setButtons(KDialog::Ok | KDialog::Cancel);
+	setDefaultButton(KDialog::Cancel);
+	setModal(true);
+		
 	setMainWidget(new QWidget(this));
 
-	QVBoxLayout *box1 = new QVBoxLayout(mainWidget(), 0, spacingHint());
+	QVBoxLayout *box1 = new QVBoxLayout(mainWidget());
 
-	QGridLayout *grid = new QGridLayout(box1, 3, 2);
+	QGridLayout *grid = new QGridLayout();
+	box1->addLayout(grid);
 
 	grid->addWidget(new QLabel(i18n("Description:"), mainWidget()), 0, 0);
 	descriptionEdit = new KLineEdit(mainWidget());
@@ -73,6 +142,7 @@ EditSplitDialog::EditSplitDialog(Budget *budg, QWidget *parent, AssetsAccount *d
 	
 	grid->addWidget(new QLabel(i18n("Date:"), mainWidget()), 1, 0);
 	dateEdit = new KDateEdit(mainWidget());
+	dateEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	grid->addWidget(dateEdit, 1, 1);
 	
 	grid->addWidget(new QLabel(i18n("Account:"), mainWidget()), 2, 0);
@@ -82,8 +152,8 @@ EditSplitDialog::EditSplitDialog(Budget *budg, QWidget *parent, AssetsAccount *d
 	AssetsAccount *account = budget->assetsAccounts.first();
 	while(account) {
 		if(account != budget->balancingAccount && account->accountType() != ASSETS_TYPE_SECURITIES) {
-			accountCombo->insertItem(account->name());
-			if(account == default_account) accountCombo->setCurrentItem(i);
+			accountCombo->addItem(account->name());
+			if(account == default_account) accountCombo->setCurrentIndex(i);
 			i++;
 		}
 		account = budget->assetsAccounts.next();
@@ -91,47 +161,44 @@ EditSplitDialog::EditSplitDialog(Budget *budg, QWidget *parent, AssetsAccount *d
 	grid->addWidget(accountCombo, 2, 1);
 		
 	box1->addWidget(new QLabel(i18n("Transactions:"), mainWidget()));
-	QHBoxLayout *box2 = new QHBoxLayout(box1);
-	transactionsView = new KListView(mainWidget());
-	transactionsView->addColumn(i18n("Type"));
-	transactionsView->addColumn(i18n("Description"));
-	transactionsView->addColumn(i18n("Account/Category"));
-	transactionsView->addColumn(i18n("Payment"));
-	transactionsView->addColumn(i18n("Deposit"));
-	transactionsView->setRootIsDecorated(false);
+	QHBoxLayout *box2 = new QHBoxLayout();
+	box1->addLayout(box2);
+	transactionsView = new EqonomizeTreeWidget(mainWidget());
+	transactionsView->setSortingEnabled(true);
+	transactionsView->sortByColumn(0, Qt::AscendingOrder);
 	transactionsView->setAllColumnsShowFocus(true);
-	transactionsView->setSorting(0);
-	transactionsView->setColumnAlignment(3, Qt::AlignRight);
-	transactionsView->setColumnAlignment(4, Qt::AlignRight);
+	transactionsView->setColumnCount(5);
+	QStringList headers;
+	headers << i18n("Type");
+	headers << i18n("Description");
+	headers << i18n("Account/Category");	
+	headers << i18n("Payment");
+	headers << i18n("Deposit");	
+	transactionsView->setHeaderLabels(headers);
+	transactionsView->setRootIsDecorated(false);
 	box2->addWidget(transactionsView);
-	KButtonBox *buttons = new KButtonBox(mainWidget(), KButtonBox::Vertical);
-	QPushButton *newButton = buttons->addButton(i18n("New"));
-	QPopupMenu *newMenu = new QPopupMenu(this);
-	newButton->setPopup(newMenu);
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("New Expense..."), this, SLOT(newExpense()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("New Income..."), this, SLOT(newIncome()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("New Deposit..."), this, SLOT(newTransferTo()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("New Withdrawal..."), this, SLOT(newTransferFrom()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("Security Shares Bought..."), this, SLOT(newSecurityBuy()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("Security Shares Sold..."), this, SLOT(newSecuritySell()));
-	newMenu->insertItem(kapp->iconLoader()->loadIconSet("filenew", KIcon::Small), i18n("New Dividend..."), this, SLOT(newDividend()));
-	editButton = buttons->addButton(i18n("Edit..."));
+	KDialogButtonBox *buttons = new KDialogButtonBox(mainWidget(), Qt::Vertical);
+	QPushButton *newButton = buttons->addButton(i18n("New"), QDialogButtonBox::ActionRole);
+	QMenu *newMenu = new QMenu(this);
+	newButton->setMenu(newMenu);
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Expense...")), SIGNAL(triggered()), this, SLOT(newExpense()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Income...")), SIGNAL(triggered()), this, SLOT(newIncome()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Deposit...")), SIGNAL(triggered()), this, SLOT(newTransferTo()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Withdrawal...")), SIGNAL(triggered()), this, SLOT(newTransferFrom()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Security Shares Bought...")), SIGNAL(triggered()), this, SLOT(newSecurityBuy()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("Security Shares Sold...")), SIGNAL(triggered()), this, SLOT(newSecuritySell()));
+	connect(newMenu->addAction(KIcon("document-new"), i18n("New Dividend...")), SIGNAL(triggered()), this, SLOT(newDividend()));
+	editButton = buttons->addButton(i18n("Edit..."), QDialogButtonBox::ActionRole);
 	editButton->setEnabled(false);
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 3
-	removeButton = buttons->addButton(KStdGuiItem::guiItem(KStdGuiItem::Delete));
-#else
-	removeButton = buttons->addButton(i18n("Delete"));
-#endif
+	removeButton = buttons->addButton(KStandardGuiItem::guiItem(KStandardGuiItem::Delete), QDialogButtonBox::ActionRole);
 	removeButton->setEnabled(false);
 	box2->addWidget(buttons);
-	buttons->addStretch();
-	buttons->layout();	
 	totalLabel = new QLabel(mainWidget());
 	updateTotalValue();
 	box1->addWidget(totalLabel);
 	
-	connect(transactionsView, SIGNAL(selectionChanged()), this, SLOT(transactionSelectionChanged()));
-	connect(transactionsView, SIGNAL(doubleClicked(QListViewItem*, const QPoint&, int)), this, SLOT(edit(QListViewItem*)));
+	connect(transactionsView, SIGNAL(itemSelectionChanged()), this, SLOT(transactionSelectionChanged()));
+	connect(transactionsView, SIGNAL(doubleClicked(QTreeWidgetItem*, int)), this, SLOT(edit(QTreeWidgetItem*)));
 	connect(removeButton, SIGNAL(clicked()), this, SLOT(remove()));
 	connect(editButton, SIGNAL(clicked()), this, SLOT(edit()));
 
@@ -140,20 +207,22 @@ EditSplitDialog::~EditSplitDialog() {}
 
 void EditSplitDialog::updateTotalValue() {
 	double total_value = 0.0;
-	QListViewItem *i = transactionsView->firstChild();
+	QTreeWidgetItemIterator it(transactionsView);
+	QTreeWidgetItem *i = *it;
 	while(i) {
 		Transaction *trans = ((SplitListViewItem*) i)->transaction();
 		if(trans) {
 			if(trans->fromAccount()) total_value += trans->value();
 			else total_value -= trans->value();
 		}
-		i = i->nextSibling();
+		++it;
+		i = *it;
 	}
 	totalLabel->setText(QString("<div align=\"left\"><b>%1</b> %2</div>").arg(i18n("Total value:")).arg(KGlobal::locale()->formatMoney(total_value)));
 }
 AssetsAccount *EditSplitDialog::selectedAccount() {
 	int index = 0;
-	int cur_index = accountCombo->currentItem();
+	int cur_index = accountCombo->currentIndex();
 	AssetsAccount *account = budget->assetsAccounts.first();
 	while(account) {
 		if(account != budget->balancingAccount && account->accountType() != ASSETS_TYPE_SECURITIES) {
@@ -167,7 +236,9 @@ AssetsAccount *EditSplitDialog::selectedAccount() {
 	return account;
 }
 void EditSplitDialog::transactionSelectionChanged() {
-	SplitListViewItem *i = (SplitListViewItem*) transactionsView->selectedItem();
+	QList<QTreeWidgetItem*> list = transactionsView->selectedItems();
+	SplitListViewItem *i = NULL;
+	if(!list.isEmpty()) i = (SplitListViewItem*) list.first();
 	editButton->setEnabled(i && i->transaction());
 	removeButton->setEnabled(i && i->transaction());
 }
@@ -205,8 +276,9 @@ void EditSplitDialog::newTransferTo() {
 	newTransaction(TRANSACTION_TYPE_TRANSFER, false, true, selectedAccount());
 }
 void EditSplitDialog::remove() {
-	SplitListViewItem *i = (SplitListViewItem*) transactionsView->selectedItem();
-	if(i == NULL) return;
+	QList<QTreeWidgetItem*> list = transactionsView->selectedItems();
+	if(list.isEmpty()) return;
+	SplitListViewItem *i = (SplitListViewItem*) list.first();
 	if(i->transaction()) {		
 		delete i->transaction();
 	}
@@ -214,9 +286,11 @@ void EditSplitDialog::remove() {
 	updateTotalValue();
 }
 void EditSplitDialog::edit() {
-	edit(transactionsView->selectedItem());
+	QList<QTreeWidgetItem*> list = transactionsView->selectedItems();
+	if(list.isEmpty()) return;
+	edit(list.first());
 }
-void EditSplitDialog::edit(QListViewItem *i_pre) {
+void EditSplitDialog::edit(QTreeWidgetItem *i_pre) {
 	if(i_pre == NULL) return;
 	SplitListViewItem *i = (SplitListViewItem*) i_pre;
 	Transaction *trans = i->transaction();
@@ -233,28 +307,7 @@ void EditSplitDialog::edit(QListViewItem *i_pre) {
 		dialog->editWidget->setTransaction(trans);
 		if(dialog->exec() == QDialog::Accepted) {
 			if(dialog->editWidget->modifyTransaction(trans)) {
-				double value = trans->value();
-				bool deposit = (trans->toAccount() == NULL);
-				i->setText(1, trans->description());
-				i->setText(2, deposit ? trans->fromAccount()->name() : trans->toAccount()->name());
-				i->setText(3, (deposit && value >= 0.0) ? QString::null : KGlobal::locale()->formatMoney(value < 0.0 ? -value : value));
-				i->setText(4, (deposit && value >= 0.0) ? KGlobal::locale()->formatMoney(value < 0.0 ? -value : value) : QString::null);
-				if(trans->type() == TRANSACTION_TYPE_INCOME) {
-					if(((Income*) trans)->security()) i->setText(0, i18n("Dividend"));
-					else if(value >= 0) i->setText(0, i18n("Income"));
-					else i->setText(0, i18n("Repayment"));
-				} else if(trans->type() == TRANSACTION_TYPE_EXPENSE) {
-					if(value >= 0) i->setText(0, i18n("Expense"));
-					else i->setText(0, i18n("Refund"));
-				} else if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) {
-					i->setText(0, i18n("Security Buy"));
-				} else if(trans->type() == TRANSACTION_TYPE_SECURITY_SELL) {
-					i->setText(0, i18n("Security Sell"));
-				} else if(trans->toAccount() == budget->balancingAccount || trans->fromAccount() == budget->balancingAccount) {
-					i->setText(0, i18n("Balancing"));
-				} else {
-					i->setText(0, i18n("Transfer"));
-				}
+				i->setTransaction(trans, trans->toAccount() == NULL);				
 			}
 			updateTotalValue();
 		}
@@ -265,11 +318,13 @@ SplitTransaction *EditSplitDialog::createSplitTransaction() {
 	if(!validValues()) return NULL;
 	AssetsAccount *account = selectedAccount();
 	SplitTransaction *split = new SplitTransaction(budget, dateEdit->date(), account, descriptionEdit->text());
-	QListViewItem *i = transactionsView->firstChild();
+	QTreeWidgetItemIterator it(transactionsView);
+	QTreeWidgetItem *i = *it;
 	while(i) {
 		Transaction *trans = ((SplitListViewItem*) i)->transaction();
 		if(trans) split->addTransaction(trans);
-		i = i->nextSibling();
+		++it;
+		i = *it;
 	}
 	return split;
 }
@@ -281,7 +336,7 @@ void EditSplitDialog::setSplitTransaction(SplitTransaction *split) {
 	while(account) {
 		if(account != budget->balancingAccount && account->accountType() != ASSETS_TYPE_SECURITIES) {
 			if(account == split->account()) {
-				accountCombo->setCurrentItem(index);
+				accountCombo->setCurrentIndex(index);
 				break;
 			}
 			index++;
@@ -289,11 +344,12 @@ void EditSplitDialog::setSplitTransaction(SplitTransaction *split) {
 		account = budget->assetsAccounts.next();
 	}
 	transactionsView->clear();
-	QValueVector<Transaction*>::size_type c = split->splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QList<QTreeWidgetItem *> items;
+	QVector<Transaction*>::size_type c = split->splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		Transaction *trans = split->splits[i]->copy();
 		trans->setDate(QDate());
-		appendTransaction(trans, (trans->toAccount() == split->account()));
+		items.append(new SplitListViewItem(trans, (trans->toAccount() == split->account())));
 		switch(trans->type()) {
 			case TRANSACTION_TYPE_EXPENSE: {
 				((Expense*) trans)->setFrom(NULL);
@@ -318,42 +374,29 @@ void EditSplitDialog::setSplitTransaction(SplitTransaction *split) {
 			}
 		}		
 	}
+	transactionsView->addTopLevelItems(items);
 	updateTotalValue();
+	transactionsView->setSortingEnabled(true);
 }
 void EditSplitDialog::appendTransaction(Transaction *trans, bool deposit) {
-	double value = trans->value();
-	SplitListViewItem *i = new SplitListViewItem(trans, transactionsView, QString::null, trans->description(), deposit ? trans->fromAccount()->name() : trans->toAccount()->name(), (deposit && value >= 0.0) ? QString::null : KGlobal::locale()->formatMoney(value < 0.0 ? -value : value), (deposit && value >= 0.0) ? KGlobal::locale()->formatMoney(value < 0.0 ? -value : value) : QString::null);
-	if(trans->type() == TRANSACTION_TYPE_INCOME) {
-		if(((Income*) trans)->security()) i->setText(0, i18n("Dividend"));
-		else if(value >= 0) i->setText(0, i18n("Income"));
-		else i->setText(0, i18n("Repayment"));
-	} else if(trans->type() == TRANSACTION_TYPE_EXPENSE) {
-		if(value >= 0) i->setText(0, i18n("Expense"));
-		else i->setText(0, i18n("Refund"));
-	} else if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) {
-		i->setText(0, i18n("Security Buy"));
-	} else if(trans->type() == TRANSACTION_TYPE_SECURITY_SELL) {
-		i->setText(0, i18n("Security Sell"));
-	} else if(trans->toAccount() == budget->balancingAccount || trans->fromAccount() == budget->balancingAccount) {
-		i->setText(0, i18n("Balancing"));
-	} else {
-		i->setText(0, i18n("Transfer"));
-	}
+	SplitListViewItem *i = new SplitListViewItem(trans, deposit);
+	transactionsView->insertTopLevelItem(transactionsView->topLevelItemCount(), i);
+	transactionsView->setSortingEnabled(true);
 }
 
-void EditSplitDialog::slotOk() {
-	if(validValues()) {
-		KDialogBase::slotOk();
+void EditSplitDialog::slotButtonClicked(int button) {
+	if(button == KDialog::Ok && !validValues()) return;
+	if(button == KDialog::Cancel) {
+		QTreeWidgetItemIterator it(transactionsView);
+		QTreeWidgetItem *i = *it;
+		while(i) {
+			Transaction *trans = ((SplitListViewItem*) i)->transaction();
+			if(trans) delete trans;
+			++it;
+			i = *it;
+		}
 	}
-}
-void EditSplitDialog::slotCancel() {
-	QListViewItem *i = transactionsView->firstChild();
-	while(i) {
-		Transaction *trans = ((SplitListViewItem*) i)->transaction();
-		if(trans) delete trans;
-		i = i->nextSibling();
-	}
-	KDialogBase::slotCancel();
+	KDialog::slotButtonClicked(button);
 }
 bool EditSplitDialog::checkAccounts() {
 	if(accountCombo->count() == 0) {
@@ -372,19 +415,21 @@ bool EditSplitDialog::validValues() {
 		KMessageBox::error(this, i18n("Future dates is not allowed."));
 		return false;
 	}
-	if(transactionsView->childCount() < 2) {
+	if(transactionsView->topLevelItemCount() < 2) {
 		KMessageBox::error(this, i18n("A split must contain at least two transactions."));
 		return false;
 	}
 	AssetsAccount *account = selectedAccount();
-	QListViewItem *i = transactionsView->firstChild();
+	QTreeWidgetItemIterator it(transactionsView);
+	QTreeWidgetItem *i = *it;
 	while(i) {
 		Transaction *trans = ((SplitListViewItem*) i)->transaction();
 		if(trans && (trans->fromAccount() == account || trans->toAccount() == account)) {
 			KMessageBox::error(this, i18n("Cannot transfer money to and from the same account."));
 			return false;
 		}
-		i = i->nextSibling();
+		++it;
+		i = *it;
 	}	
 	return true;
 }
