@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,7 @@
 #ifndef EDIT_SPLIT_DIALOG_H
 #define EDIT_SPLIT_DIALOG_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
 class Budget;
 class Transaction;
@@ -34,8 +34,10 @@ class KDateEdit;
 class KComboBox;
 class QPushButton;
 class QLabel;
+class QTreeWidget;
+class QTreeWidgetItem;
 
-class EditSplitDialog : public KDialogBase {
+class EditSplitDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -47,7 +49,7 @@ class EditSplitDialog : public KDialogBase {
 		KDateEdit *dateEdit;
 		KComboBox *accountCombo;
 		KLineEdit *descriptionEdit;
-		KListView *transactionsView;
+		QTreeWidget *transactionsView;
 		QPushButton *editButton, *removeButton;
 		QLabel *totalLabel;
 
@@ -68,11 +70,10 @@ class EditSplitDialog : public KDialogBase {
 
 	protected slots:
 		
-		void slotOk();
-		void slotCancel();
+		void slotButtonClicked(int);
 		void remove();
 		void edit();
-		void edit(QListViewItem*);
+		void edit(QTreeWidgetItem*);
 		void transactionSelectionChanged();
 		void newExpense();
 		void newIncome();
