@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,13 +23,20 @@
 #define EQONOMIZE_H
 
 #include <kapplication.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kurl.h>
-#include <qvaluevector.h>
+#include <qvector.h>
 #include <qmap.h>
 #include <qdatetime.h>
-#include <kdialogbase.h>
+#include <QLabel>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <kdialog.h>
 #include <qtextstream.h>
+#include <QModelIndex>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
+#include <QWizardPage>
 
 class Budget;
 class Transaction;
@@ -45,16 +52,17 @@ class KComboBox;
 class QPushButton;
 class QLabel;
 class QCheckBox;
-class KJanusWidget;
+class KPageWidget;
+class KPageWidgetItem;
 class QRadioButton;
 class TransactionListWidget;
 class KAction;
+class QAction;
 class KSelectAction;
 class KToggleAction;
 class KRecentFilesAction;
-class QPopupMenu;
-class KListView;
-class QListViewItem;
+class QMenu;
+class KMenu;
 class Expense;
 class Income;
 class Transfer;
@@ -67,8 +75,9 @@ class SecurityTrade;
 class QSpinBox;
 class QTabWidget;
 class EqonomizeMonthSelector;
-class QVBoxLayout;
 class KToolBar;
+class QVBoxLayout;
+class KAutoSaveFile;
 
 typedef enum {
 	INITIAL_PERIOD_CURRENT_MONTH,
@@ -78,7 +87,7 @@ typedef enum {
 	INITIAL_PERIOD_LAST
 } InitialPeriod;
 
-class Eqonomize : public KMainWindow {
+class Eqonomize : public KXmlGuiWindow {
 	
 	Q_OBJECT
 
@@ -87,7 +96,7 @@ class Eqonomize : public KMainWindow {
 		Eqonomize();
 		virtual ~Eqonomize();
 		
-		bool saveURL(const KURL& url);
+		bool saveURL(const KUrl& url);
 		bool askSave(bool before_exit = false);
 		void createDefaultBudget();
 		void readFileDependentOptions();
@@ -135,10 +144,10 @@ class Eqonomize : public KMainWindow {
 		bool exportScheduleList(QTextStream &outf, int fileformat);
 		bool exportAccountsList(QTextStream &outf, int fileformat);
 		bool exportSecuritiesList(QTextStream &outf, int fileformat);
-		void editSecurity(QListViewItem *i);
+		void editSecurity(QTreeWidgetItem *i);
 		void appendSecurity(Security *security);
 		void updateSecurity(Security *security);
-		void updateSecurity(QListViewItem *i);
+		void updateSecurity(QTreeWidgetItem *i);
 		void updateSecurityAccount(AssetsAccount *account, bool update_display = true);
 		bool editReinvestedDividend(ReinvestedDividend *rediv, Security *security, QWidget *parent);
 		void editReinvestedDividend(ReinvestedDividend *rediv, Security *security);
@@ -149,9 +158,12 @@ class Eqonomize : public KMainWindow {
 		void showIncomes();
 		void showTransfers();
 		void updateSecuritiesStatistics();
-		bool crashRecovery(KURL url);
+		bool crashRecovery(KUrl url);
 		bool newRefundRepayment(Transaction *trans);
+		void readOptions();
 
+		QAction *ActionAP_1, *ActionAP_2, *ActionAP_3, *ActionAP_4, *ActionAP_5, *ActionAP_6, *ActionAP_7, *ActionAP_8;
+		KAction *ActionEditSchedule, *ActionEditOccurrence, *ActionDeleteSchedule, *ActionDeleteOccurrence;
 		KAction *ActionAddAccount, *ActionNewAssetsAccount, *ActionNewIncomesAccount, *ActionNewExpensesAccount, *ActionEditAccount, *ActionDeleteAccount, *ActionBalanceAccount;
 		KAction *ActionShowAccountTransactions;
 		KAction *ActionNewExpense, *ActionNewIncome, *ActionNewTransfer, *ActionNewSplitTransaction;
@@ -166,43 +178,40 @@ class Eqonomize : public KMainWindow {
 		KSelectAction *ActionSelectInitialPeriod;
 		KToggleAction *ActionExtraProperties;
 		KRecentFilesAction *ActionOpenRecent;
-
+		
 	protected:
 
 		void setupActions();
 		void saveOptions();
-		void readOptions();
 		bool queryClose();
 		bool queryExit();
-		void saveProperties(KConfig*);
-		void readProperties(KConfig*);
+		
 		void dragEnterEvent(QDragEnterEvent *event);
 		void dropEvent(QDropEvent *event);
 
-		KConfig *config;
-		KURL current_url;
+		KUrl current_url;
 		double period_months, from_to_months;
 		bool modified, modified_auto_save, auto_save_timeout;
 		QDate from_date, to_date, frommonth_begin, prevmonth_begin;
 		QDate securities_from_date, securities_to_date;
 		QDate prev_cur_date;
-		int current_page;
 		bool partial_budget;
 		bool b_extra;
-		QString cr_tmp_file;
+		KAutoSaveFile *cr_tmp_file;
 
 		KToolBar *scheduleButtons, *securitiesButtons;
-		KJanusWidget *tabs;
+		KPageWidget *tabs;
 		QTabWidget *accountsTabs;
 		QCheckBox *budgetButton;
 		EqonomizeValueEdit *budgetEdit;
 		EqonomizeMonthSelector *budgetMonthEdit;
 		QLabel *prevMonthBudgetLabel;
 		QWidget *accounts_page, *expenses_page, *incomes_page, *transfers_page, *securities_page, *schedule_page;
+		KPageWidgetItem *accounts_page_item, *expenses_page_item, *incomes_page_item, *transfers_page_item, *securities_page_item, *schedule_page_item;
 		QVBoxLayout *expensesLayout, *incomesLayout, *transfersLayout;
 		TransactionListWidget *expensesWidget, *incomesWidget, *transfersWidget;
-		KListView *accountsView, *securitiesView, *scheduleView;
-		QListViewItem *assetsItem, *incomesItem, *expensesItem;
+		QTreeWidget *accountsView, *securitiesView, *scheduleView;
+		QTreeWidgetItem *assetsItem, *incomesItem, *expensesItem;
 		QCheckBox *accountsPeriodFromButton;
 		KDateEdit *accountsPeriodFromEdit, *accountsPeriodToEdit;
 		QCheckBox *partialBudgetButton;
@@ -210,7 +219,7 @@ class Eqonomize : public KMainWindow {
 		QCheckBox *securitiesPeriodFromButton;
 		KDateEdit *securitiesPeriodFromEdit, *securitiesPeriodToEdit;
 		QPushButton *newScheduleButton, *editScheduleButton, *removeScheduleButton;
-		QPopupMenu *editScheduleMenu, *removeScheduleMenu;
+		QMenu *editScheduleMenu, *removeScheduleMenu;
 		QPushButton *newSecurityTransactionButton, *newSecurityButton, *setQuotationButton;
 		QLabel *securitiesStatLabel;
 		QLabel *footer1;
@@ -229,10 +238,10 @@ class Eqonomize : public KMainWindow {
 		QMap<Account*, double> account_budget_diff;
 		QMap<Account*, double> account_future_diff;
 		QMap<Account*, double> account_future_diff_change;
-		QMap<QListViewItem*, Account*> account_items;
-		QMap<Account*, QListViewItem*> item_accounts;
+		QMap<QTreeWidgetItem*, Account*> account_items;
+		QMap<Account*, QTreeWidgetItem*> item_accounts;
 
-		QPopupMenu *accountPopupMenu, *securitiesPopupMenu, *schedulePopupMenu;
+		QMenu *accountPopupMenu, *securitiesPopupMenu, *schedulePopupMenu;
 
 	public slots:
 
@@ -258,6 +267,7 @@ class Eqonomize : public KMainWindow {
 		void categoriesComparisonChartClosed();
 		void printView();
 		void saveView();
+		void ledgerClosed();
 
 		void newSecurity();
 		void editSecurity();
@@ -271,9 +281,9 @@ class Eqonomize : public KMainWindow {
 		void editQuotations();
 		void editSecurityTransactions();
 		void securitiesSelectionChanged();
-		void securitiesExecuted(QListViewItem*);
-		void securitiesExecuted(QListViewItem*, const QPoint&, int);
-		void popupSecuritiesMenu(KListView*, QListViewItem*, const QPoint&);
+		void securitiesExecuted(QTreeWidgetItem*);
+		void securitiesExecuted(QTreeWidgetItem*, int);
+		void popupSecuritiesMenu(const QPoint&);
 		void updateSecurities();
 		
 		void newSplitTransaction();
@@ -285,8 +295,8 @@ class Eqonomize : public KMainWindow {
 		void removeScheduledTransaction();
 		void removeOccurrence();
 		void scheduleSelectionChanged();
-		void scheduleExecuted(QListViewItem*);
-		void popupScheduleMenu(KListView*, QListViewItem*, const QPoint&);
+		void scheduleExecuted(QTreeWidgetItem*);
+		void popupScheduleMenu(const QPoint&);
 
 		void editSelectedScheduledTransaction();
 		void editSelectedTransaction();
@@ -301,17 +311,17 @@ class Eqonomize : public KMainWindow {
 		void newRepayment();
 		void newRefundRepayment();
 
-		void checkForPageChange();
+		void onPageChange(KPageWidgetItem*, KPageWidgetItem*);
 		void onPageChange(QWidget*);
 
 		void showAccountTransactions(bool = false);
 
 		void updateTransactionActions();
 		
-		void openURL(const KURL&);
+		void openURL(const KUrl&);
 		void fileNew();
 		void fileOpen();
-		void fileOpenRecent(const KURL&);
+		void fileOpenRecent(const KUrl&);
 		void fileReload();
 		void fileSave();
 		void fileSaveAs();
@@ -321,14 +331,14 @@ class Eqonomize : public KMainWindow {
 
 		void checkDate();
 
-		void popupAccountsMenu(KListView*, QListViewItem*, const QPoint&);
+		void popupAccountsMenu(const QPoint&);
 
 		void addAccount();
 		void newAssetsAccount();
 		void newIncomesAccount();
 		void newExpensesAccount();
-		void accountExecuted(QListViewItem*, const QPoint&, int);
-		void accountExecuted(QListViewItem*);
+		void accountExecuted(QTreeWidgetItem*, int);
+		void accountExecuted(QTreeWidgetItem*);
 		void balanceAccount();
 		void editAccount();
 		void deleteAccount();
@@ -344,7 +354,7 @@ class Eqonomize : public KMainWindow {
 		
 		void accountsPeriodFromChanged(const QDate&);
 		void accountsPeriodToChanged(const QDate&);
-		void periodSelected(int);
+		void periodSelected(QAction*);
 		void prevMonth();
 		void nextMonth();
 		void currentMonth();
@@ -384,17 +394,18 @@ class Eqonomize : public KMainWindow {
 
 };
 
-class ConfirmScheduleDialog : public KDialogBase {
+class ConfirmScheduleDialog : public KDialog {
 	
 	Q_OBJECT
 	
 	protected:
 
-		KListView *transactionsView;
+		QTreeWidget *transactionsView;
 		Budget *budget;
 		bool b_extra;
 		QPushButton *editButton, *removeButton, *postponeButton;
 		ConfirmScheduleListViewItem *current_item;
+		int current_index;
 		
 	public:
 		
@@ -413,7 +424,7 @@ class ConfirmScheduleDialog : public KDialogBase {
 		
 };
 
-class EditAssetsAccountDialog : public KDialogBase {
+class EditAssetsAccountDialog : public KDialog {
 
 	Q_OBJECT
 	
@@ -438,11 +449,11 @@ class EditAssetsAccountDialog : public KDialogBase {
 	protected slots:
 
 		void typeActivated(int);
-		void slotOk();
+		void slotButtonClicked(int);
 		
 };
 
-class EditExpensesAccountDialog : public KDialogBase {
+class EditExpensesAccountDialog : public KDialog {
 
 	Q_OBJECT
 	
@@ -465,11 +476,11 @@ class EditExpensesAccountDialog : public KDialogBase {
 	protected slots:
 
 		void budgetEnabled(bool);
-		void slotOk();
+		void slotButtonClicked(int);
 		
 };
 
-class EditIncomesAccountDialog : public KDialogBase {
+class EditIncomesAccountDialog : public KDialog {
 
 	Q_OBJECT
 	
@@ -492,11 +503,11 @@ class EditIncomesAccountDialog : public KDialogBase {
 	protected slots:
 
 		void budgetEnabled(bool);
-		void slotOk();
+		void slotButtonClicked(int);
 		
 };
 
-class EditSecurityDialog : public KDialogBase {
+class EditSecurityDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -510,7 +521,7 @@ class EditSecurityDialog : public KDialogBase {
 		QSpinBox *decimalsEdit;
 		QLabel *quotationLabel, *quotationDateLabel;
 		Budget *budget;
-		QValueVector<AssetsAccount*> accounts;
+		QVector<AssetsAccount*> accounts;
 
 	public:
 		
@@ -526,14 +537,14 @@ class EditSecurityDialog : public KDialogBase {
 
 };
  
-class EditQuotationsDialog : public KDialogBase {
+class EditQuotationsDialog : public KDialog {
 
 	Q_OBJECT
 
 	protected:
 
 		QLabel *titleLabel;
-		KListView *quotationsView;
+		QTreeWidget *quotationsView;
 		EqonomizeValueEdit *quotationEdit;
 		KDateEdit *dateEdit;
 		QPushButton *changeButton, *addButton, *deleteButton;
@@ -554,7 +565,7 @@ class EditQuotationsDialog : public KDialogBase {
 
 };
 
-class RefundDialog : public KDialogBase {
+class RefundDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -575,11 +586,11 @@ class RefundDialog : public KDialogBase {
 
 	protected slots:
 		
-		void slotOk();
+		void slotButtonClicked(int);
 
 };
 
-class EditReinvestedDividendDialog : public KDialogBase {
+class EditReinvestedDividendDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -603,11 +614,11 @@ class EditReinvestedDividendDialog : public KDialogBase {
 
 	protected slots:
 		
-		void slotOk();
+		void slotButtonClicked(int);
 
 };
 
-class EditSecurityTradeDialog : public KDialogBase {
+class EditSecurityTradeDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -629,7 +640,7 @@ class EditSecurityTradeDialog : public KDialogBase {
 
 	protected slots:
 		
-		void slotOk();
+		void slotButtonClicked(int);
 		void maxShares();
 		Security *selectedFromSecurity();
 		Security *selectedToSecurity();
@@ -638,7 +649,7 @@ class EditSecurityTradeDialog : public KDialogBase {
 
 };
 
-class SecurityTransactionsDialog : public KDialogBase {
+class SecurityTransactionsDialog : public KDialog {
 	
 	Q_OBJECT
 	
@@ -646,7 +657,7 @@ class SecurityTransactionsDialog : public KDialogBase {
 
 		Security *security;
 		Eqonomize *mainWin;
-		KListView *transactionsView;
+		QTreeWidget *transactionsView;
 		QPushButton *editButton, *removeButton;
 
 		void updateTransactions();
@@ -659,10 +670,40 @@ class SecurityTransactionsDialog : public KDialogBase {
 		
 		void remove();
 		void edit();
-		void edit(QListViewItem*);
+		void edit(QTreeWidgetItem*);
 		void transactionSelectionChanged();
 		
 };
 
+class EqonomizeTreeWidget : public QTreeWidget {
+
+	Q_OBJECT
+	
+	public:
+	
+		EqonomizeTreeWidget(QWidget *parent);
+		EqonomizeTreeWidget();
+
+	protected slots:
+	
+		void keyPressEvent(QKeyEvent*);
+		void onDoubleClick(const QModelIndex&);
+
+	signals:
+	
+		void returnPressed(QTreeWidgetItem*);
+		void doubleClicked(QTreeWidgetItem*, int);
+		 
+};
+
+class QIFWizardPage : public QWizardPage {
+	protected:
+		bool is_complete;
+	public:		
+		QIFWizardPage();
+		bool isComplete() const;
+		void setComplete(bool b);
+};
+
 #endif
 
