@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,6 +26,7 @@
 
 #include <qobject.h>
 #include <qlayout.h>
+#include <QHBoxLayout>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kcalendarsystem.h>
@@ -36,15 +37,17 @@ EqonomizeMonthSelector::EqonomizeMonthSelector(QWidget *parent) : QWidget(parent
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	d_date = QDate::currentDate();
 	calSys->setYMD(d_date, calSys->year(d_date), calSys->month(d_date), 1);
-	QHBoxLayout *layout = new QHBoxLayout(this, 0, 6);
+	QHBoxLayout *layout = new QHBoxLayout(this);
+	layout->setContentsMargins(0, 0, 0, 0);
 	monthCombo = new KComboBox(this);
 	monthCombo->setEditable(false);
 	layout->addWidget(monthCombo);
-	yearEdit = new QSpinBox(calSys->minValidYear(), calSys->maxValidYear(), 1, this);
+	yearEdit = new QSpinBox(this);
+	yearEdit->setRange(0, 4000);
 	yearEdit->setValue(calSys->year(d_date));
 	layout->addWidget(yearEdit);
 	updateMonths();
-	monthCombo->setCurrentItem(calSys->month(d_date) - 1);
+	monthCombo->setCurrentIndex(calSys->month(d_date) - 1);
 	connect(yearEdit, SIGNAL(valueChanged(int)), this, SLOT(onYearChanged(int)));
 	connect(monthCombo, SIGNAL(activated(int)), this, SLOT(onMonthChanged(int)));
 }
@@ -75,7 +78,7 @@ void EqonomizeMonthSelector::setDate(const QDate &newdate) {
 		yearEdit->blockSignals(false);
 		monthCombo->blockSignals(true);
 		updateMonths();
-		monthCombo->setCurrentItem(calSys->month(d_date) - 1);
+		monthCombo->setCurrentIndex(calSys->month(d_date) - 1);
 		monthCombo->blockSignals(false);
 	}
 }
@@ -88,9 +91,9 @@ void EqonomizeMonthSelector::updateMonths() {
 	if(monthCombo->count() != 12 || KGlobal::locale()->calendarType() != "gregorian") {
 		monthCombo->clear();
 		for(int i = 1; i <= months; i++) {
-			monthCombo->insertItem(calSys->monthName(i, year));
+			monthCombo->addItem(calSys->monthName(i, year));
 		}
-		monthCombo->setCurrentItem(calSys->month(d_date) - 1);
+		monthCombo->setCurrentIndex(calSys->month(d_date) - 1);
 	}
 	monthCombo->blockSignals(false);
 }
