@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,14 +26,20 @@
 #include "budget.h"
 #include "kdateedit.h"
 #include "eqonomizevalueedit.h"
+#include "eqonomize.h"
 
+#include <time.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <qlayout.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <QButtonGroup>
 #include <qlabel.h>
 #include <qspinbox.h>
+#include <QTextStream>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QVBoxLayout>
 #include <knuminput.h>
 #include <klineedit.h>
 #include <kcombobox.h>
@@ -42,76 +48,96 @@
 #include <qdatetime.h>
 #include <qcheckbox.h>
 #include <kio/netaccess.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <qmap.h>
 
 #include <math.h>
 
 #define ALL_TYPES_ID		5
 
-ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent, 0, true), budget(budg) {
+ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : QWizard(parent), budget(budg) {
 
-	setCaption(i18n("Import CSV file"));
+	setWindowTitle(i18n("Import CSV file"));
+	setModal(true);
 
-	QWidget *page1 = new QWidget(this);
-	addPage(page1, i18n("Transaction Type Selection"));
-	QVBoxLayout *layout1 = new QVBoxLayout(page1, 6, 6);
-	typeGroup = new QButtonGroup(6, Qt::Vertical, page1);
-	new QRadioButton(i18n("Expenses"), typeGroup);
-	new QRadioButton(i18n("Incomes"), typeGroup);
-	new QRadioButton(i18n("Transfers"), typeGroup);
-	new QRadioButton(i18n("Expenses and incomes (negative cost)"), typeGroup);
-	new QRadioButton(i18n("Expenses and incomes (separate columns)"), typeGroup);
-	new QRadioButton(i18n("All types"), typeGroup);
-	layout1->addWidget(typeGroup);
+	QIFWizardPage *page1 = new QIFWizardPage();
+	page1->setTitle(i18n("Transaction Type Selection"));
+	setPage(0, page1);
+	QVBoxLayout *layout1 = new QVBoxLayout(page1);
+	typeGroup = new QButtonGroup(this);
+	QVBoxLayout *typeGroup_layout = new QVBoxLayout();
+	layout1->addLayout(typeGroup_layout);
+	QRadioButton *rb = new QRadioButton(i18n("Expenses"));
+	rb->setChecked(true);
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 0);
+	rb->setFocus();
+	rb = new QRadioButton(i18n("Incomes"));
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 1);
+	rb = new QRadioButton(i18n("Transfers"));
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 2);
+	rb = new QRadioButton(i18n("Expenses and incomes (negative cost)"));
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 3);
+	rb = new QRadioButton(i18n("Expenses and incomes (separate columns)"));
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 4);
+	rb = new QRadioButton(i18n("All types"));
+	typeGroup_layout->addWidget(rb);
+	typeGroup->addButton(rb, 5);
 	typeDescriptionLabel = new QLabel(page1);
-	typeDescriptionLabel->setAlignment(Qt::WordBreak);
+	typeDescriptionLabel->setWordWrap(true);
 	layout1->addWidget(typeDescriptionLabel);
-	typeGroup->setButton(0);
 
-	QWidget *page2 = new QWidget(this);
-	addPage(page2, i18n("File Selection"));
-	QGridLayout *layout2 = new QGridLayout(page2, 5, 2, 6, 6);
+	QIFWizardPage *page2 = new QIFWizardPage();
+	page2->setTitle(i18n("File Selection"));
+	setPage(1, page2);
+	QGridLayout *layout2 = new QGridLayout(page2);
 
 	layout2->addWidget(new QLabel(i18n("File:"), page2), 0, 0);
-	fileEdit = new KURLRequester(page2);
+	fileEdit = new KUrlRequester(page2);
 	fileEdit->setMode(KFile::File | KFile::ExistingOnly);
 	fileEdit->setFilter("text/x-csv");
 	layout2->addWidget(fileEdit, 0, 1);
 	layout2->addWidget(new QLabel(i18n("First data row:"), page2), 1, 0);
-	rowEdit = new QSpinBox(0, 1000, 1, page2);
+	rowEdit = new QSpinBox(page2);
+	rowEdit->setRange(0, 1000);
 	rowEdit->setSpecialValueText(i18n("Auto"));
 	rowEdit->setValue(0);
 	layout2->addWidget(rowEdit, 1, 1);
 	layout2->addWidget(new QLabel(i18n("Column delimiter:"), page2), 2, 0);
 	delimiterCombo = new KComboBox(page2);
 	delimiterCombo->setEditable(false);
-	delimiterCombo->insertItem(i18n("Comma"));
-	delimiterCombo->insertItem(i18n("Tabulator"));
-	delimiterCombo->insertItem(i18n("Semicolon"));
-	delimiterCombo->insertItem(i18n("Space"));
-	delimiterCombo->insertItem(i18n("Other"));
+	delimiterCombo->addItem(i18n("Comma"));
+	delimiterCombo->addItem(i18n("Tabulator"));
+	delimiterCombo->addItem(i18n("Semicolon"));
+	delimiterCombo->addItem(i18n("Space"));
+	delimiterCombo->addItem(i18n("Other"));
 	layout2->addWidget(delimiterCombo, 2, 1);
 	delimiterEdit = new KLineEdit(page2);
 	delimiterEdit->setEnabled(false);
 	layout2->addWidget(delimiterEdit, 3, 1);
-	layout2->addMultiCell(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 4, 0, 1);
+	layout2->addItem(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 0, 1, 2);
 
-	QWidget *page3 = new QWidget(this);
-	addPage(page3, i18n("Columns Specification"));
-	QGridLayout *layout3 = new QGridLayout(page3, 9, 5, 6, 6);
+	QIFWizardPage *page3 = new QIFWizardPage();
+	page3->setTitle(i18n("Columns Specification"));
+	setPage(2, page3);
+	QGridLayout *layout3 = new QGridLayout(page3);
 
 	layout3->addWidget(new QLabel(i18n("Description:"), page3), 0, 0);
-	descriptionGroup = new QButtonGroup();
+	descriptionGroup = new QButtonGroup(this);
 	columnDescriptionButton = new QRadioButton(i18n("Column"), page3);
-	descriptionGroup->insert(columnDescriptionButton);
+	descriptionGroup->addButton(columnDescriptionButton);
 	layout3->addWidget(columnDescriptionButton, 0, 1);
-	columnDescriptionEdit = new QSpinBox(1, 100, 1, page3);
+	columnDescriptionEdit = new QSpinBox(page3);
+	columnDescriptionEdit->setRange(1, 100);
 	columnDescriptionEdit->setValue(2);
 	columnDescriptionButton->setChecked(true);
 	layout3->addWidget(columnDescriptionEdit, 0, 2);
 	valueDescriptionButton = new QRadioButton(i18n("Value"), page3);
-	descriptionGroup->insert(valueDescriptionButton);
+	descriptionGroup->addButton(valueDescriptionButton);
 	layout3->addWidget(valueDescriptionButton, 0, 3);
 	valueDescriptionEdit = new KLineEdit(page3);
 	valueDescriptionEdit->setEnabled(false);
@@ -119,16 +145,17 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 
 	costLabel = new QLabel(i18n("Cost:"), page3);
 	layout3->addWidget(costLabel, 1, 0);
-	costGroup = new QButtonGroup();
+	costGroup = new QButtonGroup(this);
 	columnCostButton = new QRadioButton(i18n("Column"), page3);
-	costGroup->insert(columnCostButton);
+	costGroup->addButton(columnCostButton);
 	layout3->addWidget(columnCostButton, 1, 1);
-	columnCostEdit = new QSpinBox(1, 100, 1, page3);
+	columnCostEdit = new QSpinBox(page3);
+	columnCostEdit->setRange(1, 100);
 	columnCostEdit->setValue(3);
 	columnCostButton->setChecked(true);
 	layout3->addWidget(columnCostEdit, 1, 2);
 	valueCostButton = new QRadioButton(i18n("Value"), page3);
-	costGroup->insert(valueCostButton);
+	costGroup->addButton(valueCostButton);
 	layout3->addWidget(valueCostButton, 1, 3);
 	valueCostEdit = new EqonomizeValueEdit(false, page3);
 	valueCostEdit->setEnabled(false);
@@ -141,49 +168,53 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 
 	valueLabel = new QLabel(i18n("Cost:"), page3);
 	layout3->addWidget(valueLabel, 2, 0);
-	valueGroup = new QButtonGroup();
+	valueGroup = new QButtonGroup(this);
 	columnValueButton = new QRadioButton(i18n("Column"), page3);
-	valueGroup->insert(columnValueButton);
+	valueGroup->addButton(columnValueButton);
 	layout3->addWidget(columnValueButton, 2, 1);
-	columnValueEdit = new QSpinBox(1, 100, 1, page3);
+	columnValueEdit = new QSpinBox(page3);
+	columnValueEdit->setRange(1, 100);
 	columnValueEdit->setValue(3);
 	columnValueButton->setChecked(true);
 	layout3->addWidget(columnValueEdit, 2, 2);
 	valueValueButton = new QRadioButton(i18n("Value"), page3);
-	valueGroup->insert(valueValueButton);
+	valueGroup->addButton(valueValueButton);
 	layout3->addWidget(valueValueButton, 2, 3);
 	valueValueEdit = new EqonomizeValueEdit(false, page3);
 	valueValueEdit->setEnabled(false);
 	layout3->addWidget(valueValueEdit, 2, 4);
 
 	layout3->addWidget(new QLabel(i18n("Date:"), page3), 3, 0);
-	dateGroup = new QButtonGroup();
+	dateGroup = new QButtonGroup(this);
 	columnDateButton = new QRadioButton(i18n("Column"), page3);
-	dateGroup->insert(columnDateButton);
+	dateGroup->addButton(columnDateButton);
 	layout3->addWidget(columnDateButton, 3, 1);
-	columnDateEdit = new QSpinBox(1, 100, 1, page3);
+	columnDateEdit = new QSpinBox(page3);
+	columnDateEdit->setRange(1, 100);
 	columnDateEdit->setValue(1);
 	columnDateButton->setChecked(true);
 	layout3->addWidget(columnDateEdit, 3, 2);
 	valueDateButton = new QRadioButton(i18n("Value"), page3);
-	dateGroup->insert(valueDateButton);
+	dateGroup->addButton(valueDateButton);
 	layout3->addWidget(valueDateButton, 3, 3);
 	valueDateEdit = new KDateEdit(page3);
+	valueDateEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	valueDateEdit->setEnabled(false);
 	layout3->addWidget(valueDateEdit, 3, 4);
 
 	AC1Label = new QLabel(i18n("Category:"), page3);
 	layout3->addWidget(AC1Label, 4, 0);
-	AC1Group = new QButtonGroup();
+	AC1Group = new QButtonGroup(this);
 	columnAC1Button = new QRadioButton(i18n("Column"), page3);
-	AC1Group->insert(columnAC1Button);
+	AC1Group->addButton(columnAC1Button);
 	layout3->addWidget(columnAC1Button, 4, 1);
-	columnAC1Edit = new QSpinBox(1, 100, 1, page3);
+	columnAC1Edit = new QSpinBox(page3);
+	columnAC1Edit->setRange(1, 100);
 	columnAC1Edit->setValue(4);
 	columnAC1Edit->setEnabled(false);
 	layout3->addWidget(columnAC1Edit, 4, 2);
 	valueAC1Button = new QRadioButton(i18n("Value"), page3);
-	AC1Group->insert(valueAC1Button);
+	AC1Group->addButton(valueAC1Button);
 	valueAC1Button->setChecked(true);
 	layout3->addWidget(valueAC1Button, 4, 3);
 	valueAC1Edit = new KComboBox(page3);
@@ -192,16 +223,17 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 
 	AC2Label = new QLabel(i18n("From account:"), page3);
 	layout3->addWidget(AC2Label, 5, 0);
-	AC2Group = new QButtonGroup();
+	AC2Group = new QButtonGroup(this);
 	columnAC2Button = new QRadioButton(i18n("Column"), page3);
-	AC2Group->insert(columnAC2Button);
+	AC2Group->addButton(columnAC2Button);
 	layout3->addWidget(columnAC2Button, 5, 1);
-	columnAC2Edit = new QSpinBox(1, 100, 1, page3);
+	columnAC2Edit = new QSpinBox(page3);
+	columnAC2Edit->setRange(1, 100);
 	columnAC2Edit->setValue(5);
 	columnAC2Edit->setEnabled(false);
 	layout3->addWidget(columnAC2Edit, 5, 2);
 	valueAC2Button = new QRadioButton(i18n("Value"), page3);
-	AC2Group->insert(valueAC2Button);
+	AC2Group->addButton(valueAC2Button);
 	valueAC2Button->setChecked(true);
 	layout3->addWidget(valueAC2Button, 5, 3);
 	valueAC2Edit = new KComboBox(page3);
@@ -209,16 +241,17 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 	layout3->addWidget(valueAC2Edit, 5, 4);
 
 	layout3->addWidget(new QLabel(i18n("Comments:"), page3), 6, 0);
-	commentsGroup = new QButtonGroup();
+	commentsGroup = new QButtonGroup(this);
 	columnCommentsButton = new QRadioButton(i18n("Column"), page3);
-	commentsGroup->insert(columnCommentsButton);
+	commentsGroup->addButton(columnCommentsButton);
 	layout3->addWidget(columnCommentsButton, 6, 1);
-	columnCommentsEdit = new QSpinBox(1, 100, 1, page3);
+	columnCommentsEdit = new QSpinBox(page3);
+	columnCommentsEdit->setRange(1, 100);
 	columnCommentsEdit->setValue(6);
 	columnCommentsEdit->setEnabled(false);
 	layout3->addWidget(columnCommentsEdit, 6, 2);
 	valueCommentsButton = new QRadioButton(i18n("Value"), page3);
-	commentsGroup->insert(valueCommentsButton);
+	commentsGroup->addButton(valueCommentsButton);
 	valueCommentsButton->setChecked(true);
 	layout3->addWidget(valueCommentsButton, 6, 3);
 	valueCommentsEdit = new KLineEdit(page3);
@@ -229,19 +262,24 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 	createMissingButton = new QCheckBox(i18n("Create missing categories and accounts"), page3);
 	createMissingButton->setChecked(true);
 	layout3_cm->addWidget(createMissingButton);
-	layout3->addMultiCellLayout(layout3_cm, 7, 7, 0, 4);
+	layout3->addLayout(layout3_cm, 7, 0, 1, 5);
 
-	layout3->addMultiCell(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 8, 8, 0, 4);
+	layout3->addItem(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 8, 0, 1, 5);
 
-	setHelpEnabled(page1, false);
-	setHelpEnabled(page2, false);
-	setHelpEnabled(page3, false);
-	setFinishEnabled(page3, true);
+	setOption(QWizard::HaveHelpButton, false);
+	
+	page3->setFinalPage(true);
+
+	page1->setComplete(true);
+	page2->setComplete(false);
+	page3->setComplete(true);
+	
+	disconnect(button(NextButton), SIGNAL(clicked()), this, 0);
+	connect(button(NextButton), SIGNAL(clicked()), this, SLOT(nextClicked()));
 	
 	typeChanged(0);
 
-	typeGroup->setFocus();
-
+	connect(fileEdit, SIGNAL(textChanged(const QString&)), this, SLOT(onFileChanged(const QString&)));
 	connect(delimiterCombo, SIGNAL(activated(int)), this, SLOT(delimiterChanged(int)));
 	connect(columnDescriptionButton, SIGNAL(toggled(bool)), columnDescriptionEdit, SLOT(setEnabled(bool)));
 	connect(valueDescriptionButton, SIGNAL(toggled(bool)), valueDescriptionEdit, SLOT(setEnabled(bool)));
@@ -255,19 +293,16 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 	connect(valueAC2Button, SIGNAL(toggled(bool)), valueAC2Edit, SLOT(setEnabled(bool)));
 	connect(columnCommentsButton, SIGNAL(toggled(bool)), columnCommentsEdit, SLOT(setEnabled(bool)));
 	connect(valueCommentsButton, SIGNAL(toggled(bool)), valueCommentsEdit, SLOT(setEnabled(bool)));
-	connect(typeGroup, SIGNAL(clicked(int)), this, SLOT(typeChanged(int)));
+	connect(typeGroup, SIGNAL(buttonClicked(int)), this, SLOT(typeChanged(int)));
 	
 }
 
 ImportCSVDialog::~ImportCSVDialog() {
-	delete descriptionGroup;
-	delete dateGroup;
-	delete valueGroup;
-	delete AC1Group;
-	delete AC2Group;
-	delete commentsGroup;
 }
 
+void ImportCSVDialog::onFileChanged(const QString &str) {
+	((QIFWizardPage*) page(1))->setComplete(!str.isEmpty());
+}
 void ImportCSVDialog::delimiterChanged(int index) {
 	delimiterEdit->setEnabled(index == 4);
 }
@@ -288,7 +323,7 @@ void ImportCSVDialog::typeChanged(int id) {
 	valueAC2Edit->clear();
 	if(id < 5) {
 		AssetsAccount *aa = budget->assetsAccounts.first();
-		while(aa) {if(aa != budget->balancingAccount && aa->accountType() != ASSETS_TYPE_SECURITIES) valueAC2Edit->insertItem(aa->name()); aa = budget->assetsAccounts.next();}
+		while(aa) {if(aa != budget->balancingAccount && aa->accountType() != ASSETS_TYPE_SECURITIES) valueAC2Edit->addItem(aa->name()); aa = budget->assetsAccounts.next();}
 	}
 	if(id == 4) {
 		costLabel->show();
@@ -321,7 +356,7 @@ void ImportCSVDialog::typeChanged(int id) {
 			AC1Label->setText(i18n("Category:"));
 			AC2Label->setText(i18n("From account:"));
 			ExpensesAccount *ea = budget->expensesAccounts.first();
-			while(ea) {valueAC1Edit->insertItem(ea->name()); ea = budget->expensesAccounts.next();}
+			while(ea) {valueAC1Edit->addItem(ea->name()); ea = budget->expensesAccounts.next();}
 			break;
 		}
 		case 1: {
@@ -330,7 +365,7 @@ void ImportCSVDialog::typeChanged(int id) {
 			AC1Label->setText(i18n("Category:"));
 			AC2Label->setText(i18n("To account:"));
 			IncomesAccount *ia = budget->incomesAccounts.first();
-			while(ia) {valueAC1Edit->insertItem(ia->name()); ia = budget->incomesAccounts.next();}
+			while(ia) {valueAC1Edit->addItem(ia->name()); ia = budget->incomesAccounts.next();}
 			break;
 		}
 		case 2: {
@@ -339,7 +374,7 @@ void ImportCSVDialog::typeChanged(int id) {
 			AC1Label->setText(i18n("From account:"));
 			AC2Label->setText(i18n("To account:"));
 			AssetsAccount *aa = budget->assetsAccounts.first();
-			while(aa) {if(aa != budget->balancingAccount && aa->accountType() != ASSETS_TYPE_SECURITIES) valueAC1Edit->insertItem(aa->name()); aa = budget->assetsAccounts.next();}
+			while(aa) {if(aa != budget->balancingAccount && aa->accountType() != ASSETS_TYPE_SECURITIES) valueAC1Edit->addItem(aa->name()); aa = budget->assetsAccounts.next();}
 			break;
 		}
 		case 3: {
@@ -396,11 +431,11 @@ void ImportCSVDialog::typeChanged(int id) {
 	}
 	
 }
-void ImportCSVDialog::next() {
+void ImportCSVDialog::nextClicked() {
 	if(currentPage() == page(0)) {
 		fileEdit->setFocus();
 	} else if(currentPage() == page(1)) {
-		const KURL &url = fileEdit->url();
+		const KUrl &url = fileEdit->url();
 		if(url.isEmpty()) {
 			KMessageBox::error(this, i18n("A file must be selected."));
 			fileEdit->setFocus();
@@ -416,7 +451,7 @@ void ImportCSVDialog::next() {
 				fileEdit->setFocus();
 				return;
 			}
-			fileEdit->setURL(info.absFilePath());
+			fileEdit->setUrl(info.absoluteFilePath());
 		} else if(url.isLocalFile()) {
 			QFileInfo info(url.path());
 			if(info.isDir()) {
@@ -429,22 +464,22 @@ void ImportCSVDialog::next() {
 				return;
 			}
 		}
-		if(delimiterCombo->currentItem() == 4 && delimiterEdit->text().isEmpty()) {
+		if(delimiterCombo->currentIndex() == 4 && delimiterEdit->text().isEmpty()) {
 			KMessageBox::error(this, i18n("Empty delimiter."));
 			delimiterEdit->setFocus();
 			return;
 		}
 		columnDescriptionEdit->setFocus();
 	}
-	KWizard::next();
+	QWizard::next();
 }
 
 QDate readCSVDate(const QString &str, const QString &date_format, const QString &alt_date_format) {
 	struct tm tp;
 	QDate date;
-	if(strptime(str.ascii(), date_format.ascii(), &tp)) {
+	if(strptime(str.toAscii(), date_format.toAscii(), &tp)) {
 		date.setYMD(tp.tm_year > 17100 ? tp.tm_year - 15200 : tp.tm_year + 1900, tp.tm_mon + 1, tp.tm_mday);
-	} else if(!alt_date_format.isEmpty() && strptime(str.ascii(), alt_date_format.ascii(), &tp)) {
+	} else if(!alt_date_format.isEmpty() && strptime(str.toAscii(), alt_date_format.toAscii(), &tp)) {
 		date.setYMD(tp.tm_year > 17100 ? tp.tm_year - 15200 : tp.tm_year + 1900, tp.tm_mon + 1, tp.tm_mday);
 	}
 	return date;
@@ -487,7 +522,7 @@ void testCSVDate(const QString &str, bool &p1, bool &p2, bool &p3, bool &p4, boo
 	if(separator < 0) {
 		for(int i = 0; i < (int) str.length(); i++) {
 			if(str[i] < '0' || str[i] > '9') {
-				separator = str[i];
+				separator = str[i].toLatin1();
 				break;
 			}
 		}
@@ -499,9 +534,9 @@ void testCSVDate(const QString &str, bool &p1, bool &p2, bool &p3, bool &p4, boo
 		ly = false;
 	}
 	if(p1 + p2 + p3 + p4 <= 1) return;
-	QStringList strlist = QStringList::split(separator, str);
+	QStringList strlist = str.split(separator, QString::SkipEmptyParts);
 	if(strlist.count() == 2 && (p1 || p2)) {
-		int i = strlist[1].find('\'');
+		int i = strlist[1].indexOf('\'');
 		if(i >= 0) {
 			strlist.append(strlist[1]);
 			strlist[2].remove(0, i + 1);
@@ -534,8 +569,8 @@ void testCSVDate(const QString &str, bool &p1, bool &p2, bool &p3, bool &p4, boo
 
 void testCSVValue(const QString &str, int &value_format) {
 	if(value_format <= 0) {
-		int i = str.findRev('.');
-		int i2 = str.findRev(',');
+		int i = str.lastIndexOf('.');
+		int i2 = str.lastIndexOf(',');
 		if(i2 >= 0 && i >= 0) {
 			if(i2 > i) value_format = 2;
 			else value_format = 1;
@@ -635,9 +670,9 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 		}
 	}
 	int first_row = rowEdit->value();
-	int type = typeGroup->selectedId();
+	int type = typeGroup->checkedId();
 	QString delimiter;
-	switch(delimiterCombo->currentItem()) {
+	switch(delimiterCombo->currentIndex()) {
 		case 0: {delimiter = ","; break;}
 		case 1: {delimiter = "\t"; break;}
 		case 2: {delimiter = ";"; break;}
@@ -704,7 +739,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 					if(!account) break;
 				}
 			}
-			if(i == valueAC1Edit->currentItem()) {
+			if(i == valueAC1Edit->currentIndex()) {
 				ac1 = account;
 				break;
 			}
@@ -726,7 +761,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 				account = budget->assetsAccounts.next();
 				if(!account) break;
 			}
-			if(i == valueAC2Edit->currentItem()) {
+			if(i == valueAC2Edit->currentIndex()) {
 				ac2 = account;
 				break;
 			}
@@ -753,26 +788,26 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 	}
 	double cost = 0.0;
 
-	KURL url = fileEdit->url();
+	KUrl url = fileEdit->url();
 	QString tmpfile;
 	if(!url.isLocalFile()) {
 		if(!KIO::NetAccess::download(url, tmpfile, this)) {
-			KMessageBox::error(this, i18n("Couldn't fetch %1.").arg(url.prettyURL()));
+			KMessageBox::error(this, i18n("Couldn't fetch %1.").arg(url.prettyUrl()));
 			return false;
 		}
 	} else {
 		tmpfile = url.path();
 	}
 	QFile file(tmpfile);
-	if(!file.open(IO_ReadOnly) ) {
-		KMessageBox::error(this, i18n("Couldn't open %1 for reading.").arg(url.prettyURL()));
+	if(!file.open(QIODevice::ReadOnly) ) {
+		KMessageBox::error(this, i18n("Couldn't open %1 for reading.").arg(url.prettyUrl()));
 		return false;
 	} else if(!file.size()) {
-		KMessageBox::error(this, i18n("Error reading %1.").arg(url.prettyURL()));
+		KMessageBox::error(this, i18n("Error reading %1.").arg(url.prettyUrl()));
 		return false;
 	}
 	QTextStream fstream(&file);
-	fstream.setEncoding(QTextStream::Locale);
+	fstream.setCodec("UTF-8");
 
 	bool had_data = false;
 	int successes = 0;
@@ -788,7 +823,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 	while(!line.isNull()) {
 		row++;
 		if((first_row == 0 && !line.isEmpty() && line[0] != '#') || (first_row > 0 && row >= first_row && !line.isEmpty())) {
-			QStringList columns = QStringList::split(delimiter, line, true);
+			QStringList columns = line.split(delimiter, QString::KeepEmptyParts);
 			for(QStringList::Iterator it = columns.begin(); it != columns.end(); ++it) {
 				int i = 0;
 				while(i < (int) (*it).length() && ((*it)[i] == ' ' || (*it)[i] == '\t')) {
@@ -825,7 +860,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 						}
 					}
 				}
-				*it = (*it).stripWhiteSpace();
+				*it = (*it).trimmed();
 			}
 			if((int) columns.count() < min_columns) {
 				if(first_row != 0) {
@@ -952,7 +987,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 						}
 					}
 					if(found) {
-						ac1 = it_ac.data();
+						ac1 = it_ac.value();
 						if(ac1->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) ac1)->accountType() == ASSETS_TYPE_SECURITIES) {
 							AC_security = true;
 							success = false;
@@ -985,7 +1020,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 						found = (it_ac != aaccounts.end());
 					}
 					if(found) {
-						ac2 = it_ac.data();
+						ac2 = it_ac.value();
 						if(ac1 == ac2) {
 							AC_same = true;
 							success = false;
@@ -1001,7 +1036,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 									it_ac = aaccounts.find(columns[AC1_c - 1]);
 									found = it_ac != aaccounts.end();
 									if(found) {
-										ac1 = it_ac.data();
+										ac1 = it_ac.value();
 										if(ac1->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) ac1)->accountType() == ASSETS_TYPE_SECURITIES) {
 											AC_security = true;
 											success = false;
@@ -1025,7 +1060,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 							it_ac = aaccounts.find(columns[AC2_c - 1]);
 							found = it_ac != aaccounts.end();
 							if(found) {
-								ac2 = it_ac.data();
+								ac2 = it_ac.value();
 								if(ac2->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) ac2)->accountType() == ASSETS_TYPE_SECURITIES) {
 									AC_security = true;
 									success = false;
@@ -1149,13 +1184,13 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 
 	QString info = "", details = "";
 	if(successes > 0) {
-		info = i18n("Successfully imported 1 transaction.", "Successfully imported %n transactions.", successes);
+		info = i18np("Successfully imported 1 transaction.", "Successfully imported %n transactions.", successes);
 	} else {
 		info = i18n("Unable to import any transactions imported.");
 	}
 	if(failed > 0) {
 		info += '\n';
-		info += i18n("Failed to import 1 data row.", "Failed to import %n data rows.", failed);
+		info += i18np("Failed to import 1 data row.", "Failed to import %n data rows.", failed);
 		if(missing_columns) {details += "\n-"; details += i18n("Required columns missing.");}
 		if(value_error) {details += "\n-"; details += i18n("Invalid value.");}
 		if(date_error) {details += "\n-"; details += i18n("Invalid date.");}
@@ -1185,12 +1220,16 @@ void ImportCSVDialog::accept() {
 		return;
 	}
 	if(ci.value_format < 0 || ps > 1) {
-		KDialogBase *dialog = new KDialogBase(this, 0, true, i18n("Specify Format"), KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true);
+		KDialog *dialog = new KDialog(this, 0);
+		dialog->setCaption(i18n("Specify Format"));	
+		dialog->setButtons(KDialog::Ok | KDialog::Cancel);
+		dialog->setDefaultButton(KDialog::Cancel);
+		dialog->setModal(true);
 		dialog->setMainWidget(new QWidget(dialog));
-		QGridLayout *grid = new QGridLayout(dialog->mainWidget(), (ci.value_format < 0 && ps > 1) ? 3 : 2, 2, 0, dialog->spacingHint());
+		QGridLayout *grid = new QGridLayout(dialog->mainWidget());
 		QLabel *label = new QLabel(i18n("The format of dates and/or numbers in the CSV file is ambiguous. Please select the correct format."), dialog->mainWidget());
-		label->setAlignment(Qt::WordBreak);
-		grid->addMultiCellWidget(label, 0, 0, 0, 1);		
+		label->setWordWrap(true);
+		grid->addWidget(label, 0, 0, 1, 2);
 		KComboBox *dateFormatCombo = NULL;
 		if(ps > 1) {
 			grid->addWidget(new QLabel(i18n("Date format:"), dialog->mainWidget()), 1, 0);
@@ -1203,7 +1242,7 @@ void ImportCSVDialog::accept() {
 				if(ci.separator > 0) date_format += ci.separator;
 				date_format += "YY";
 				if(ci.ly) date_format += "YY";
-				dateFormatCombo->insertItem(date_format);
+				dateFormatCombo->addItem(date_format);
 			}
 			if(ci.p2) {
 				QString date_format = "DD";
@@ -1212,7 +1251,7 @@ void ImportCSVDialog::accept() {
 				if(ci.separator > 0) date_format += ci.separator;
 				date_format += "YY";
 				if(ci.ly) date_format += "YY";
-				dateFormatCombo->insertItem(date_format);
+				dateFormatCombo->addItem(date_format);
 			}
 			if(ci.p3) {
 				QString date_format = "YY";
@@ -1221,7 +1260,7 @@ void ImportCSVDialog::accept() {
 				date_format += "MM";
 				if(ci.separator > 0) date_format += ci.separator;
 				date_format += "DD";
-				dateFormatCombo->insertItem(date_format);
+				dateFormatCombo->addItem(date_format);
 			}
 			if(ci.p4) {
 				QString date_format = "YY";
@@ -1230,7 +1269,7 @@ void ImportCSVDialog::accept() {
 				date_format += "DD";
 				if(ci.separator > 0) date_format += ci.separator;
 				date_format += "MM";
-				dateFormatCombo->insertItem(date_format);
+				dateFormatCombo->addItem(date_format);
 			}
 			grid->addWidget(dateFormatCombo, 1, 1);
 		}
@@ -1239,8 +1278,8 @@ void ImportCSVDialog::accept() {
 			grid->addWidget(new QLabel(i18n("Value format:"), dialog->mainWidget()), ps > 1 ? 2 : 1, 0);
 			valueFormatCombo = new KComboBox(dialog->mainWidget());
 			valueFormatCombo->setEditable(false);
-			valueFormatCombo->insertItem("1,000,000.00");
-			valueFormatCombo->insertItem("1.000.000,00");
+			valueFormatCombo->addItem("1,000,000.00");
+			valueFormatCombo->addItem("1.000.000,00");
 			grid->addWidget(valueFormatCombo, ps > 1 ? 2 : 1, 1);
 		}
 		if(dialog->exec() != QDialog::Accepted) {
@@ -1254,7 +1293,7 @@ void ImportCSVDialog::accept() {
 			if(ci.p2) {p[i] = 2; i++;}
 			if(ci.p3) {p[i] = 3; i++;}
 			if(ci.p4) {p[i] = 4; i++;}
-			switch(p[dateFormatCombo->currentItem()]) {
+			switch(p[dateFormatCombo->currentIndex()]) {
 				case 1: {p1 = true; break;}
 				case 2: {p2 = true; break;}
 				case 3: {p3 = true; break;}
@@ -1262,10 +1301,10 @@ void ImportCSVDialog::accept() {
 			}
 			ci.p1 = p1; ci.p2 = p2; ci.p3 = p3; ci.p4 = p4;
 		}
-		if(ci.value_format < 0) ci.value_format = valueFormatCombo->currentItem() + 1;
+		if(ci.value_format < 0) ci.value_format = valueFormatCombo->currentIndex() + 1;
 		dialog->deleteLater();
 	}
-	if(import(false, &ci)) KWizard::accept();
+	if(import(false, &ci)) QWizard::accept();
 }
 
 #include "importcsvdialog.moc"
