@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,14 +30,20 @@
 #include <khtml_part.h>
 #include <khtmlview.h>
 #include <qlabel.h>
+#include <ktemporaryfile.h>
+#include <QTextStream>
+#include <QHBoxLayout>
+#include <QList>
+#include <QTextStream>
+#include <QVBoxLayout>
 #include <klocale.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
 #include <qlabel.h>
-#include <klistview.h>
+#include <QTreeWidget>
 #include <qlayout.h>
-#include <kbuttonbox.h>
-#include <qpopupmenu.h>
+#include <KDialogButtonBox>
+#include <QMenu>
 #include <kaction.h>
 #include <kdeversion.h>
 #include <kmessagebox.h>
@@ -48,20 +54,33 @@
 #include <kfiledialog.h>
 #include <kurl.h>
 #include <qcheckbox.h>
+#include <QScrollBar>
 
 extern QString htmlize_string(QString str);
 
-class LedgerListViewItem : public KListViewItem {
+class LedgerListViewItem : public QTreeWidgetItem {
 	protected:
 		Transaction *o_trans;
 		SplitTransaction *o_split;
 	public:
-		LedgerListViewItem(Transaction *trans, SplitTransaction *split, QListView *parent, QString, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null);
+		LedgerListViewItem(Transaction *trans, SplitTransaction *split, QTreeWidget *parent, QString, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null, QString=QString::null);
 		Transaction *transaction() const;
 		SplitTransaction *splitTransaction() const;
 };
 
-LedgerListViewItem::LedgerListViewItem(Transaction *trans, SplitTransaction *split, QListView *parent, QString s1, QString s2, QString s3, QString s4, QString s5, QString s6, QString s7, QString s8) : KListViewItem(parent, s1, s2, s3, s4, s5, s6, s7, s8), o_trans(trans), o_split(split) {}
+LedgerListViewItem::LedgerListViewItem(Transaction *trans, SplitTransaction *split, QTreeWidget *parent, QString s1, QString s2, QString s3, QString s4, QString s5, QString s6, QString s7, QString s8) : QTreeWidgetItem(parent), o_trans(trans), o_split(split) {
+	setText(0, s1);
+	setText(1, s2);
+	setText(2, s3);
+	setText(3, s4);
+	setText(4, s5);
+	setText(5, s6);
+	setText(6, s7);
+	setText(7, s8);
+	setTextAlignment(4, Qt::AlignRight);
+	setTextAlignment(5, Qt::AlignRight);
+	setTextAlignment(6, Qt::AlignRight);
+}
 Transaction *LedgerListViewItem::transaction() const {
 	return o_trans;
 }
@@ -69,16 +88,22 @@ SplitTransaction *LedgerListViewItem::splitTransaction() const {
 	return o_split;
 }
 
-LedgerDialog::LedgerDialog(AssetsAccount *acc, Eqonomize *parent, QString title, bool extra_parameters) : KDialogBase(NULL, 0, false, title, Close, Close, true), account(acc), mainWin(parent), b_extra(extra_parameters) {
+LedgerDialog::LedgerDialog(AssetsAccount *acc, Eqonomize *parent, QString title, bool extra_parameters) : KDialog(NULL, 0), account(acc), mainWin(parent), b_extra(extra_parameters) {
 
-	setWFlags(getWFlags() | Qt::WDestructiveClose);
+	setCaption(title);	
+	setButtons(KDialog::Close);
+	setDefaultButton(KDialog::Close);
+	setModal(true);
+	
+	setAttribute(Qt::WA_DeleteOnClose, true);
 
 	budget = account->budget();
 	
 	setMainWidget(new QWidget(this));
-	QVBoxLayout *box1 = new QVBoxLayout(mainWidget(), 0, spacingHint());
+	QVBoxLayout *box1 = new QVBoxLayout(mainWidget());
 	
-	QHBoxLayout *topbox = new QHBoxLayout(box1);
+	QHBoxLayout *topbox = new QHBoxLayout();
+	box1->addLayout(topbox);
 	topbox->addWidget(new QLabel(i18n("Account:"), mainWidget()));
 	accountCombo = new KComboBox(mainWidget());
 	accountCombo->setEditable(false);
@@ -86,67 +111,62 @@ LedgerDialog::LedgerDialog(AssetsAccount *acc, Eqonomize *parent, QString title,
 	AssetsAccount *aaccount = budget->assetsAccounts.first();
 	while(aaccount) {
 		if(aaccount != budget->balancingAccount && aaccount->accountType() != ASSETS_TYPE_SECURITIES) {
-			accountCombo->insertItem(aaccount->name());
-			if(aaccount == account) accountCombo->setCurrentItem(i);
+			accountCombo->addItem(aaccount->name());
+			if(aaccount == account) accountCombo->setCurrentIndex(i);
 			i++;
 		}
 		aaccount = budget->assetsAccounts.next();
 	}
 	topbox->addWidget(accountCombo);
-	KButtonBox *topbuttons = new KButtonBox(mainWidget(), KButtonBox::Horizontal);
-	exportButton = topbuttons->addButton(i18n("Export..."));
-	printButton = topbuttons->addButton(i18n("Print..."));
+	KDialogButtonBox *topbuttons = new KDialogButtonBox(mainWidget());
+	exportButton = topbuttons->addButton(i18n("Export..."), QDialogButtonBox::ActionRole);
+	printButton = topbuttons->addButton(i18n("Print..."), QDialogButtonBox::ActionRole);
 	topbox->addWidget(topbuttons);
 	topbox->addStretch(1);
 
-	QHBoxLayout *box2 = new QHBoxLayout(box1);
-	transactionsView = new KListView(mainWidget());
-	transactionsView->addColumn(i18n("Date"));
-	transactionsView->addColumn(i18n("Type"));
-	transactionsView->addColumn(i18n("Description"));
-	transactionsView->addColumn(i18n("Account/Category"));	
-	transactionsView->addColumn(i18n("Deposit"));
-	transactionsView->addColumn(i18n("Withdrawal"));
-	transactionsView->addColumn(i18n("Balance"));
-	transactionsView->setRootIsDecorated(false);
+	QHBoxLayout *box2 = new QHBoxLayout();
+	box1->addLayout(box2);
+	transactionsView = new EqonomizeTreeWidget(mainWidget());
+	transactionsView->setSortingEnabled(false);
 	transactionsView->setAllColumnsShowFocus(true);
-	transactionsView->setSorting(-1);
-	transactionsView->setColumnAlignment(4, Qt::AlignRight);
-	transactionsView->setColumnAlignment(5, Qt::AlignRight);
-	transactionsView->setColumnAlignment(6, Qt::AlignRight);
-	transactionsView->setItemMargin(3);
+	transactionsView->setColumnCount(7);
+	QStringList headers;
+	headers << i18n("Date");
+	headers << i18n("Type");
+	headers << i18n("Description");
+	headers << i18n("Account/Category");	
+	headers << i18n("Deposit");
+	headers << i18n("Withdrawal");
+	headers << i18n("Balance");
+	transactionsView->setHeaderLabels(headers);
+	transactionsView->setRootIsDecorated(false);	
+	//transactionsView->setItemMargin(3);
 	transactionsView->setMinimumHeight(450);
-	transactionsView->setSelectionMode(QListView::Extended);
+	transactionsView->setSelectionMode(QTreeWidget::ExtendedSelection);
 	QSizePolicy sp = transactionsView->sizePolicy();
-	sp.setHorData(QSizePolicy::MinimumExpanding);
+	sp.setHorizontalPolicy(QSizePolicy::MinimumExpanding);
 	transactionsView->setSizePolicy(sp);
 	box2->addWidget(transactionsView);
-	KButtonBox *buttons = new KButtonBox(mainWidget(), KButtonBox::Vertical);
-	QPushButton *newButton = buttons->addButton(i18n("New"));
-	QPopupMenu *newMenu = new QPopupMenu(this);
-	newButton->setPopup(newMenu);
-	newMenu->insertItem(mainWin->ActionNewExpense->iconSet(), mainWin->ActionNewExpense->text(), this, SLOT(newExpense()));
-	newMenu->insertItem(mainWin->ActionNewIncome->iconSet(), mainWin->ActionNewIncome->text(), this, SLOT(newIncome()));
-	newMenu->insertItem(mainWin->ActionNewTransfer->iconSet(), mainWin->ActionNewTransfer->text(), this, SLOT(newTransfer()));
-	newMenu->insertItem(mainWin->ActionNewSplitTransaction->iconSet(), mainWin->ActionNewSplitTransaction->text(), this, SLOT(newSplit()));
-	editButton = buttons->addButton(i18n("Edit..."));
+	KDialogButtonBox *buttons = new KDialogButtonBox(mainWidget(), Qt::Vertical);
+	QPushButton *newButton = buttons->addButton(i18n("New"), QDialogButtonBox::ActionRole);
+	QMenu *newMenu = new QMenu(this);
+	newButton->setMenu(newMenu);
+	connect(newMenu->addAction(mainWin->ActionNewExpense->icon(), mainWin->ActionNewExpense->text()), SIGNAL(triggered()), this, SLOT(newExpense()));
+	connect(newMenu->addAction(mainWin->ActionNewIncome->icon(), mainWin->ActionNewIncome->text()), SIGNAL(triggered()), this, SLOT(newIncome()));
+	connect(newMenu->addAction(mainWin->ActionNewTransfer->icon(), mainWin->ActionNewTransfer->text()), SIGNAL(triggered()), this, SLOT(newTransfer()));
+	connect(newMenu->addAction(mainWin->ActionNewSplitTransaction->icon(), mainWin->ActionNewSplitTransaction->text()), SIGNAL(triggered()), this, SLOT(newSplit()));
+	editButton = buttons->addButton(i18n("Edit..."), QDialogButtonBox::ActionRole);
 	editButton->setEnabled(false);
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 3
-	removeButton = buttons->addButton(KStdGuiItem::guiItem(KStdGuiItem::Delete));
-#else
-	removeButton = buttons->addButton(i18n("Delete"));
-#endif
+	removeButton = buttons->addButton(KStandardGuiItem::guiItem(KStandardGuiItem::Delete), QDialogButtonBox::ActionRole);
 	removeButton->setEnabled(false);
-	joinButton = buttons->addButton(i18n("Join..."));
+	joinButton = buttons->addButton(i18n("Join..."), QDialogButtonBox::ActionRole);
 	joinButton->setEnabled(false);
-	splitUpButton = buttons->addButton(i18n("Split Up"));
+	splitUpButton = buttons->addButton(i18n("Split Up"), QDialogButtonBox::ActionRole);
 	splitUpButton->setEnabled(false);
 	box2->addWidget(buttons);
-	buttons->addStretch();
-	buttons->layout();
 	
-	connect(transactionsView, SIGNAL(selectionChanged()), this, SLOT(transactionSelectionChanged()));
-	connect(transactionsView, SIGNAL(doubleClicked(QListViewItem*, const QPoint&, int)), this, SLOT(edit(QListViewItem*)));
+	connect(transactionsView, SIGNAL(itemSelectionChanged()), this, SLOT(transactionSelectionChanged()));
+	connect(transactionsView, SIGNAL(doubleClicked(QTreeWidgetItem*, int)), this, SLOT(edit(QTreeWidgetItem*)));
 	connect(removeButton, SIGNAL(clicked()), this, SLOT(remove()));
 	connect(editButton, SIGNAL(clicked()), this, SLOT(edit()));
 	connect(joinButton, SIGNAL(clicked()), this, SLOT(joinTransactions()));
@@ -162,6 +182,11 @@ LedgerDialog::LedgerDialog(AssetsAccount *acc, Eqonomize *parent, QString title,
 }
 LedgerDialog::~LedgerDialog() {}
 
+void LedgerDialog::saveConfig() {
+	KConfigGroup config = KGlobal::config()->group("Ledger");
+	saveDialogSize(config);
+}
+
 void LedgerDialog::accountChanged(int index) {
 	int i = 0;
 	AssetsAccount *aaccount = budget->assetsAccounts.first();
@@ -184,9 +209,9 @@ void LedgerDialog::updateAccounts() {
 	AssetsAccount *aaccount = budget->assetsAccounts.first();
 	while(aaccount) {
 		if(aaccount != budget->balancingAccount && aaccount->accountType() != ASSETS_TYPE_SECURITIES) {
-			accountCombo->insertItem(aaccount->name());
+			accountCombo->addItem(aaccount->name());
 			if(aaccount == account) {
-				accountCombo->setCurrentItem(i);
+				accountCombo->setCurrentIndex(i);
 				account_found = true;
 			}
 			i++;
@@ -205,18 +230,18 @@ void LedgerDialog::updateAccounts() {
 	accountCombo->blockSignals(false);
 }
 void LedgerDialog::saveView() {
-	if(transactionsView->childCount() == 0) {
+	if(transactionsView->topLevelItemCount() == 0) {
 		KMessageBox::error(this, i18n("Empty transaction list."));
 		return;
 	}
-	KFileDialog *dialog = new KFileDialog(QString::null, QString::null, this, NULL, true);
+	KFileDialog *dialog = new KFileDialog(KUrl(), QString::null, this);
 	QStringList filter;
 	filter << "text/html" << "text/x-csv";
 	dialog->setMimeFilter(filter, "text/html");
 	dialog->setOperationMode(KFileDialog::Saving);
 	dialog->setMode(KFile::File);
 	if(dialog->exec() != QDialog::Accepted) {dialog->deleteLater(); return;}
-	KURL url = dialog->selectedURL();
+	KUrl url = dialog->selectedUrl();
 	char filetype = 'h';
 	if(dialog->currentMimeFilter() == "text/x-csv") filetype = 'c';
 	dialog->deleteLater();
@@ -230,31 +255,30 @@ void LedgerDialog::saveView() {
 			KMessageBox::error(this, i18n("You selected a directory!"));
 			return;
 		}
-		KSaveFile ofile(url.path(), 0660);
-		if(ofile.status()) {
+		KSaveFile ofile(url.path());
+		ofile.open();
+		ofile.setPermissions((QFile::Permissions) 0x0660);
+		if(!ofile.isOpen()) {
 			ofile.abort();
 			KMessageBox::error(this, i18n("Couldn't open file for writing."));
 			return;
 		}
-		exportList(*ofile.textStream(), filetype);
-		if(ofile.status()) {
-			ofile.abort();
+		QTextStream stream(&ofile);
+		exportList(stream, filetype);
+		if(!ofile.finalize()) {
 			KMessageBox::error(this, i18n("Error while writing file; file was not saved."));
 			return;
 		}
-		ofile.close();
-		if(ofile.status()) {
-			KMessageBox::error(this, i18n("Error after saving file; data may not have been saved."));
-			return;
-		}
 		return;
 	}
 
-	KTempFile tf;
-	tf.setAutoDelete(true);
-	if(exportList(*tf.textStream(), filetype)) {
-		if(!KIO::NetAccess::upload(tf.name(), url, this)) {
-			KMessageBox::error(this, i18n("Failed to upload file to %1.").arg(url.prettyURL()));
+	KTemporaryFile tf;
+	tf.open();
+	tf.setAutoRemove(true);
+	QTextStream stream(&tf);
+	if(exportList(stream, filetype)) {
+		if(!KIO::NetAccess::upload(tf.fileName(), url, this)) {
+			KMessageBox::error(this, i18n("Failed to upload file to %1.").arg(url.prettyUrl()));
 		}
 	}
 }
@@ -262,7 +286,7 @@ bool LedgerDialog::exportList(QTextStream &outf, int fileformat) {
 
 	switch(fileformat) {
 		case 'h': {
-			outf.setEncoding(QTextStream::UnicodeUTF8);
+			outf.setCodec("UTF-8");
 			outf << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">" << '\n';
 			outf << "<html>" << '\n';
 			outf << "\t<head>" << '\n';
@@ -275,17 +299,19 @@ bool LedgerDialog::exportList(QTextStream &outf, int fileformat) {
 			outf << "\t\t\t<caption>"; outf << htmlize_string(i18n("Transactions for %1").arg(account->name())); outf << "</caption>" << '\n';
 			outf << "\t\t\t<thead>" << '\n';
 			outf << "\t\t\t\t<tr>" << '\n';
-			outf << "\t\t\t\t\t<th>" << htmlize_string(transactionsView->columnText(0)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(1)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(2)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(3)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(4)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(5)) << "</th>";
-			outf << "<th>" << htmlize_string(transactionsView->columnText(6)) << "</th>" << "\n";
+			QTreeWidgetItem *header = transactionsView->headerItem();
+			outf << "\t\t\t\t\t<th>" << htmlize_string(header->text(0)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(1)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(2)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(3)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(4)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(5)) << "</th>";
+			outf << "<th>" << htmlize_string(header->text(6)) << "</th>" << "\n";
 			outf << "\t\t\t\t</tr>" << '\n';
 			outf << "\t\t\t</thead>" << '\n';
 			outf << "\t\t\t<tbody>" << '\n';
-			LedgerListViewItem *i = (LedgerListViewItem*) transactionsView->firstChild();
+			QTreeWidgetItemIterator it(transactionsView);
+			LedgerListViewItem *i = (LedgerListViewItem*) *it;
 			while(i) {
 				outf << "\t\t\t\t<tr>" << '\n';
 				outf << "\t\t\t\t\t<td nowrap align=\"right\">" << htmlize_string(i->text(0)) << "</td>";
@@ -296,7 +322,8 @@ bool LedgerDialog::exportList(QTextStream &outf, int fileformat) {
 				outf << "<td nowrap align=\"right\">" << htmlize_string(i->text(5)) << "</td>";
 				outf << "<td nowrap align=\"right\">" << htmlize_string(i->text(6)) << "</td>" << "\n";
 				outf << "\t\t\t\t</tr>" << '\n';
-				i = (LedgerListViewItem*) i->nextSibling();
+				++it;
+				i = (LedgerListViewItem*) *it;
 			}
 			outf << "\t\t\t</tbody>" << '\n';
 			outf << "\t\t</table>" << '\n';
@@ -305,12 +332,15 @@ bool LedgerDialog::exportList(QTextStream &outf, int fileformat) {
 			break;
 		}
 		case 'c': {
-			outf.setEncoding(QTextStream::Locale);
-			outf << "\"" << transactionsView->columnText(0) << "\",\"" << transactionsView->columnText(1) << "\",\"" << transactionsView->columnText(2) << "\",\"" << transactionsView->columnText(3) << "\",\"" << transactionsView->columnText(4) << "\",\""<< transactionsView->columnText(5) << "\",\"" << transactionsView->columnText(6) << "\"\n";
-			LedgerListViewItem *i = (LedgerListViewItem*) transactionsView->firstChild();
+			//outf.setEncoding(Q3TextStream::Locale);
+			QTreeWidgetItem *header = transactionsView->headerItem();
+			outf << "\"" << header->text(0) << "\",\"" << header->text(1) << "\",\"" << header->text(2) << "\",\"" << header->text(3) << "\",\"" << header->text(4) << "\",\""<< header->text(5) << "\",\"" << header->text(6) << "\"\n";
+			QTreeWidgetItemIterator it(transactionsView);
+			LedgerListViewItem *i = (LedgerListViewItem*) *it;
 			while(i) {
 				outf << "\"" << i->text(0) << "\",\"" << i->text(1) << "\",\"" << i->text(2) << "\",\"" << i->text(3) << "\",\"" << i->text(4) << "\",\"" << i->text(5) << "\",\"" << i->text(6) << "\"\n";
-				i = (LedgerListViewItem*) i->nextSibling();
+				++it;
+				i = (LedgerListViewItem*) *it;
 			}
 			break;
 		}
@@ -320,12 +350,12 @@ bool LedgerDialog::exportList(QTextStream &outf, int fileformat) {
 	
 }
 void LedgerDialog::printView() {
-	if(transactionsView->childCount() == 0) {
+	if(transactionsView->topLevelItemCount() == 0) {
 		KMessageBox::error(this, i18n("Empty transaction list."));
 		return;
 	}
 	QString str;
-	QTextOStream stream(&str);
+	QTextStream stream(&str, QIODevice::WriteOnly);
 	exportList(stream, 'h');
 	KHTMLPart *htmlpart = new KHTMLPart(this);
 	htmlpart->begin();
@@ -335,14 +365,10 @@ void LedgerDialog::printView() {
 	delete htmlpart;
 }
 void LedgerDialog::joinTransactions() {
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
 	SplitTransaction *split = NULL;
-	LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
-	while(i) {
+	for(int index = 0; index < selection.size(); index++) {
+		LedgerListViewItem *i = (LedgerListViewItem*) selection[index];
 		Transaction *trans = i->transaction();
 		if(trans && !i->splitTransaction()) {
 			if(!split) {
@@ -350,7 +376,6 @@ void LedgerDialog::joinTransactions() {
 			}
 			split->splits.push_back(trans);
 		}
-		i = (LedgerListViewItem*) selection.next();
 	}
 	if(!split) return;
 	if(!mainWin->editSplitTransaction(split, this)) {
@@ -359,11 +384,7 @@ void LedgerDialog::joinTransactions() {
 	}
 }
 void LedgerDialog::splitUpTransaction() {
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
 	LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
 	if(i) {
 		if(i->splitTransaction()) mainWin->splitUpTransaction(i->splitTransaction());
@@ -371,19 +392,15 @@ void LedgerDialog::splitUpTransaction() {
 	}
 }
 void LedgerDialog::transactionSelectionChanged() {
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
-	bool selected = selection.count() > 0;
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
+	bool selected = !selection.isEmpty();
 	removeButton->setEnabled(selected);
 	editButton->setEnabled(selected);
 	bool b_join = selected;
 	bool b_split = selected;
 	SplitTransaction *split = NULL;
-	LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
-	while(i) {
+	for(int index = 0; index < selection.size(); index++) {
+		LedgerListViewItem *i = (LedgerListViewItem*) selection[index];
 		Transaction *trans = i->transaction();
 		if(!trans) {
 			removeButton->setEnabled(false);
@@ -404,7 +421,6 @@ void LedgerDialog::transactionSelectionChanged() {
 		if(b_join && trans->parentSplit()) {
 			b_join = false;
 		}
-		i = (LedgerListViewItem*) selection.next();
 	}	
 	joinButton->setEnabled(b_join);
 	splitUpButton->setEnabled(b_split);
@@ -422,19 +438,15 @@ void LedgerDialog::newSplit() {
 	mainWin->newSplitTransaction(this, account);
 }
 void LedgerDialog::remove() {
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
 	if(selection.count() > 1) {
 		if(KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) selected transactions?").arg(selection.count())) == KMessageBox::Cancel) {
 			return;
 		}
 	}
-	transactionsView->selectAll(false);
-	LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
-	while(i) {
+	transactionsView->clearSelection();
+	for(int index = 0; index < selection.size(); index++) {
+		LedgerListViewItem *i = (LedgerListViewItem*) selection[index];
 		if(i->splitTransaction()) {
 			budget->removeSplitTransaction(i->splitTransaction(), true);
 			mainWin->splitTransactionRemoved(i->splitTransaction());
@@ -444,17 +456,12 @@ void LedgerDialog::remove() {
 			mainWin->transactionRemoved(i->transaction());
 			delete i->transaction();
 		}
-		i = (LedgerListViewItem*) selection.next();
 	}
 }
 void LedgerDialog::edit() {
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
 	if(selection.count() == 1) {
-		LedgerListViewItem *i = (LedgerListViewItem*) selection.getFirst();
+		LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
 		if(i->splitTransaction()) mainWin->editSplitTransaction(i->splitTransaction(), this);
 		else if(!i->transaction()) mainWin->editAccount(account, this);
 		else if(i->transaction()->parentSplit()) mainWin->editSplitTransaction(i->transaction()->parentSplit(), this);
@@ -466,8 +473,8 @@ void LedgerDialog::edit() {
 		Transaction *comptrans = NULL;
 		Account *compcat = NULL;
 		QDate compdate;
-		LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
-		while(i) {
+		for(int index = 0; index < selection.size(); index++) {
+			LedgerListViewItem *i = (LedgerListViewItem*) selection[index];
 			if(!comptrans) {				
 				comptrans = i->transaction();
 				compdate = i->transaction()->date();
@@ -518,10 +525,9 @@ void LedgerDialog::edit() {
 					}
 				}
 			}
-			i = (LedgerListViewItem*) selection.next();
 		}
 		MultipleTransactionsEditDialog *dialog = new MultipleTransactionsEditDialog(b_extra, transtype, budget, this);
-		i = (LedgerListViewItem*) transactionsView->currentItem();
+		LedgerListViewItem *i = (LedgerListViewItem*) transactionsView->currentItem();
 		if(!i->isSelected()) i = (LedgerListViewItem*) selection.first();
 		if(i) {
 			dialog->setTransaction(i->transaction());
@@ -534,8 +540,8 @@ void LedgerDialog::edit() {
 		if(dialog->exec() == QDialog::Accepted) {
 			QDate date = dialog->date();
 			bool future = !date.isNull() && date > QDate::currentDate();
-			i = (LedgerListViewItem*) selection.first();
-			while(i) {
+			for(int index = 0; index < selection.size(); index++) {
+				LedgerListViewItem *i = (LedgerListViewItem*) selection[index];
 				if(!warned1 && (i->transaction()->type() == TRANSACTION_TYPE_SECURITY_BUY || i->transaction()->type() == TRANSACTION_TYPE_SECURITY_SELL)) {
 					if(dialog->valueButton && dialog->valueButton->isChecked()) {
 						KMessageBox::error(this, i18n("Cannot set the value of security transactions using the dialog for modifying multiple transactions."));
@@ -574,35 +580,32 @@ void LedgerDialog::edit() {
 					}
 				}
 				delete oldtrans;
-				i = (LedgerListViewItem*) selection.next();
 			}
 		}
 		dialog->deleteLater();
 	}
 }
-void LedgerDialog::edit(QListViewItem*) {
+void LedgerDialog::edit(QTreeWidgetItem*) {
 	edit();
 }
 void LedgerDialog::updateTransactions() {
-	int contents_x = transactionsView->contentsX();
-	int contents_y = transactionsView->contentsY();
+	/*int contents_x = transactionsView->contentsX();
+	int contents_y = transactionsView->contentsY();*/
+	int scroll_h = transactionsView->horizontalScrollBar()->value();
+	int scroll_v = transactionsView->verticalScrollBar()->value();
 	Transaction *selected_transaction = NULL;
 	SplitTransaction *selected_split = NULL;
-#if KDE_VERSION_MAJOR > 3 || KDE_VERSION_MINOR >= 4
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems(true);
-#else
-	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
-#endif
+	QList<QTreeWidgetItem*> selection = transactionsView->selectedItems();
 	if(selection.count() == 1) {
-		LedgerListViewItem *i = (LedgerListViewItem*) selection.getFirst();
+		LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
 		selected_split = i->splitTransaction();
 		if(!selected_split) selected_transaction = i->transaction();
 	}
 	transactionsView->clear();
 	double balance = account->initialBalance();
-	if(balance != 0.0) new LedgerListViewItem(NULL, NULL, transactionsView, "-", "-", "Initial balance", "-", QString::null, QString::null, KGlobal::locale()->formatMoney(balance));
+	if(balance != 0.0) transactionsView->insertTopLevelItem(0, new LedgerListViewItem(NULL, NULL, NULL, "-", "-", "Initial balance", "-", QString::null, QString::null, KGlobal::locale()->formatMoney(balance)));
 	Transaction *trans = budget->transactions.first();
-	QValueVector<SplitTransaction*> splits;
+	QVector<SplitTransaction*> splits;
 	while(trans) {
 		SplitTransaction *split_this = trans->parentSplit();
 		bool skip = false;
@@ -610,7 +613,7 @@ void LedgerDialog::updateTransactions() {
 			if(splits[splits.size() - 1]->date() != split_this->date()) {
 				splits.clear();
 			} else if(split_this) {
-				for(QValueVector<SplitTransaction*>::size_type i = 0; i < splits.size(); i++) {
+				for(QVector<SplitTransaction*>::size_type i = 0; i < splits.size(); i++) {
 					if(split_this == splits[i]) {
 						skip = true;
 						break;
@@ -632,12 +635,14 @@ void LedgerDialog::updateTransactions() {
 				value = -value;
 			}
 			if(split_this) {
-				LedgerListViewItem *i = new LedgerListViewItem(trans, split_this, transactionsView, KGlobal::locale()->formatDate(split_this->date(), true), i18n("Split Transaction"), split_this->description(), (value >= 0.0) ? KGlobal::locale()->formatMoney(value) : QString::null, QString::null, (value < 0.0) ? KGlobal::locale()->formatMoney(-value) : QString::null, KGlobal::locale()->formatMoney(balance));
+				LedgerListViewItem *i = new LedgerListViewItem(trans, split_this, NULL, KGlobal::locale()->formatDate(split_this->date(), KLocale::ShortDate), i18n("Split Transaction"), split_this->description(), QString::null, (value >= 0.0) ? KGlobal::locale()->formatMoney(value) : QString::null, (value < 0.0) ? KGlobal::locale()->formatMoney(-value) : QString::null, KGlobal::locale()->formatMoney(balance));
+				transactionsView->insertTopLevelItem(0, i); 
 				if(split_this == selected_split) {
-					transactionsView->setSelected(i, true);
+					i->setSelected(true);
 				}
 			} else {
-				LedgerListViewItem *i = new LedgerListViewItem(trans, NULL, transactionsView, KGlobal::locale()->formatDate(trans->date(), true), QString::null, trans->description(), deposit ? trans->fromAccount()->name() : trans->toAccount()->name(), (deposit && value >= 0.0) ? KGlobal::locale()->formatMoney(value < 0.0 ? -value : value) : QString::null, (deposit && value >= 0.0) ? QString::null : KGlobal::locale()->formatMoney(value < 0.0 ? -value : value), KGlobal::locale()->formatMoney(balance));
+				LedgerListViewItem *i = new LedgerListViewItem(trans, NULL, NULL, KGlobal::locale()->formatDate(trans->date(), KLocale::ShortDate), QString::null, trans->description(), deposit ? trans->fromAccount()->name() : trans->toAccount()->name(), (deposit && value >= 0.0) ? KGlobal::locale()->formatMoney(value < 0.0 ? -value : value) : QString::null, (deposit && value >= 0.0) ? QString::null : KGlobal::locale()->formatMoney(value < 0.0 ? -value : value), KGlobal::locale()->formatMoney(balance));
+				transactionsView->insertTopLevelItem(0, i); 
 				if(trans->type() == TRANSACTION_TYPE_INCOME) {
 					if(value >= 0.0) i->setText(1, i18n("Income"));
 					else i->setText(1, i18n("Repayment"));
@@ -647,13 +652,15 @@ void LedgerDialog::updateTransactions() {
 				} else if(trans->toAccount() == budget->balancingAccount || trans->fromAccount() == budget->balancingAccount) i->setText(1, i18n("Balancing"));
 				else i->setText(1, i18n("Transfer"));
 				if(trans == selected_transaction) {
-					transactionsView->setSelected(i, true);
+					i->setSelected(true);
 				}
 			}
 		}
 		trans = budget->transactions.next();
 	}
-	transactionsView->setContentsPos(contents_x, contents_y);
+	//transactionsView->setContentsPos(contents_x, contents_y);
+	transactionsView->horizontalScrollBar()->setValue(scroll_h);
+	transactionsView->verticalScrollBar()->setValue(scroll_v);
 }
 
 #include "ledgerdialog.moc"
