@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,17 +22,18 @@
 #ifndef LEDGER_DIALOG_H
 #define LEDGER_DIALOG_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <qtextstream.h>
 
 class Eqonomize;
 class AssetsAccount;
 class Budget;
-class KListView;
+class QTreeWidget;
+class QTreeWidgetItem;
 class QPushButton;
 class KComboBox;
 
-class LedgerDialog : public KDialogBase {
+class LedgerDialog : public KDialog {
 	
 	Q_OBJECT
 	
@@ -43,7 +44,7 @@ class LedgerDialog : public KDialogBase {
 		Budget *budget;
 		bool b_extra;
 		
-		KListView *transactionsView;
+		QTreeWidget *transactionsView;
 		QPushButton *editButton, *removeButton, *joinButton, *splitUpButton;
 		QPushButton *exportButton, *printButton;
 		KComboBox *accountCombo;
@@ -54,12 +55,16 @@ class LedgerDialog : public KDialogBase {
 		
 		LedgerDialog(AssetsAccount *acc, Eqonomize *parent, QString title, bool extra_parameters);
 		~LedgerDialog();
+		
+	public slots:
+	
+		void saveConfig();
 
 	protected slots:
 		
 		void remove();
 		void edit();
-		void edit(QListViewItem*);
+		void edit(QTreeWidgetItem*);
 		void transactionSelectionChanged();
 		void updateTransactions();
 		void updateAccounts();
