@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,15 +23,15 @@
 
 #include <qwidget.h>
 #include <qdatetime.h>
+#include <QResizeEvent>
 
 class Budget;
 class QPushButton;
 class QComboBox;
 class QRadioButton;
-class QCanvas;
-class QCanvasView;
+class QGraphicsScene;
+class QGraphicsView;
 class QButtonGroup;
-//class KDateEdit;
 class Account;
 class EqonomizeMonthSelector;
 
@@ -53,8 +53,8 @@ class OverTimeChart : public QWidget {
 		EqonomizeMonthSelector *startDateEdit, *endDateEdit;
 		QPushButton *saveButton, *printButton;
 		QRadioButton *dailyButton, *valueButton, *countButton, *perButton;
-		QCanvas *canvas;
-		QCanvasView *view;
+		QGraphicsScene *scene;
+		QGraphicsView *view;
 		QButtonGroup *valueGroup;
 		
 		QDate start_date, end_date;
@@ -64,9 +64,6 @@ class OverTimeChart : public QWidget {
 		int current_source;
 		bool has_empty_description, has_empty_payee;
 
-		int min_width;
-		int min_height;
-
 		void resizeEvent(QResizeEvent*);
 
 	public slots:
