@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,21 +22,22 @@
 #define QIF_IMPORT_EXPORT_H
 
 #include <qstring.h>
-#include <qtextstream.h>
+#include <QTextStream>
 
 #include "budget.h"
 
-#include <kwizard.h>
-#include <kdialogbase.h>
+#include <QWizard>
+#include <kdialog.h>
 #include <qmap.h>
 
 class Budget;
 class AssetsAccount;
 class KLineEdit;
 class KComboBox;
-class KURLRequester;
+class KUrlRequester;
 class QRadioButton;
-class KListView;
+class QTreeWidget;
+class QTreeWidgetItem;
 
 struct qif_info {
 	AssetsAccount *current_account;
@@ -56,7 +57,7 @@ struct qif_info {
 	int description_priority;
 };
 
-class ImportQIFDialog : public KWizard {
+class ImportQIFDialog : public QWizard {
 
 	Q_OBJECT
 	
@@ -65,9 +66,10 @@ class ImportQIFDialog : public KWizard {
 		Budget *budget;
 		qif_info qi;
 		bool b_extra;
+		int next_id;
 
-		KURLRequester *fileEdit;
-		KListView *defsView;
+		KUrlRequester *fileEdit;
+		QTreeWidget *defsView;
 		KComboBox *defsCombo, *dateFormatCombo, *accountCombo, *descriptionPriorityCombo;
 		KLineEdit *openingBalanceEdit;
 		QRadioButton *payeeAsDescriptionButton, *payeeAsPayeeButton, *memoAsDescriptionButton, *memoAsCommentButton;
@@ -77,18 +79,21 @@ class ImportQIFDialog : public KWizard {
 		
 		ImportQIFDialog(Budget *budg, QWidget *parent, bool extra_parameters);
 		~ImportQIFDialog();
+		
+		void showPage(int index);
+		int nextId() const;
 
 	protected slots:
 
-		void next();
+		void nextClicked();
 		void accept();
 		void onFileChanged(const QString&);
-		void defSelectionChanged(QListViewItem*);
+		void defSelectionChanged();
 		void defSelected(int);
 		
 };
 
-class ExportQIFDialog : public KDialogBase {
+class ExportQIFDialog : public KDialog {
 
 	Q_OBJECT
 
@@ -100,7 +105,7 @@ class ExportQIFDialog : public KDialogBase {
 
 		QRadioButton *descriptionAsSubcategoryButton, *descriptionAsPayeeButton, *descriptionAsMemoButton, *descriptionIgnoreButton;
 		KComboBox *accountCombo, *dateFormatCombo, *valueFormatCombo;
-		KURLRequester *fileEdit;
+		KUrlRequester *fileEdit;
 
 	public:
 
@@ -109,7 +114,7 @@ class ExportQIFDialog : public KDialogBase {
 
 	protected slots:
 		
-		void slotOk();
+		void slotButtonClicked(int);
 		void onFileChanged(const QString&);
 
 };
