@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,9 +29,6 @@
 #include <klocale.h>
 #include <kcalendarsystem.h>
 
-extern QDate addMonths(const QDate &date, int nmonths);
-extern QDate addYears(const QDate &date, int nyears);
-
 int months_between_dates(const QDate &date1, const QDate &date2) {
 	const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 	if(calSys->year(date1) == calSys->year(date2)) {
@@ -40,10 +37,10 @@ int months_between_dates(const QDate &date1, const QDate &date2) {
 	int months = calSys->monthsInYear(date1) - calSys->month(date1);
 	QDate yeardate;
 	calSys->setYMD(yeardate, calSys->year(date1), 1, 1);
-	yeardate = addYears(yeardate, 1);
+	yeardate = calSys->addYears(yeardate, 1);
 	while(calSys->year(yeardate) != calSys->year(date2)) {
 		months += calSys->monthsInYear(yeardate);
-		yeardate = addYears(yeardate, 1);
+		yeardate = calSys->addYears(yeardate, 1);
 	}
 	months += calSys->month(date2);
 	return months;
@@ -116,7 +113,7 @@ Recurrence::Recurrence(Budget *parent_budget, QDomElement *e, bool *valid) : o_b
 			}
 		}
 	}
-	qHeapSort(exceptions);
+	qSort(exceptions);
 }
 Recurrence::Recurrence(const Recurrence *rec) : o_budget(rec->budget()), d_startdate(rec->startDate()), d_enddate(rec->endDate()), i_count(rec->fixedOccurrenceCount()), exceptions(rec->exceptions) {}
 Recurrence::~Recurrence() {}
@@ -155,9 +152,9 @@ void Recurrence::updateDates() {
 			if(new_enddate.isNull()) {
 				i_count = i;
 				break;
-			}
-			d_enddate = new_enddate;
+			}			
 		}
+		d_enddate = new_enddate;
 		if(d_enddate.isNull()) {
 			d_enddate = d_startdate;
 		}
@@ -257,9 +254,9 @@ void Recurrence::setFixedOccurrenceCount(int new_count) {
 			if(new_enddate.isNull()) {
 				i_count = i;
 				break;
-			}
-			d_enddate = new_enddate;
+			}			
 		}
+		d_enddate = new_enddate;
 		if(d_enddate.isNull()) {
 			d_enddate = d_startdate;
 		}
@@ -278,10 +275,10 @@ void Recurrence::addException(const QDate &date) {
 		return;
 	}
 	exceptions.append(date);
-	qHeapSort(exceptions);
+	qSort(exceptions);
 }
 int Recurrence::findException(const QDate &date) const {
-	for(QValueVector<QDate>::size_type i = 0; i < exceptions.count(); i++) {
+	for(QVector<QDate>::size_type i = 0; i < exceptions.count(); i++) {
 		if(exceptions[i] == date) {
 			return (int) i;
 		}
@@ -293,7 +290,7 @@ bool Recurrence::hasException(const QDate &date) const {
 	return findException(date) >= 0;
 }
 bool Recurrence::removeException(const QDate &date) {
-	for(QValueVector<QDate>::iterator it = exceptions.begin(); it != exceptions.end(); ++it) {
+	for(QVector<QDate>::iterator it = exceptions.begin(); it != exceptions.end(); ++it) {
 		if(*it == date) {
 			exceptions.erase(it);
 			return true;
@@ -309,7 +306,7 @@ Budget *Recurrence::budget() const {return o_budget;}
 void Recurrence::save(QDomElement *e) const {
 	e->setAttribute("startdate", d_startdate.toString(Qt::ISODate));
 	if(d_enddate.isValid()) e->setAttribute("enddate", d_enddate.toString(Qt::ISODate));
-	for(QValueVector<QDate>::size_type i = 0; i < exceptions.count(); i++) {
+	for(QVector<QDate>::size_type i = 0; i < exceptions.count(); i++) {
 		QDomElement e2 = e->ownerDocument().createElement("exception");
 		e2.setAttribute("date", exceptions[i].toString(Qt::ISODate));
 		e->appendChild(e2);
@@ -399,13 +396,13 @@ WeeklyRecurrence::WeeklyRecurrence(Budget *parent_budget) : Recurrence(parent_bu
 WeeklyRecurrence::WeeklyRecurrence(Budget *parent_budget, QDomElement *e, bool *valid) : Recurrence(parent_budget, e, valid) {
 	i_frequency = e->attribute("frequency", "1").toInt();
 	QString days = e->attribute("days");
-	b_daysofweek[0] = days.find('1') >= 0;
-	b_daysofweek[1] = days.find('2') >= 0;
-	b_daysofweek[2] = days.find('3') >= 0;
-	b_daysofweek[3] = days.find('4') >= 0;
-	b_daysofweek[4] = days.find('5') >= 0;
-	b_daysofweek[5] = days.find('6') >= 0;
-	b_daysofweek[6] = days.find('7') >= 0;
+	b_daysofweek[0] = days.indexOf('1') >= 0;
+	b_daysofweek[1] = days.indexOf('2') >= 0;
+	b_daysofweek[2] = days.indexOf('3') >= 0;
+	b_daysofweek[3] = days.indexOf('4') >= 0;
+	b_daysofweek[4] = days.indexOf('5') >= 0;
+	b_daysofweek[5] = days.indexOf('6') >= 0;
+	b_daysofweek[6] = days.indexOf('7') >= 0;
 	if(valid) {
 		bool b = false;
 		for(int i = 0; i < 7; i++) {
@@ -542,13 +539,13 @@ void WeeklyRecurrence::save(QDomElement *e) const {
 	Recurrence::save(e);
 	e->setAttribute("frequency", i_frequency);
 	QString days;
-	if(b_daysofweek[0]) days += 1;
-	if(b_daysofweek[1]) days += 2;
-	if(b_daysofweek[2]) days += 3;
-	if(b_daysofweek[3]) days += 4;
-	if(b_daysofweek[4]) days += 5;
-	if(b_daysofweek[5]) days += 6;
-	if(b_daysofweek[6]) days += 7;
+	if(b_daysofweek[0]) days += '1';
+	if(b_daysofweek[1]) days += '2';
+	if(b_daysofweek[2]) days += '3';
+	if(b_daysofweek[3]) days += '4';
+	if(b_daysofweek[4]) days += '5';
+	if(b_daysofweek[5]) days += '6';
+	if(b_daysofweek[6]) days += '7';
 	e->setAttribute("days", days);
 }
 
@@ -588,14 +585,14 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 	if(calSys->month(nextdate) == calSys->month(startDate())) {
 		if(i_frequency > 1) prevday = 1;
 		else prevday = calSys->day(nextdate);
-		nextdate = addMonths(nextdate, i_frequency);
+		nextdate = calSys->addMonths(nextdate, i_frequency);
 		calSys->setYMD(nextdate, calSys->year(nextdate), calSys->month(nextdate), 1);
 	} else if(i_frequency != 1) {
 		int i = months_between_dates(startDate(), nextdate) % i_frequency;
 		if(i != 0) {
 			if(i_frequency - i > 1) prevday = 1;
 			else prevday = calSys->day(nextdate);
-			nextdate = addMonths(nextdate, i_frequency - i);
+			nextdate = calSys->addMonths(nextdate, i_frequency - i);
 			calSys->setYMD(nextdate, calSys->year(nextdate), calSys->month(nextdate), 1);
 		}
 	}
@@ -608,8 +605,8 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 		int wday = calSys->dayOfWeek(date);
 		if(wday == 6) day -= 1;
 		else if(wday == 7) day -= 2;
-		if(day <= 0 && prevday > 0 && prevday <= calSys->daysInMonth(addMonths(nextdate, -1)) + day) {
-			nextdate = addMonths(nextdate, -1);
+		if(day <= 0 && prevday > 0 && prevday <= calSys->daysInMonth(calSys->addMonths(nextdate, -1)) + day) {
+			nextdate = calSys->addMonths(nextdate, -1);
 			day = calSys->daysInMonth(nextdate) + day;
 		}
 	} else if(wh_weekendhandling == WEEKEND_HANDLING_AFTER) {
@@ -620,7 +617,7 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 		else if(wday == 7) day += 1;
 		if(day > calSys->daysInMonth(nextdate)) {
 			day -= calSys->daysInMonth(nextdate);
-			nextdate = addMonths(nextdate, 1);
+			nextdate = calSys->addMonths(nextdate, 1);
 			calSys->setYMD(nextdate, calSys->year(nextdate), calSys->month(nextdate), day);
 		}
 	}
@@ -628,7 +625,7 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 		do {
 			if(i_frequency > 1) prevday = 1;
 			else prevday = calSys->day(nextdate);
-			nextdate = addMonths(nextdate, i_frequency);
+			nextdate = calSys->addMonths(nextdate, i_frequency);
 			if(!endDate().isNull() && calSys->month(nextdate) > calSys->month(endDate())) return QDate();
 			day = i_day;
 			if(i_dayofweek > 0) day = get_day_in_month(nextdate, i_week, i_dayofweek);
@@ -639,8 +636,8 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 				int wday = calSys->dayOfWeek(date);
 				if(wday == 6) day -= 1;
 				else if(wday == 7) day -= 2;
-				if(day <= 0 && prevday > 0 && prevday <= calSys->daysInMonth(addMonths(nextdate, -1)) + day) {
-					nextdate = addMonths(nextdate, -1);
+				if(day <= 0 && prevday > 0 && prevday <= calSys->daysInMonth(calSys->addMonths(nextdate, -1)) + day) {
+					nextdate = calSys->addMonths(nextdate, -1);
 					day = calSys->daysInMonth(nextdate) + day;
 				} else {
 					calSys->setYMD(nextdate, calSys->year(nextdate), calSys->month(nextdate), 1);
@@ -653,7 +650,7 @@ QDate MonthlyRecurrence::nextOccurrence(const QDate &date, bool include_equals)
 				else if(wday == 7) day += 1;
 				if(day > calSys->daysInMonth(nextdate)) {
 					day -= calSys->daysInMonth(nextdate);
-					nextdate = addMonths(nextdate, 1);
+					nextdate = calSys->addMonths(nextdate, 1);
 					calSys->setYMD(nextdate, calSys->year(nextdate), calSys->month(nextdate), day);
 				}
 			}
@@ -680,7 +677,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 		if(i != 0) {
 			if(i > 1) prevday = 1;
 			else prevday = calSys->day(prevdate);
-			prevdate = addMonths(prevdate, -i);
+			prevdate = calSys->addMonths(prevdate, -i);
 			calSys->setYMD(prevdate, calSys->year(prevdate), calSys->month(prevdate), calSys->daysInMonth(prevdate));
 		}
 	}
@@ -695,7 +692,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 		if(wday == 6) day -= 1;
 		else if(wday == 7) day -= 2;
 		if(day <= 0) {
-			prevdate = addMonths(prevdate, -1);
+			prevdate = calSys->addMonths(prevdate, -1);
 			day = calSys->daysInMonth(prevdate) + day;
 		}
 	} else if(wh_weekendhandling == WEEKEND_HANDLING_AFTER) {
@@ -706,7 +703,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 		else if(wday == 7) day += 1;
 		if(day > calSys->daysInMonth(prevdate) && prevday > 0 && prevday >= day - calSys->daysInMonth(prevdate)) {
 			day -= calSys->daysInMonth(prevdate);
-			prevdate = addMonths(prevdate, 1);
+			prevdate = calSys->addMonths(prevdate, 1);
 			calSys->setYMD(prevdate, calSys->year(prevdate), calSys->month(prevdate), day);
 		}
 	}
@@ -714,7 +711,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 		do {
 			if(i_frequency > 1) prevday = 1;
 			else prevday = calSys->day(prevdate);
-			prevdate = addMonths(prevdate, -i_frequency);
+			prevdate = calSys->addMonths(prevdate, -i_frequency);
 			if(calSys->month(prevdate) == calSys->month(startDate())) return startDate();
 			if(calSys->month(prevdate) < calSys->month(startDate())) return QDate();
 			day = i_day;
@@ -727,7 +724,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 				if(wday == 6) day -= 1;
 				else if(wday == 7) day -= 2;
 				if(day <= 0) {
-					prevdate = addMonths(prevdate, -1);
+					prevdate = calSys->addMonths(prevdate, -1);
 					day = calSys->daysInMonth(prevdate) + day;
 				}
 			} else if(wh_weekendhandling == WEEKEND_HANDLING_AFTER) {
@@ -738,7 +735,7 @@ QDate MonthlyRecurrence::prevOccurrence(const QDate &date, bool include_equals)
 				else if(wday == 7) day += 1;
 				if(day > calSys->daysInMonth(prevdate) && prevday > 0 && prevday >= day - calSys->daysInMonth(prevdate)) {
 					day -= calSys->daysInMonth(prevdate);
-					prevdate = addMonths(prevdate, 1);
+					prevdate = calSys->addMonths(prevdate, 1);
 					calSys->setYMD(prevdate, calSys->year(prevdate), calSys->month(prevdate), day);
 				} else {
 					calSys->setYMD(prevdate, calSys->year(prevdate), calSys->month(prevdate), calSys->daysInMonth(prevdate));
@@ -836,24 +833,24 @@ QDate YearlyRecurrence::nextOccurrence(const QDate &date, bool include_equals) c
 	if(!include_equals) nextdate = calSys->addDays(nextdate, 1);
 	if(!endDate().isNull() && nextdate > endDate()) return QDate();
 	if(calSys->year(nextdate) == calSys->year(startDate())) {
-		nextdate = addYears(nextdate, i_frequency);
+		nextdate = calSys->addYears(nextdate, i_frequency);
 		calSys->setYMD(nextdate, calSys->year(nextdate), 1, 1);
 	} else if(i_frequency != 1) {
 		int i = (calSys->year(nextdate) - calSys->year(startDate())) % i_frequency;
 		if(i != 0) {
-			nextdate = addYears(nextdate, i_frequency - i);
+			nextdate = calSys->addYears(nextdate, i_frequency - i);
 			calSys->setYMD(nextdate, calSys->year(nextdate), 1, 1);
 		}
 	}
 	if(i_dayofyear > 0) {
 		if(calSys->dayOfYear(nextdate) > i_dayofyear) {
-			nextdate = addYears(nextdate, i_frequency);
+			nextdate = calSys->addYears(nextdate, i_frequency);
 		}
 		if(i_dayofyear > calSys->daysInYear(nextdate)) {
 			int i = 10;
 			do {
 				if(i == 0) return QDate();
-				nextdate = addYears(nextdate, i_frequency);
+				nextdate = calSys->addYears(nextdate, i_frequency);
 				i--;
 			} while(i_dayofyear > calSys->daysInYear(nextdate));
 		}
@@ -863,7 +860,7 @@ QDate YearlyRecurrence::nextOccurrence(const QDate &date, bool include_equals) c
 		if(i_dayofweek > 0) day = get_day_in_month(calSys->year(nextdate), i_month, i_week, i_dayofweek);
 		if(day == 0 || calSys->month(nextdate) > i_month || (calSys->month(nextdate) == i_month && calSys->day(nextdate) > day)) {
 			do {
-				nextdate = addYears(nextdate, i_frequency);
+				nextdate = calSys->addYears(nextdate, i_frequency);
 				day = get_day_in_month(calSys->year(nextdate), i_month, i_week, i_dayofweek);
 				if(!endDate().isNull() && calSys->year(nextdate) > calSys->year(endDate())) return QDate();
 			} while(day == 0);
@@ -874,7 +871,7 @@ QDate YearlyRecurrence::nextOccurrence(const QDate &date, bool include_equals) c
 				int i = 10;
 				do {
 					if(i == 0) return QDate();
-					nextdate = addYears(nextdate, i_frequency);
+					nextdate = calSys->addYears(nextdate, i_frequency);
 					calSys->setYMD(nextdate, calSys->year(nextdate), i_month, 1);
 					i--;
 				} while(day > calSys->daysInMonth(nextdate));
@@ -899,18 +896,18 @@ QDate YearlyRecurrence::prevOccurrence(const QDate &date, bool include_equals) c
 	if(i_frequency != 1) {
 		int i = (calSys->year(prevdate) - calSys->year(startDate())) % i_frequency;
 		if(i != 0) {
-			prevdate = addYears(prevdate, - i);
+			prevdate = calSys->addYears(prevdate, - i);
 		}
 	}
 	if(calSys->year(prevdate) == calSys->year(startDate())) return startDate();
 	if(i_dayofyear > 0) {
 		if(calSys->dayOfYear(prevdate) < i_dayofyear) {
-			prevdate = addYears(prevdate, -i_frequency);
+			prevdate = calSys->addYears(prevdate, -i_frequency);
 			if(calSys->year(prevdate) == calSys->year(startDate())) return startDate();
 		}
 		if(i_dayofyear > calSys->daysInYear(prevdate)) {
 			do {
-				prevdate = addYears(prevdate, -i_frequency);
+				prevdate = calSys->addYears(prevdate, -i_frequency);
 				if(calSys->year(prevdate) <= calSys->year(startDate())) return startDate();
 			} while(i_dayofyear > calSys->daysInYear(prevdate));
 		}
@@ -920,7 +917,7 @@ QDate YearlyRecurrence::prevOccurrence(const QDate &date, bool include_equals) c
 		if(i_dayofweek > 0) day = get_day_in_month(calSys->year(prevdate), i_month, i_week, i_dayofweek);
 		if(day <= 0 || calSys->month(prevdate) < i_month || (calSys->month(prevdate) == i_month && calSys->day(prevdate) < day)) {
 			do {
-				prevdate = addYears(prevdate, -i_frequency);
+				prevdate = calSys->addYears(prevdate, -i_frequency);
 				if(i_dayofweek > 0) day = get_day_in_month(calSys->year(prevdate), i_month, i_week, i_dayofweek);
 				if(calSys->year(prevdate) == calSys->year(startDate())) return startDate();
 			} while(day <= 0);
@@ -929,7 +926,7 @@ QDate YearlyRecurrence::prevOccurrence(const QDate &date, bool include_equals) c
 			calSys->setYMD(prevdate, calSys->year(prevdate), i_month, 1);
 			if(day > calSys->daysInMonth(prevdate)) {
 				do {
-					prevdate = addYears(prevdate, -i_frequency);
+					prevdate = calSys->addYears(prevdate, -i_frequency);
 					calSys->setYMD(prevdate, calSys->year(prevdate), i_month, 1);
 					if(calSys->year(prevdate) <= calSys->year(startDate())) return startDate();
 				} while(day > calSys->daysInMonth(prevdate));
