@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,7 @@
 
 #include <qstring.h>
 #include <qdatetime.h>
-#include <qvaluevector.h>
+#include <qvector.h>
 
 class Budget;
 class QDomElement;
@@ -74,7 +74,7 @@ class Recurrence {
 		Budget *budget() const;
 		virtual void save(QDomElement *e) const;
 
-		QValueVector<QDate> exceptions;
+		QVector<QDate> exceptions;
 
 };
 
