@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,23 +24,24 @@
 
 #include <qwidget.h>
 #include <qdatetime.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <qstringlist.h>
 
 class Recurrence;
 class Budget;
-class QWidgetStack;
+class QStackedWidget;
 class QCheckBox;
 class QSpinBox;
 class QComboBox;
 class QPushButton;
-class QVGroupBox;
+class QGroupBox;
 class QRadioButton;
 class KDateEdit;
 class QLabel;
 class EditRangeDialog;
 class EditExceptionsDialog;
 class QButtonGroup;
+class QListWidget;
 
 class RecurrenceEditWidget : public QWidget {
 
@@ -48,7 +49,7 @@ class RecurrenceEditWidget : public QWidget {
 	
 	public:
 
-		RecurrenceEditWidget(const QDate &startdate, Budget *budg, QWidget *parent = 0, const char *name = 0);
+		RecurrenceEditWidget(const QDate &startdate, Budget *budg, QWidget *parent = 0);
 		~RecurrenceEditWidget();
 		void setRecurrence(Recurrence *rec);
 		Recurrence *createRecurrence();
@@ -58,8 +59,8 @@ class RecurrenceEditWidget : public QWidget {
 
 		QDate date;
 		Budget *budget;
-		QVGroupBox *ruleGroup;
-		QWidgetStack *ruleStack;
+		QGroupBox *ruleGroup;
+		QStackedWidget *ruleStack;
 		QCheckBox *recurrenceButton;
 		QComboBox *typeCombo;
 		QPushButton *exceptionsButton, *rangeButton;
@@ -88,7 +89,7 @@ class RecurrenceEditWidget : public QWidget {
 		
 };
 
-class EditRangeDialog : public KDialogBase {
+class EditRangeDialog : public KDialog {
 
 	Q_OBJECT
 	
@@ -119,12 +120,11 @@ class EditRangeDialog : public KDialogBase {
 
 	protected slots:
 
-		void slotOk();
-		void slotCancel();
+		void slotButtonClicked(int);
 		
 };
 
-class EditExceptionsDialog : public KDialogBase {
+class EditExceptionsDialog : public KDialog {
 
 	Q_OBJECT
 	
@@ -132,7 +132,7 @@ class EditExceptionsDialog : public KDialogBase {
 
 		KDateEdit *dateEdit;
 		QPushButton *changeButton, *addButton, *deleteButton;
-		QListBox *exceptionsList;
+		QListWidget *exceptionsList;
 		QStringList savedExceptions;
 	
 	public:
@@ -147,8 +147,7 @@ class EditExceptionsDialog : public KDialogBase {
 
 	protected slots:
 
-		void slotOk();
-		void slotCancel();
+		void slotButtonClicked(int);
 		void onSelectionChanged();
 		void addException();
 		void changeException();
