@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,7 +32,6 @@
 #include <kcalendarsystem.h>
 
 extern double yearsBetweenDates(const QDate &date1, const QDate &date2);
-extern QDate addYears(const QDate &date, int nyears);
 
 void Security::init() {
 	transactions.setAutoDelete(false);
@@ -42,7 +41,7 @@ void Security::init() {
 	tradedShares.setAutoDelete(false);
 	reinvestedDividends.setAutoDelete(true);
 }
-Security::Security(Budget *parent_budget, AssetsAccount *parent_account, SecurityType initial_type, double initial_shares, int initial_decimals, QString initial_name, QString initial_description) : o_budget(parent_budget), i_id(-1), o_account(parent_account), st_type(initial_type), d_initial_shares(initial_shares), i_decimals(initial_decimals), s_name(initial_name.stripWhiteSpace()), s_description(initial_description) {
+Security::Security(Budget *parent_budget, AssetsAccount *parent_account, SecurityType initial_type, double initial_shares, int initial_decimals, QString initial_name, QString initial_description) : o_budget(parent_budget), i_id(-1), o_account(parent_account), st_type(initial_type), d_initial_shares(initial_shares), i_decimals(initial_decimals), s_name(initial_name.trimmed()), s_description(initial_description) {
 	init();
 }
 Security::Security(Budget *parent_budget, QDomElement *e, bool *valid) : o_budget(parent_budget) {
@@ -60,7 +59,7 @@ Security::Security(Budget *parent_budget, QDomElement *e, bool *valid) : o_budge
 	}
 	d_initial_shares = e->attribute("initialshares").toDouble();
 	i_decimals = e->attribute("decimals", "4").toInt();
-	s_name = e->attribute("name").stripWhiteSpace();
+	s_name = e->attribute("name").trimmed();
 	s_description = e->attribute("description");
 	int id_account = e->attribute("account").toInt();
 	if(parent_budget->assetsAccounts_id.contains(id_account)) {
@@ -86,14 +85,14 @@ Security::Security(const Security *security) : o_budget(security->budget()), i_i
 Security::~Security() {}
 
 const QString &Security::name() const {return s_name;}
-void Security::setName(QString new_name) {s_name = new_name.stripWhiteSpace(); o_budget->securityNameModified(this);}
+void Security::setName(QString new_name) {s_name = new_name.trimmed(); o_budget->securityNameModified(this);}
 const QString &Security::description() const {return s_description;}
 void Security::setDescription(QString new_description) {s_description = new_description;}
 Budget *Security::budget() const {return o_budget;}
 double Security::initialBalance() const {
 	QMap<QDate, double>::const_iterator it = quotations.begin();
 	if(it == quotations.end()) return 0.0;
-	return it.data() * d_initial_shares;
+	return it.value() * d_initial_shares;
 }
 double Security::initialShares() const {return d_initial_shares;}
 void Security::setInitialShares(double initial_shares) {d_initial_shares = initial_shares;}
@@ -114,8 +113,8 @@ void Security::setQuotation(const QDate &date, double value, bool auto_added) {
 }
 void Security::removeQuotation(const QDate &date, bool auto_added) {
 	if(quotations.count(date) && (!auto_added || quotations_auto[date])) {
-		quotations.erase(date);
-		quotations_auto.erase(date);
+		quotations.remove(date);
+		quotations_auto.remove(date);
 	}
 }
 void Security::clearQuotations() {
@@ -134,7 +133,7 @@ double Security::getQuotation(const QDate &date, QDate *actual_date) const {
 		while(true) {
 			if(it.key() <= date) {
 				if(actual_date) *actual_date = it.key();
-				return it.data();
+				return it.value();
 			}
 			if(it == it_begin) break;
 			--it;
@@ -169,9 +168,9 @@ void Security::save(QDomElement *e) const {
 	QMap<QDate, bool>::const_iterator it_auto = quotations_auto.begin();
 	for(; it != it_end; ++it, ++it_auto) {
 		QDomElement e2 = e->ownerDocument().createElement("quotation");
-		e2.setAttribute("value", QString::number(it.data(), 'f', KGlobal::locale()->fracDigits()));
+		e2.setAttribute("value", QString::number(it.value(), 'f', KGlobal::locale()->fracDigits()));
 		e2.setAttribute("date", it.key().toString(Qt::ISODate));
-		if(it_auto.data()) e2.setAttribute("auto", it_auto.data());
+		if(it_auto.value()) e2.setAttribute("auto", it_auto.value());
 		e->appendChild(e2);
 	}
 }
@@ -239,7 +238,7 @@ double Security::shares(const QDate &date, bool estimate, bool no_scheduled_shar
 		}
 		int years = days2 / calSys->daysInYear(date1);
 		if(years == 0) years = 1;
-		QDate date2 = addYears(date1, -years);
+		QDate date2 = calSys->addYears(date1, -years);
 		double n2 = 0.0;
 		rediv = reinvestedDividends.first();
 		while(trans) {
@@ -265,7 +264,7 @@ double Security::cost(const QDate &date, bool no_scheduled_shares) {
 	double c = d_initial_shares;
 	QMap<QDate, double>::const_iterator it = quotations.begin();
 	if(it == quotations.end() || date < it.key()) c = 0.0;
-	else c *= it.data();
+	else c *= it.value();
 	SecurityTransaction *trans = transactions.first();
 	while(trans && trans->date() <= date) {
 		if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) c += trans->value();
@@ -295,7 +294,7 @@ double Security::cost() {
 	double c = d_initial_shares;
 	QMap<QDate, double>::const_iterator it = quotations.begin();
 	if(it == quotations.end()) c = 0.0;
-	else c *= it.data();
+	else c *= it.value();
 	SecurityTransaction *trans = transactions.first();
 	while(trans) {
 		if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) c += trans->value();
@@ -337,7 +336,7 @@ double Security::profit(const QDate &date, bool estimate, bool no_scheduled_shar
 		}
 		int years = days2 / calSys->daysInYear(date1);
 		if(years == 0) years = 1;
-		QDate date2 = addYears(date1, -years);
+		QDate date2 = calSys->addYears(date1, -years);
 		double p2 = 0.0;
 		trans = dividends.first();
 		while(trans) {
@@ -370,7 +369,7 @@ double Security::yearlyRate() {
 	if(it_end == it_begin) return 0.0;
 	it_end--;
 	QDate date1 = it_begin.key(), date2 = QDate::currentDate();
-	double q1 = it_begin.data(), q2 = it_end.data();
+	double q1 = it_begin.value(), q2 = it_end.value();
 	int days = date1.daysTo(date2);
 	if(it_end.key() != date2 && q1 != q2) {
 		int days2 = it_end.key().daysTo(date2);
@@ -408,7 +407,7 @@ double Security::yearlyRate(const QDate &date) {
 		return ((rate1 * days1) + (rate2 * days2)) / (days1 + days2);
 	}
 	QDate date2_q;
-	double q1 = it_begin.data(), q2 = getQuotation(date2, &date2_q);
+	double q1 = it_begin.value(), q2 = getQuotation(date2, &date2_q);
 	int days = date1.daysTo(date2);
 	if(date2 != date2_q && q1 != q2) {
 		int days2 = date2_q.daysTo(date2);
@@ -497,18 +496,18 @@ double Security::expectedQuotation(const QDate &date) {
 	QMap<QDate, double>::const_iterator it = quotations.end();
 	if(it == it_begin) return 0.0;
 	--it;
-	if(it == it_begin) return it_begin.data();
+	if(it == it_begin) return it_begin.value();
 	if(date < it_begin.key()) {
 		const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 		int days = date.daysTo(it_begin.key());
 		double q2 = expectedQuotation(calSys->addDays(it_begin.key(), days));
-		return it_begin.data() * (it_begin.data() / q2);
+		return it_begin.value() * (it_begin.value() / q2);
 	}
 	if(it.key() < date) {
 		const KCalendarSystem *calSys = KGlobal::locale()->calendar();
 		int days = it.key().daysTo(date);
 		double q1 = expectedQuotation(calSys->addDays(it.key(), -days));
-		return it.data() * (it.data() / q1);
+		return it.value() * (it.value() / q1);
 	}
 	--it;
 	while(true) {
@@ -516,9 +515,9 @@ double Security::expectedQuotation(const QDate &date) {
 			it_begin = it;
 			++it;
 			int days = it_begin.key().daysTo(date), days2 = it_begin.key().daysTo(it.key());
-			if(it.data() == it_begin.data()) return it.data();
-			double rate = it.data() / it_begin.data();
-			return it_begin.data() * pow(rate, days / days2);
+			if(it.value() == it_begin.value()) return it.value();
+			double rate = it.value() / it_begin.value();
+			return it_begin.value() * pow(rate, days / days2);
 		}
 		if(it == it_begin) break;
 		--it;
