@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,14 +32,14 @@
 #include <klocale.h>
 #include <kglobal.h>
 
-Transaction::Transaction(Budget *parent_budget, double initial_value, QDate initial_date, Account *from, Account *to, QString initial_description, QString initial_comment) : o_budget(parent_budget), d_value(initial_value), d_date(initial_date), o_from(from), o_to(to), s_description(initial_description.stripWhiteSpace()), s_comment(initial_comment), d_quantity(1.0), o_split(NULL) {
+Transaction::Transaction(Budget *parent_budget, double initial_value, QDate initial_date, Account *from, Account *to, QString initial_description, QString initial_comment) : o_budget(parent_budget), d_value(initial_value), d_date(initial_date), o_from(from), o_to(to), s_description(initial_description.trimmed()), s_comment(initial_comment), d_quantity(1.0), o_split(NULL) {
 	if(s_description.isNull()) s_description = emptystr;
 }
 Transaction::Transaction(Budget *parent_budget, QDomElement *e, bool *valid) : o_budget(parent_budget) {
 	o_split = NULL;
 	o_from = NULL; o_to = NULL;
 	d_date = QDate::fromString(e->attribute("date"), Qt::ISODate);
-	s_description = e->attribute("description", emptystr).stripWhiteSpace();
+	s_description = e->attribute("description", emptystr).trimmed();
 	s_comment = e->attribute("comment", emptystr);
 	d_quantity = e->attribute("quantity", "1.0").toDouble();
 	if(valid) *valid = d_date.isValid();
@@ -70,7 +70,7 @@ void Transaction::setQuantity(double new_quantity) {d_quantity = new_quantity;}
 const QDate &Transaction::date() const {return d_date;}
 void Transaction::setDate(QDate new_date) {QDate old_date = d_date; d_date = new_date; o_budget->transactionDateModified(this, old_date);}
 const QString &Transaction::description() const {return s_description;}
-void Transaction::setDescription(QString new_description) {s_description = new_description.stripWhiteSpace();}
+void Transaction::setDescription(QString new_description) {s_description = new_description.trimmed();}
 const QString &Transaction::comment() const {return s_comment;}
 void Transaction::setComment(QString new_comment) {s_comment = new_comment;}
 Account *Transaction::fromAccount() const {return o_from;}
@@ -604,11 +604,11 @@ void ScheduledTransaction::addException(const QDate &exceptiondate) {
 	}
 }
 
-SplitTransaction::SplitTransaction(Budget *parent_budget, QDate initial_date, AssetsAccount *initial_account, QString initial_description) : o_budget(parent_budget), d_date(initial_date), o_account(initial_account), s_description(initial_description.stripWhiteSpace()) {}
+SplitTransaction::SplitTransaction(Budget *parent_budget, QDate initial_date, AssetsAccount *initial_account, QString initial_description) : o_budget(parent_budget), d_date(initial_date), o_account(initial_account), s_description(initial_description.trimmed()) {}
 SplitTransaction::SplitTransaction(Budget *parent_budget, QDomElement *e, bool *valid) : o_budget(parent_budget) {
 	o_account = NULL;
 	d_date = QDate::fromString(e->attribute("date"), Qt::ISODate);
-	s_description = e->attribute("description", emptystr).stripWhiteSpace();
+	s_description = e->attribute("description", emptystr).trimmed();
 	s_comment = e->attribute("comment", emptystr);
 	int id = e->attribute("account").toInt();
 	if(d_date.isValid() && parent_budget->assetsAccounts_id.contains(id)) {
@@ -667,8 +667,8 @@ SplitTransaction::~SplitTransaction() {
 
 double SplitTransaction::value() const {
 	double d_value = 0.0;
-	QValueVector<Transaction*>::size_type c = splits.size();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = splits.size();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		Transaction *trans = splits[i];
 		if(trans->fromAccount() == o_account) d_value -= trans->value();
 		if(trans->toAccount() == o_account) d_value += trans->value();
@@ -704,8 +704,8 @@ void SplitTransaction::addTransaction(Transaction *trans) {
 	trans->setParentSplit(this);
 }
 void SplitTransaction::removeTransaction(Transaction *trans, bool keep) {
-	QValueVector<Transaction*>::iterator it_e = splits.end();
-	for(QValueVector<Transaction*>::iterator it = splits.begin(); it != it_e; ++it) {
+	QVector<Transaction*>::iterator it_e = splits.end();
+	for(QVector<Transaction*>::iterator it = splits.begin(); it != it_e; ++it) {
 		if(*it == trans) {
 			splits.erase(it);
 			break;
@@ -715,8 +715,8 @@ void SplitTransaction::removeTransaction(Transaction *trans, bool keep) {
 	o_budget->removeTransaction(trans, keep);
 }
 void SplitTransaction::clear(bool keep) {
-	QValueVector<Transaction*>::iterator it_e = splits.end();
-	for(QValueVector<Transaction*>::iterator it = splits.begin(); it != it_e; ++it) {
+	QVector<Transaction*>::iterator it_e = splits.end();
+	for(QVector<Transaction*>::iterator it = splits.begin(); it != it_e; ++it) {
 		(*it)->setParentSplit(NULL);
 		if(!keep) o_budget->removeTransaction(*it);
 	}
@@ -725,19 +725,19 @@ void SplitTransaction::clear(bool keep) {
 const QDate &SplitTransaction::date() const {return d_date;}
 void SplitTransaction::setDate(QDate new_date) {
 	QDate old_date = d_date; d_date = new_date; o_budget->splitTransactionDateModified(this, old_date);
-	QValueVector<Transaction*>::size_type c = splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		splits[i]->setDate(d_date);
 	}
 }
 const QString &SplitTransaction::description() const {return s_description;}
-void SplitTransaction::setDescription(QString new_description) {s_description = new_description.stripWhiteSpace();}
+void SplitTransaction::setDescription(QString new_description) {s_description = new_description.trimmed();}
 const QString &SplitTransaction::comment() const {return s_comment;}
 void SplitTransaction::setComment(QString new_comment) {s_comment = new_comment;}
 AssetsAccount *SplitTransaction::account() const {return o_account;}
 void SplitTransaction::setAccount(AssetsAccount *new_account) {
-	QValueVector<Transaction*>::size_type c = splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		Transaction *trans = splits[i];
 		switch(trans->type()) {
 			case TRANSACTION_TYPE_EXPENSE: {
@@ -771,8 +771,8 @@ void SplitTransaction::save(QDomElement *e) const {
 	e->setAttribute("account", o_account->id());
 	if(!s_description.isEmpty()) e->setAttribute("description", s_description);
 	if(!s_comment.isEmpty())  e->setAttribute("comment", s_comment);
-	QValueVector<Transaction*>::size_type c = splits.count();
-	for(QValueVector<Transaction*>::size_type i = 0; i < c; i++) {
+	QVector<Transaction*>::size_type c = splits.count();
+	for(QVector<Transaction*>::size_type i = 0; i < c; i++) {
 		QDomElement e2 = e->ownerDocument().createElement("transaction");
 		Transaction *trans = splits[i];
 		trans->save(&e2);
