@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,46 +33,45 @@
 #include <kiconloader.h>
 #include <kdeversion.h>
 #include <kstatusbar.h>
-#include <kaccel.h>
 #include <kio/netaccess.h>
 #include <kfiledialog.h>
 #include <kconfig.h>
 #include <kurl.h>
-#include <kurldrag.h>
-#include <qheader.h>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QVBoxLayout>
 #include <kmessagebox.h>
 #include <qlayout.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include "kdateedit.h"
 #include <qlabel.h>
-#include <kbuttonbox.h>
+#include <KDialogButtonBox>
 #include <kstdguiitem.h>
 #include <kstdaccel.h>
 #include <kaction.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <qobject.h>
 #include <qpushbutton.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <qlabel.h>
 #include <kseparator.h>
 #include <qcheckbox.h>
-#include <kjanuswidget.h>
+#include <kpagewidget.h>
 #include <qradiobutton.h>
-#include <qgroupbox.h>
 #include <kpushbutton.h>
 #include <ktextedit.h>
-#include <qbuttongroup.h>
-#include <qhbox.h>
+#include <khbox.h>
 
 extern double monthsBetweenDates(const QDate &date1, const QDate &d2);
 
 #define TEROWCOL(row, col)	row % rows, ((row / rows) * 2) + col
 
-TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *sec, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent, const char *name) : QWidget(parent, name), transtype(transaction_type), budget(budg), security(sec), b_autoedit(auto_edit), b_extra(extra_parameters) {
+TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *sec, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent) : QWidget(parent), transtype(transaction_type), budget(budg), security(sec), b_autoedit(auto_edit), b_extra(extra_parameters) {
 	value_set = false; shares_set = false; sharevalue_set = false;
 	b_sec = (transtype == TRANSACTION_TYPE_SECURITY_BUY || transtype == TRANSACTION_TYPE_SECURITY_SELL);
-	QVBoxLayout *editVLayout = new QVBoxLayout(this, 0, 6);
+	QVBoxLayout *editVLayout = new QVBoxLayout(this);
+	editVLayout->setContentsMargins(0, 0, 0, 0);
 	int cols = 1;
 	if(auto_edit) cols = 2;
 	int rows = 6;
@@ -80,7 +79,8 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 	else if(b_extra && !security && !select_security && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) rows = 8;
 	if(rows % cols > 0) rows += rows / cols + 1;
 	else rows = rows / cols;	
-	QGridLayout *editLayout = new QGridLayout(editVLayout, rows, cols * 2);
+	QGridLayout *editLayout = new QGridLayout();
+	editVLayout->addLayout(editLayout);
 	dateEdit = NULL;
 	sharesEdit = NULL;
 	quotationEdit = NULL;
@@ -101,8 +101,8 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 			Security *c_sec = budget->securities.first();
 			int i2 = 0;
 			while(c_sec) {
-				securityCombo->insertItem(c_sec->name());
-				if(c_sec == security) securityCombo->setCurrentItem(i2);
+				securityCombo->addItem(c_sec->name());
+				if(c_sec == security) securityCombo->setCurrentIndex(i2);
 				c_sec = budget->securities.next();
 				i2++;
 			}
@@ -128,9 +128,9 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 				i++;
 			} else {
 				editLayout->addWidget(new QLabel(i18n("Shares sold:"), this), TEROWCOL(i, 0));
-				QHBoxLayout *sharesLayout = new QHBoxLayout(0);
+				QHBoxLayout *sharesLayout = new QHBoxLayout();
 				sharesEdit = new EqonomizeValueEdit(0.0, decimals, false, false, this);
-				sharesEdit->setSizePolicy(QSizePolicy::Expanding, sharesEdit->sizePolicy().verData());
+				sharesEdit->setSizePolicy(QSizePolicy::Expanding, sharesEdit->sizePolicy().verticalPolicy());
 				sharesLayout->addWidget(sharesEdit);
 				maxSharesButton = new QPushButton(i18n("All"), this);
 				maxSharesButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
@@ -148,6 +148,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 		if(!split) {
 			editLayout->addWidget(new QLabel(i18n("Date:"), this), TEROWCOL(i, 0));
 			dateEdit = new KDateEdit(this);
+			dateEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 			editLayout->addWidget(dateEdit, TEROWCOL(i, 1));
 		}
 		i++;
@@ -160,8 +161,8 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 				Security *c_sec = budget->securities.first();
 				int i2 = 0;
 				while(c_sec) {
-					securityCombo->insertItem(c_sec->name());
-					if(c_sec == security) securityCombo->setCurrentItem(i2);
+					securityCombo->addItem(c_sec->name());
+					if(c_sec == security) securityCombo->setCurrentIndex(i2);
 					c_sec = budget->securities.next();
 					i2++;
 				}
@@ -197,6 +198,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 		if(!split) {
 			editLayout->addWidget(new QLabel(i18n("Date:"), this), TEROWCOL(i, 0));
 			dateEdit = new KDateEdit(this);
+			dateEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 			editLayout->addWidget(dateEdit, TEROWCOL(i, 1));
 			i++;
 		}
@@ -287,7 +289,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 	commentsEdit = new KLineEdit(this);
 	editLayout->addWidget(commentsEdit, TEROWCOL(i, 1));
 	i++;
-	bottom_widget = new QHBox(this);
+	bottom_widget = new KHBox(this);
 	editVLayout->addWidget(bottom_widget);
 	editVLayout->addStretch(1);
 
@@ -364,7 +366,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 			connect(descriptionEdit, SIGNAL(textChanged(const QString&)), this, SLOT(descriptionChanged(const QString&)));
 		}		
 	}
-	if(b_autoedit && dateEdit) connect(dateEdit, SIGNAL(returnPressed()), this, SIGNAL(addmodify()));
+	if(b_autoedit && dateEdit) connect(dateEdit->lineEdit(), SIGNAL(returnPressed()), this, SIGNAL(addmodify()));
 	if(payeeEdit) connect(payeeEdit, SIGNAL(returnPressed()), commentsEdit, SLOT(setFocus()));
 	if(b_autoedit) connect(commentsEdit, SIGNAL(returnPressed()), this, SIGNAL(addmodify()));
 	if(securityCombo) connect(securityCombo, SIGNAL(activated(int)), this, SLOT(securityChanged()));
@@ -450,21 +452,21 @@ void TransactionEditWidget::descriptionChanged(const QString&) {
 }
 void TransactionEditWidget::setDefaultValue() {
 	if(descriptionEdit && description_changed && !descriptionEdit->text().isEmpty() && valueEdit && valueEdit->value() == 0.0) {
-		Transaction *trans = default_values.find(descriptionEdit->text());
+		Transaction *trans = default_values[descriptionEdit->text()];
 		if(trans) {
 			valueEdit->setValue(trans->value());
 			if(toCombo) {
-				for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+				for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 					if(trans->toAccount() == tos[i]) {
-						toCombo->setCurrentItem(i);
+						toCombo->setCurrentIndex(i);
 						break;
 					}
 				}
 			}
 			if(fromCombo) {
-				for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+				for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 					if(trans->fromAccount() == froms[i]) {
-						fromCombo->setCurrentItem(i);
+						fromCombo->setCurrentIndex(i);
 						break;
 					}
 				}
@@ -488,14 +490,14 @@ void TransactionEditWidget::updateFromAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && (b_autoedit || ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES)) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
 			}
-			for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 				if(froms[i] != budget->balancingAccount && ((AssetsAccount*) froms[i])->accountType() != ASSETS_TYPE_SECURITIES) {
-					fromCombo->setCurrentItem((int) i);
+					fromCombo->setCurrentIndex((int) i);
 					break;
 				}
 			}
@@ -505,14 +507,14 @@ void TransactionEditWidget::updateFromAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && account != budget->balancingAccount && ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
 			}
-			for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 				if(froms[i] != budget->balancingAccount && ((AssetsAccount*) froms[i])->accountType() != ASSETS_TYPE_SECURITIES) {
-					fromCombo->setCurrentItem((int) i);
+					fromCombo->setCurrentIndex((int) i);
 					break;
 				}
 			}
@@ -522,7 +524,7 @@ void TransactionEditWidget::updateFromAccounts(Account *exclude_account) {
 			account = budget->incomesAccounts.first();
 			while(account) {
 				if(account != exclude_account) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 				}
 				account = budget->incomesAccounts.next();
@@ -533,7 +535,7 @@ void TransactionEditWidget::updateFromAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && account != budget->balancingAccount && ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
@@ -541,7 +543,7 @@ void TransactionEditWidget::updateFromAccounts(Account *exclude_account) {
 			account = budget->incomesAccounts.first();
 			while(account) {
 				if(account != exclude_account) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 					account = budget->incomesAccounts.next();
 				}
@@ -563,14 +565,14 @@ void TransactionEditWidget::updateToAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && (b_autoedit || ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES)) {
-					toCombo->insertItem(account->name());
+					toCombo->addItem(account->name());
 					tos.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
 			}
-			for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 				if(tos[i] != budget->balancingAccount && ((AssetsAccount*) tos[i])->accountType() != ASSETS_TYPE_SECURITIES) {
-					toCombo->setCurrentItem((int) i);
+					toCombo->setCurrentIndex((int) i);
 					break;
 				}
 			}
@@ -580,14 +582,14 @@ void TransactionEditWidget::updateToAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && account != budget->balancingAccount && (b_autoedit || ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES)) {
-					toCombo->insertItem(account->name());
+					toCombo->addItem(account->name());
 					tos.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
 			}
-			for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 				if(tos[i] != budget->balancingAccount && ((AssetsAccount*) tos[i])->accountType() != ASSETS_TYPE_SECURITIES) {
-					toCombo->setCurrentItem((int) i);
+					toCombo->setCurrentIndex((int) i);
 					break;
 				}
 			}
@@ -597,7 +599,7 @@ void TransactionEditWidget::updateToAccounts(Account *exclude_account) {
 			account = budget->expensesAccounts.first();
 			while(account) {
 				if(account != exclude_account) {
-					toCombo->insertItem(account->name());
+					toCombo->addItem(account->name());
 					tos.push_back(account);
 				}
 				account = budget->expensesAccounts.next();
@@ -611,7 +613,7 @@ void TransactionEditWidget::updateToAccounts(Account *exclude_account) {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != exclude_account && account != budget->balancingAccount && ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES) {
-					toCombo->insertItem(account->name());
+					toCombo->addItem(account->name());
 					tos.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
@@ -628,7 +630,7 @@ void TransactionEditWidget::transactionAdded(Transaction *trans) {
 	if(descriptionEdit && trans->type() == transtype && (transtype != TRANSACTION_TYPE_INCOME || !((Income*) trans)->security())) {
 		if(!trans->description().isEmpty()) {
 			descriptionEdit->completionObject()->addItem(trans->description());
-			default_values.replace(trans->description(), trans);
+			default_values[trans->description()] = trans;
 		}
 		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE && !((Expense*) trans)->payee().isEmpty()) payeeEdit->completionObject()->addItem(((Expense*) trans)->payee());
 		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME && !((Income*) trans)->security() && !((Income*) trans)->payer().isEmpty()) payeeEdit->completionObject()->addItem(((Income*) trans)->payer());
@@ -638,7 +640,7 @@ void TransactionEditWidget::transactionModified(Transaction *trans) {
 	if(descriptionEdit && trans->type() == transtype && (transtype != TRANSACTION_TYPE_INCOME || !((Income*) trans)->security())) {
 		if(!trans->description().isEmpty()) {
 			descriptionEdit->completionObject()->addItem(trans->description());
-			default_values.replace(trans->description(), trans);
+			default_values[trans->description()] = trans;
 		}
 		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE && !((Expense*) trans)->payee().isEmpty()) payeeEdit->completionObject()->addItem(((Expense*) trans)->payee());
 		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME && !((Income*) trans)->security() && !((Income*) trans)->payer().isEmpty()) payeeEdit->completionObject()->addItem(((Income*) trans)->payer());
@@ -708,20 +710,20 @@ bool TransactionEditWidget::validValues(bool) {
 		return false;
 	}
 	if(!checkAccounts()) return false;
-	if(toCombo && fromCombo && tos[toCombo->currentItem()] == froms[fromCombo->currentItem()]) {
+	if(toCombo && fromCombo && tos[toCombo->currentIndex()] == froms[fromCombo->currentIndex()]) {
 		KMessageBox::error(this, i18n("Cannot transfer money to and from the same account."));
 		return false;
 	}
 	switch(transtype) {
 		case TRANSACTION_TYPE_TRANSFER: {
-			if((toCombo && tos[toCombo->currentItem()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) tos[toCombo->currentItem()])->accountType() == ASSETS_TYPE_SECURITIES) || (fromCombo && froms[fromCombo->currentItem()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) froms[fromCombo->currentItem()])->accountType() == ASSETS_TYPE_SECURITIES)) {
+			if((toCombo && tos[toCombo->currentIndex()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) tos[toCombo->currentIndex()])->accountType() == ASSETS_TYPE_SECURITIES) || (fromCombo && froms[fromCombo->currentIndex()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) froms[fromCombo->currentIndex()])->accountType() == ASSETS_TYPE_SECURITIES)) {
 				KMessageBox::error(this, i18n("Cannot create a regular transfer to/from a securities account."));
 				return false;
 			}
 			break;
 		}
 		case TRANSACTION_TYPE_INCOME: {
-			if(toCombo && tos[toCombo->currentItem()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) tos[toCombo->currentItem()])->accountType() == ASSETS_TYPE_SECURITIES) {
+			if(toCombo && tos[toCombo->currentIndex()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) tos[toCombo->currentIndex()])->accountType() == ASSETS_TYPE_SECURITIES) {
 				KMessageBox::error(this, i18n("Cannot create a regular income to a securities account."));
 				return false;
 			}
@@ -749,7 +751,7 @@ bool TransactionEditWidget::validValues(bool) {
 			break;
 		}
 		default: {			
-			if(fromCombo && froms[fromCombo->currentItem()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) froms[fromCombo->currentItem()])->accountType() == ASSETS_TYPE_SECURITIES) {
+			if(fromCombo && froms[fromCombo->currentIndex()]->type() == ACCOUNT_TYPE_ASSETS && ((AssetsAccount*) froms[fromCombo->currentIndex()])->accountType() == ASSETS_TYPE_SECURITIES) {
 				KMessageBox::error(this, i18n("Cannot create a regular expense from a securities account."));
 				return false;
 			}
@@ -764,9 +766,9 @@ bool TransactionEditWidget::modifyTransaction(Transaction *trans) {
 	if(b_sec) {
 		if(trans->type() != transtype) return false;
 		if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY) {
-			if(fromCombo) ((SecurityTransaction*) trans)->setAccount(froms[fromCombo->currentItem()]);
+			if(fromCombo) ((SecurityTransaction*) trans)->setAccount(froms[fromCombo->currentIndex()]);
 		} else {
-			if(toCombo) ((SecurityTransaction*) trans)->setAccount(tos[toCombo->currentItem()]);
+			if(toCombo) ((SecurityTransaction*) trans)->setAccount(tos[toCombo->currentIndex()]);
 		}
 		if(dateEdit) trans->setDate(dateEdit->date());
 		double shares = 0.0, value = 0.0, share_value = 0.0;
@@ -785,8 +787,8 @@ bool TransactionEditWidget::modifyTransaction(Transaction *trans) {
 		return false;
 	}
 	if(dateEdit) trans->setDate(dateEdit->date());
-	if(fromCombo) trans->setFromAccount(froms[fromCombo->currentItem()]);
-	if(toCombo) trans->setToAccount(tos[toCombo->currentItem()]);
+	if(fromCombo) trans->setFromAccount(froms[fromCombo->currentIndex()]);
+	if(toCombo) trans->setToAccount(tos[toCombo->currentIndex()]);
 	trans->setValue(valueEdit->value());
 	if(descriptionEdit && (trans->type() != TRANSACTION_TYPE_INCOME || !((Income*) trans)->security())) trans->setDescription(descriptionEdit->text());
 	trans->setComment(commentsEdit->text());
@@ -797,7 +799,7 @@ bool TransactionEditWidget::modifyTransaction(Transaction *trans) {
 }
 Security *TransactionEditWidget::selectedSecurity() {
 	if(securityCombo) {
-		int i = securityCombo->currentItem();
+		int i = securityCombo->currentIndex();
 		if(i >= 0) {
 			Security *c_sec = budget->securities.first();
 			while(i > 0 && c_sec) {
@@ -813,10 +815,10 @@ Transaction *TransactionEditWidget::createTransaction() {
 	if(!validValues()) return NULL;
 	Transaction *trans;
 	if(transtype == TRANSACTION_TYPE_TRANSFER) {
-		Transfer *transfer = new Transfer(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), fromCombo ? (AssetsAccount*) froms[fromCombo->currentItem()] : NULL, toCombo ? (AssetsAccount*) tos[toCombo->currentItem()] : NULL, descriptionEdit->text(), commentsEdit->text());
+		Transfer *transfer = new Transfer(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), fromCombo ? (AssetsAccount*) froms[fromCombo->currentIndex()] : NULL, toCombo ? (AssetsAccount*) tos[toCombo->currentIndex()] : NULL, descriptionEdit->text(), commentsEdit->text());
 		trans = transfer;
 	} else if(transtype == TRANSACTION_TYPE_INCOME) {
-		Income *income = new Income(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), fromCombo ? (IncomesAccount*) froms[fromCombo->currentItem()] : NULL, toCombo ? (AssetsAccount*) tos[toCombo->currentItem()] : NULL, descriptionEdit ? descriptionEdit->text() : QString::null, commentsEdit->text());
+		Income *income = new Income(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), fromCombo ? (IncomesAccount*) froms[fromCombo->currentIndex()] : NULL, toCombo ? (AssetsAccount*) tos[toCombo->currentIndex()] : NULL, descriptionEdit ? descriptionEdit->text() : QString::null, commentsEdit->text());
 		if(selectedSecurity()) income->setSecurity(selectedSecurity());
 		if(quantityEdit) income->setQuantity(quantityEdit->value());
 		if(payeeEdit) income->setPayer(payeeEdit->text());
@@ -830,7 +832,7 @@ Transaction *TransactionEditWidget::createTransaction() {
 		if(!quotationEdit) share_value = value / shares;
 		else if(!sharesEdit) shares = value / share_value;
 		else if(!valueEdit) value = shares * share_value;
-		SecurityBuy *secbuy = new SecurityBuy(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), fromCombo ? froms[fromCombo->currentItem()] : NULL, commentsEdit->text());
+		SecurityBuy *secbuy = new SecurityBuy(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), fromCombo ? froms[fromCombo->currentIndex()] : NULL, commentsEdit->text());
 		trans = secbuy;
 	} else if(transtype == TRANSACTION_TYPE_SECURITY_SELL) {
 		if(!selectedSecurity()) return NULL;
@@ -841,10 +843,10 @@ Transaction *TransactionEditWidget::createTransaction() {
 		if(!quotationEdit) share_value = value / shares;
 		else if(!sharesEdit) shares = value / share_value;
 		else if(!valueEdit) value = shares * share_value;
-		SecuritySell *secsell = new SecuritySell(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), toCombo ? tos[toCombo->currentItem()] : NULL, commentsEdit->text());
+		SecuritySell *secsell = new SecuritySell(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), toCombo ? tos[toCombo->currentIndex()] : NULL, commentsEdit->text());
 		trans = secsell;
 	} else {
-		Expense *expense = new Expense(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), toCombo ? (ExpensesAccount*) tos[toCombo->currentItem()] : NULL, fromCombo ? (AssetsAccount*) froms[fromCombo->currentItem()] : NULL, descriptionEdit->text(), commentsEdit->text());
+		Expense *expense = new Expense(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), toCombo ? (ExpensesAccount*) tos[toCombo->currentIndex()] : NULL, fromCombo ? (AssetsAccount*) froms[fromCombo->currentIndex()] : NULL, descriptionEdit->text(), commentsEdit->text());
 		if(quantityEdit) expense->setQuantity(quantityEdit->value());
 		if(payeeEdit) expense->setPayee(payeeEdit->text());
 		trans = expense;
@@ -852,13 +854,13 @@ Transaction *TransactionEditWidget::createTransaction() {
 	return trans;
 }
 void TransactionEditWidget::transactionRemoved(Transaction *trans) {
-	if(descriptionEdit && trans->type() == transtype && !trans->description().isEmpty() && default_values.find(trans->description()) == trans) {
+	if(descriptionEdit && trans->type() == transtype && !trans->description().isEmpty() && default_values[trans->description()] == trans) {
 		switch(transtype) {
 			case TRANSACTION_TYPE_EXPENSE: {
 				Expense *expense = budget->expenses.first();
 				while(expense) {
 					if(expense != trans && expense->description() == trans->description()) {
-						default_values.replace(expense->description(), expense);
+						default_values[expense->description()] = expense;
 						break;
 					}
 					expense = budget->expenses.next();
@@ -869,7 +871,7 @@ void TransactionEditWidget::transactionRemoved(Transaction *trans) {
 				Income *income = budget->incomes.first();
 				while(income) {
 					if(income != trans && income->description() == trans->description()) {
-						default_values.replace(income->description(), income);
+						default_values[income->description()] = income;
 						break;
 					}
 					income = budget->incomes.next();
@@ -880,7 +882,7 @@ void TransactionEditWidget::transactionRemoved(Transaction *trans) {
 				Transfer *transfer= budget->transfers.first();
 				while(transfer) {
 					if(transfer != trans && transfer->description() == trans->description()) {
-						default_values.replace(transfer->description(), transfer);
+						default_values[transfer->description()] = transfer;
 						break;
 					}
 					transfer = budget->transfers.next();
@@ -902,7 +904,7 @@ void TransactionEditWidget::transactionsReset() {
 			while(expense) {
 				if(!expense->description().isEmpty()) {
 					descriptionEdit->completionObject()->addItem(expense->description());
-					default_values.replace(expense->description(), expense);
+					default_values[expense->description()] = expense;
 				}
 				if(payeeEdit && !expense->payee().isEmpty()) {
 					payeeEdit->completionObject()->addItem(expense->payee());
@@ -916,7 +918,7 @@ void TransactionEditWidget::transactionsReset() {
 			while(income) {
 				if(!income->security() && !income->description().isEmpty()) {
 					descriptionEdit->completionObject()->addItem(income->description());
-					default_values.replace(income->description(), income);
+					default_values[income->description()] = income;
 				}
 				if(payeeEdit && !income->security() && !income->payer().isEmpty()) {
 					payeeEdit->completionObject()->addItem(income->payer());
@@ -930,7 +932,7 @@ void TransactionEditWidget::transactionsReset() {
 			while(transfer) {
 				if(!transfer->description().isEmpty()) {
 					descriptionEdit->completionObject()->addItem(transfer->description());
-					default_values.replace(transfer->description(), transfer);
+					default_values[transfer->description()] = transfer;
 				}
 				transfer = budget->transfers.next();
 			}
@@ -940,23 +942,23 @@ void TransactionEditWidget::transactionsReset() {
 	}
 }
 void TransactionEditWidget::setCurrentToItem(int index) {
-	if(toCombo) toCombo->setCurrentItem(index);
+	if(toCombo) toCombo->setCurrentIndex(index);
 }
 void TransactionEditWidget::setCurrentFromItem(int index) {
-	if(fromCombo) fromCombo->setCurrentItem(index);
+	if(fromCombo) fromCombo->setCurrentIndex(index);
 }
 void TransactionEditWidget::setAccount(Account *account) {
 	if(fromCombo && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_TRANSFER || transtype == TRANSACTION_TYPE_SECURITY_BUY)) {
-		for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+		for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 			if(account == froms[i]) {
-				fromCombo->setCurrentItem(i);
+				fromCombo->setCurrentIndex(i);
 				break;
 			}
 		}
 	} else if(toCombo) {
-		for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+		for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 			if(account == tos[i]) {
-				toCombo->setCurrentItem(i);
+				toCombo->setCurrentIndex(i);
 				break;
 			}
 		}
@@ -964,11 +966,11 @@ void TransactionEditWidget::setAccount(Account *account) {
 }
 int TransactionEditWidget::currentToItem() {
 	if(!toCombo) return -1;
-	return toCombo->currentItem();
+	return toCombo->currentIndex();
 }
 int TransactionEditWidget::currentFromItem() {
 	if(!fromCombo) return -1;
-	return fromCombo->currentItem();
+	return fromCombo->currentIndex();
 }
 void TransactionEditWidget::setTransaction(Transaction *trans) {
 	if(valueEdit) valueEdit->blockSignals(true);
@@ -977,6 +979,7 @@ void TransactionEditWidget::setTransaction(Transaction *trans) {
 	if(trans == NULL) {
 		value_set = false; shares_set = false; sharevalue_set = false;
 		description_changed = false;
+		if(dateEdit) dateEdit->setDate(QDate::currentDate());
 		if(b_sec) {
 			if(sharesEdit) sharesEdit->setValue(0.0);
 			if(quotationEdit) quotationEdit->setValue(0.0);
@@ -995,22 +998,23 @@ void TransactionEditWidget::setTransaction(Transaction *trans) {
 		commentsEdit->clear();
 		if(quantityEdit) quantityEdit->setValue(1.0);
 		if(payeeEdit) payeeEdit->clear();
+		if(dateEdit) emit dateChanged(trans->date());
 	} else {
 		value_set = true; shares_set = true; sharevalue_set = true;
 		if(dateEdit) dateEdit->setDate(trans->date());
 		commentsEdit->setText(trans->comment());
 		if(toCombo && (!b_sec || transtype == TRANSACTION_TYPE_SECURITY_SELL)) {
-			for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 				if(trans->toAccount() == tos[i]) {
-					toCombo->setCurrentItem(i);
+					toCombo->setCurrentIndex(i);
 					break;
 				}
 			}
 		}
 		if(fromCombo && (!b_sec || transtype == TRANSACTION_TYPE_SECURITY_BUY)) {
-			for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 				if(trans->fromAccount() == froms[i]) {
-					fromCombo->setCurrentItem(i);
+					fromCombo->setCurrentIndex(i);
 					break;
 				}
 			}
@@ -1052,7 +1056,10 @@ void TransactionEditWidget::setScheduledTransaction(ScheduledTransaction *strans
 	}
 }
 
-TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent) : KDialogBase(parent, 0, true, QString::null, KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true){
+TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent) : KDialog(parent, 0){
+	setButtons(KDialog::Ok | KDialog::Cancel);
+	setDefaultButton(KDialog::Cancel);
+	setModal(true);
 	switch(transaction_type) {
 		case TRANSACTION_TYPE_EXPENSE: {setPlainCaption(i18n("Edit Expense")); break;}
 		case TRANSACTION_TYPE_INCOME: {
@@ -1068,13 +1075,18 @@ TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transact
 	editWidget->transactionsReset();
 	setMainWidget(editWidget);
 }
-void TransactionEditDialog::slotOk() {
-	if(editWidget->validValues(true)) {
-		KDialogBase::slotOk();
+void TransactionEditDialog::slotButtonClicked(int button) {
+	if(button != KDialog::Ok || editWidget->validValues(true)) {
+		KDialog::slotButtonClicked(button);
 	}
 }
 
-MultipleTransactionsEditDialog::MultipleTransactionsEditDialog(bool extra_parameters, int transaction_type, Budget *budg, QWidget *parent, const char *name)  : KDialogBase(parent, name, true, i18n("Modify Transactions"), Ok | Cancel, Ok, true), transtype(transaction_type), budget(budg), b_extra(extra_parameters) {
+MultipleTransactionsEditDialog::MultipleTransactionsEditDialog(bool extra_parameters, int transaction_type, Budget *budg, QWidget *parent)  : KDialog(parent), transtype(transaction_type), budget(budg), b_extra(extra_parameters) {
+	
+	setCaption(i18n("Modify Transactions"));	
+	setButtons(KDialog::Ok | KDialog::Cancel);
+	setDefaultButton(KDialog::Cancel);
+	setModal(true);
 	
 	setMainWidget(new QWidget(this));
 
@@ -1082,7 +1094,7 @@ MultipleTransactionsEditDialog::MultipleTransactionsEditDialog(bool extra_parame
 	if(b_extra && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) rows= 5;
 	else if(transtype == TRANSACTION_TYPE_TRANSFER) rows = 3;
 	else rows = 2;
-	QGridLayout *editLayout = new QGridLayout(mainWidget(), rows, 2, 0, spacingHint());
+	QGridLayout *editLayout = new QGridLayout(mainWidget());
 
 	descriptionButton = new QCheckBox(i18n("Description:"), mainWidget());
 	descriptionButton->setChecked(false);
@@ -1108,6 +1120,7 @@ MultipleTransactionsEditDialog::MultipleTransactionsEditDialog(bool extra_parame
 	dateButton->setChecked(false);
 	editLayout->addWidget(dateButton, 2, 0);
 	dateEdit = new KDateEdit(mainWidget());
+	dateEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	dateEdit->setEnabled(false);
 	editLayout->addWidget(dateEdit, 2, 1);
 
@@ -1150,17 +1163,17 @@ void MultipleTransactionsEditDialog::setTransaction(Transaction *trans) {
 		dateEdit->setDate(trans->date());
 		if(valueEdit) valueEdit->setValue(trans->value());
 		if(transtype == TRANSACTION_TYPE_EXPENSE) {
-			for(QValueVector<Account*>::size_type i = 0; i < categories.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < categories.size(); i++) {
 				if(((Expense*) trans)->category() == categories[i]) {
-					categoryCombo->setCurrentItem(i);
+					categoryCombo->setCurrentIndex(i);
 					break;
 				}
 			}
 			if(payeeEdit) payeeEdit->setText(((Expense*) trans)->payee());
 		} else if(transtype == TRANSACTION_TYPE_INCOME) {
-			for(QValueVector<Account*>::size_type i = 0; i < categories.size(); i++) {
+			for(QVector<Account*>::size_type i = 0; i < categories.size(); i++) {
 				if(((Income*) trans)->category() == categories[i]) {
-					categoryCombo->setCurrentItem(i);
+					categoryCombo->setCurrentIndex(i);
 					break;
 				}
 			}
@@ -1186,7 +1199,7 @@ void MultipleTransactionsEditDialog::updateAccounts() {
 		case TRANSACTION_TYPE_INCOME: {
 			Account *account = budget->incomesAccounts.first();
 			while(account) {
-				categoryCombo->insertItem(account->name());
+				categoryCombo->addItem(account->name());
 				categories.push_back(account);
 				account = budget->incomesAccounts.next();
 			}
@@ -1195,7 +1208,7 @@ void MultipleTransactionsEditDialog::updateAccounts() {
 		case TRANSACTION_TYPE_EXPENSE: {
 			Account *account = budget->expensesAccounts.first();
 			while(account) {
-				categoryCombo->insertItem(account->name());
+				categoryCombo->addItem(account->name());
 				categories.push_back(account);
 				account = budget->expensesAccounts.next();
 			}
@@ -1209,27 +1222,27 @@ bool MultipleTransactionsEditDialog::modifyTransaction(Transaction *trans) {
 	bool b_descr = true, b_value = true;
 	switch(trans->type()) {
 		case TRANSACTION_TYPE_EXPENSE: {
-			if(transtype == trans->type() && categoryButton->isChecked()) ((Expense*) trans)->setCategory((ExpensesAccount*) categories[categoryCombo->currentItem()]);
+			if(transtype == trans->type() && categoryButton->isChecked()) ((Expense*) trans)->setCategory((ExpensesAccount*) categories[categoryCombo->currentIndex()]);
 			if(payeeEdit && payeeButton->isChecked()) ((Expense*) trans)->setPayee(payeeEdit->text());
 			break;
 		}
 		case TRANSACTION_TYPE_INCOME: {
 			if(((Income*) trans)->security()) b_descr = false;
 			else if(payeeEdit && payeeButton->isChecked()) ((Income*) trans)->setPayer(payeeEdit->text());
-			if(transtype == trans->type() && categoryButton->isChecked()) ((Income*) trans)->setCategory((IncomesAccount*) categories[categoryCombo->currentItem()]);
+			if(transtype == trans->type() && categoryButton->isChecked()) ((Income*) trans)->setCategory((IncomesAccount*) categories[categoryCombo->currentIndex()]);
 			break;
 		}
 		case TRANSACTION_TYPE_TRANSFER: {
 			break;
 		}
 		case TRANSACTION_TYPE_SECURITY_BUY: {
-			if(transtype == TRANSACTION_TYPE_INCOME && categoryButton->isChecked()) ((SecurityTransaction*) trans)->setAccount(categories[categoryCombo->currentItem()]);
+			if(transtype == TRANSACTION_TYPE_INCOME && categoryButton->isChecked()) ((SecurityTransaction*) trans)->setAccount(categories[categoryCombo->currentIndex()]);
 			b_descr = false;
 			b_value = false;
 			break;
 		}
 		case TRANSACTION_TYPE_SECURITY_SELL: {
-			if(transtype == TRANSACTION_TYPE_INCOME && categoryButton->isChecked()) ((SecurityTransaction*) trans)->setAccount(categories[categoryCombo->currentItem()]);
+			if(transtype == TRANSACTION_TYPE_INCOME && categoryButton->isChecked()) ((SecurityTransaction*) trans)->setAccount(categories[categoryCombo->currentIndex()]);
 			b_descr = false;
 			b_value = false;
 			break;
@@ -1273,11 +1286,15 @@ bool MultipleTransactionsEditDialog::validValues() {
 	if(!checkAccounts()) return false;
 	return true;
 }
-void MultipleTransactionsEditDialog::slotOk() {
-	if(!descriptionButton->isChecked() && (!valueButton || !valueButton->isChecked()) && !dateButton->isChecked() && (!categoryButton || !categoryButton->isChecked()) && (!payeeButton || !payeeButton->isChecked())) {
-		KDialogBase::slotCancel();
-	} else if(validValues()) {
-		KDialogBase::slotOk();
+void MultipleTransactionsEditDialog::slotButtonClicked(int button) {
+	if(button == KDialog::Ok) {
+		if(!descriptionButton->isChecked() && (!valueButton || !valueButton->isChecked()) && !dateButton->isChecked() && (!categoryButton || !categoryButton->isChecked()) && (!payeeButton || !payeeButton->isChecked())) {
+			KDialog::slotButtonClicked(KDialog::Cancel);
+		} else if(validValues()) {
+			KDialog::slotButtonClicked(KDialog::Ok);
+		}
+	} else {
+		KDialog::slotButtonClicked(button);
 	}
 }
 QDate MultipleTransactionsEditDialog::date() {
