@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
- *   nq@altern.org                                                         *
+ *   Copyright (C) 2008 by Hanna K.                                        *
+ *   hanna_k@fmgirl.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,53 +33,54 @@
 #include <kiconloader.h>
 #include <kdeversion.h>
 #include <kstatusbar.h>
-#include <kaccel.h>
 #include <kio/netaccess.h>
 #include <kfiledialog.h>
 #include <kconfig.h>
 #include <kurl.h>
-#include <kurldrag.h>
-#include <qheader.h>
+#include <QHBoxLayout>
+#include <QGridLayout>
 #include <kmessagebox.h>
 #include <qlayout.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include "kdateedit.h"
 #include <qlabel.h>
-#include <kbuttonbox.h>
+#include <KDialogButtonBox>
 #include <kstdguiitem.h>
 #include <kstdaccel.h>
 #include <kaction.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <qobject.h>
 #include <qpushbutton.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <qlabel.h>
 #include <kseparator.h>
 #include <qcheckbox.h>
-#include <kjanuswidget.h>
+#include <kpagewidget.h>
 #include <qradiobutton.h>
-#include <qgroupbox.h>
 #include <kpushbutton.h>
 #include <ktextedit.h>
-#include <qbuttongroup.h>
+#include <QButtonGroup>
 
 extern double monthsBetweenDates(const QDate &date1, const QDate &date2);
 extern double yearsBetweenDates(const QDate &date1, const QDate &date2);
 
-TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int transaction_type, Budget *budg, QWidget *parent, const char *name) : QWidget(parent, name), transtype(transaction_type), budget(budg), b_extra(extra_parameters) {
+TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int transaction_type, Budget *budg, QWidget *parent) : QWidget(parent), transtype(transaction_type), budget(budg), b_extra(extra_parameters) {
 	payeeEdit = NULL;
 	int rows = 5;
 	if(b_extra && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) rows = 6;
-	QGridLayout *filterLayout = new QGridLayout(this, rows, 4, 0, 6);
+	QGridLayout *filterLayout = new QGridLayout(this);
+	filterLayout->setContentsMargins(0, 0, 0, 0);
 	dateFromButton = new QCheckBox(i18n("From:"), this);
 	dateFromButton->setChecked(false);
 	filterLayout->addWidget(dateFromButton, 0, 0);
 	dateFromEdit = new KDateEdit(this);
+	dateFromEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	dateFromEdit->setEnabled(false);
 	filterLayout->addWidget(dateFromEdit, 0, 1);
 	filterLayout->addWidget(new QLabel(i18n("To:"), this), 0, 2);
 	dateToEdit = new KDateEdit(this);
+	dateToEdit->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
 	filterLayout->addWidget(dateToEdit, 0, 3);
 	QDate curdate = QDate::currentDate();
 	from_date.setYMD(curdate.year(), curdate.month(), 1);
@@ -128,7 +129,7 @@ TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int tran
 	maxEdit = new EqonomizeValueEdit(false, this);
 	maxEdit->setEnabled(false);
 	QSizePolicy sp = maxEdit->sizePolicy();
-	sp.setHorData(QSizePolicy::Expanding);
+	sp.setHorizontalPolicy(QSizePolicy::Expanding);
 	maxEdit->setSizePolicy(sp);
 	filterLayout->addWidget(maxEdit, 1, 3);
 	filterLayout->addWidget(new QLabel(i18n("Description:"), this), 3, 0);
@@ -142,29 +143,29 @@ TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int tran
 		payeeEdit->setCompletionMode(KGlobalSettings::CompletionPopup);
 		filterLayout->addWidget(payeeEdit, 3, 3);
 	}
-	QHBoxLayout *filterExcludeLayout = new QHBoxLayout(NULL, 0, 6);
-	group = new QButtonGroup();
+	QHBoxLayout *filterExcludeLayout = new QHBoxLayout();
+	group = new QButtonGroup(this);
 	includeButton = new QRadioButton(i18n("Include"), this);
 	includeButton->setChecked(true);
-	group->insert(includeButton);
+	group->addButton(includeButton);
 	filterExcludeLayout->addWidget(includeButton);
 	excludeButton = new QRadioButton(i18n("Exclude"), this);
-	group->insert(excludeButton);
+	group->addButton(excludeButton);
 	filterExcludeLayout->addWidget(excludeButton);
 	filterExcludeLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum));
-	clearButton = new KPushButton(KStdGuiItem::clear(), this);
+	clearButton = new KPushButton(KStandardGuiItem::clear(), this);
 	clearButton->setEnabled(false);
 	filterExcludeLayout->addWidget(clearButton);
 	if(payeeEdit) {
-		filterLayout->addMultiCellLayout(filterExcludeLayout, 4, 4, 0, 3);
-		filterLayout->addMultiCell(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 5, 5, 0, 3);
+		filterLayout->addLayout(filterExcludeLayout, 4, 0, 1, 4);
+		filterLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 5, 0, 1, 4);
 	} else {
-		filterLayout->addMultiCellLayout(filterExcludeLayout, 3, 3, 2, 3);
-		filterLayout->addMultiCell(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 4, 0, 3);
+		filterLayout->addLayout(filterExcludeLayout, 3, 2, 1, 2);
+		filterLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 0, 1, 4);
 	}
 
-	fromCombo->insertItem(i18n("All"));
-	toCombo->insertItem(i18n("All"));
+	fromCombo->addItem(i18n("All"));
+	toCombo->addItem(i18n("All"));
 
 	descriptionEdit->completionObject()->setIgnoreCase(true);
 	if(payeeEdit) payeeEdit->completionObject()->setIgnoreCase(true);
@@ -174,7 +175,7 @@ TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int tran
 		connect(payeeEdit, SIGNAL(textChanged(const QString&)), this, SLOT(checkEnableClear()));
 	}
 	connect(clearButton, SIGNAL(clicked()), this, SLOT(clearFilter()));
-	connect(group, SIGNAL(clicked(int)), this, SIGNAL(filter()));
+	connect(group, SIGNAL(buttonClicked(int)), this, SIGNAL(filter()));
 	connect(dateFromButton, SIGNAL(toggled(bool)), dateFromEdit, SLOT(setEnabled(bool)));
 	connect(dateFromButton, SIGNAL(toggled(bool)), this, SIGNAL(filter()));
 	connect(dateFromButton, SIGNAL(toggled(bool)), this, SLOT(checkEnableClear()));
@@ -230,8 +231,8 @@ void TransactionFilterWidget::clearFilter() {
 	minEdit->setEnabled(false);
 	maxButton->setChecked(false);
 	maxEdit->setEnabled(false);
-	fromCombo->setCurrentItem(0);
-	toCombo->setCurrentItem(0);
+	fromCombo->setCurrentIndex(0);
+	toCombo->setCurrentIndex(0);
 	descriptionEdit->setText(QString::null);
 	if(payeeEdit) payeeEdit->setText(QString::null);
 	dateFromButton->blockSignals(false);
@@ -246,7 +247,7 @@ void TransactionFilterWidget::clearFilter() {
 	emit filter();
 }
 void TransactionFilterWidget::checkEnableClear() {
-	clearButton->setEnabled(dateFromButton->isChecked() || minButton->isChecked() || maxButton->isChecked() || fromCombo->currentItem() || toCombo->currentItem() || !descriptionEdit->text().isEmpty() || (payeeEdit && !payeeEdit->text().isEmpty()) || to_date != QDate::currentDate());
+	clearButton->setEnabled(dateFromButton->isChecked() || minButton->isChecked() || maxButton->isChecked() || fromCombo->currentIndex() || toCombo->currentIndex() || !descriptionEdit->text().isEmpty() || (payeeEdit && !payeeEdit->text().isEmpty()) || to_date != QDate::currentDate());
 }
 void TransactionFilterWidget::setFilter(QDate fromdate, QDate todate, double min, double max, Account *from_account, Account *to_account, QString description, QString payee, bool exclude) {
 	dateFromButton->blockSignals(true);
@@ -294,27 +295,27 @@ void TransactionFilterWidget::setFilter(QDate fromdate, QDate todate, double min
 		maxEdit->setValue(max);
 	}
 	if(from_account) {
-		for(QValueVector<Account*>::size_type i = 0; i < froms.size(); i++) {
+		for(QVector<Account*>::size_type i = 0; i < froms.size(); i++) {
 			if(froms[i] == from_account) {
-				fromCombo->setCurrentItem(i + 1);
+				fromCombo->setCurrentIndex(i + 1);
 				emit fromActivated(i + 1);
 				break;
 			}
 		}
 	} else {
-		fromCombo->setCurrentItem(0);
+		fromCombo->setCurrentIndex(0);
 		emit fromActivated(0);
 	}
 	if(to_account) {
-		for(QValueVector<Account*>::size_type i = 0; i < tos.size(); i++) {
+		for(QVector<Account*>::size_type i = 0; i < tos.size(); i++) {
 			if(tos[i] == to_account) {
-				toCombo->setCurrentItem(i + 1);
+				toCombo->setCurrentIndex(i + 1);
 				emit toActivated(i + 1);
 				break;
 			}
 		}
 	} else {
-		toCombo->setCurrentItem(0);
+		toCombo->setCurrentIndex(0);
 		emit toActivated(0);
 	}
 	descriptionEdit->setText(description);
@@ -339,13 +340,13 @@ void TransactionFilterWidget::setFilter(QDate fromdate, QDate todate, double min
 void TransactionFilterWidget::updateFromAccounts() {
 	fromCombo->clear();
 	froms.clear();
-	fromCombo->insertItem(i18n("All"));
+	fromCombo->addItem(i18n("All"));
 	Account *account;
 	switch(transtype) {
 		case TRANSACTION_TYPE_TRANSFER: {
 			account = budget->assetsAccounts.first();
 			while(account) {
-				fromCombo->insertItem(account->name());
+				fromCombo->addItem(account->name());
 				froms.push_back(account);
 				account = budget->assetsAccounts.next();
 			}
@@ -355,7 +356,7 @@ void TransactionFilterWidget::updateFromAccounts() {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != budget->balancingAccount && ((AssetsAccount*) account)->accountType() != ASSETS_TYPE_SECURITIES) {
-					fromCombo->insertItem(account->name());
+					fromCombo->addItem(account->name());
 					froms.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
@@ -365,7 +366,7 @@ void TransactionFilterWidget::updateFromAccounts() {
 		case TRANSACTION_TYPE_INCOME: {
 			account = budget->incomesAccounts.first();
 			while(account) {
-				fromCombo->insertItem(account->name());
+				fromCombo->addItem(account->name());
 				froms.push_back(account);
 				account = budget->incomesAccounts.next();
 			}
@@ -376,13 +377,13 @@ void TransactionFilterWidget::updateFromAccounts() {
 void TransactionFilterWidget::updateToAccounts() {
 	toCombo->clear();
 	tos.clear();
-	toCombo->insertItem(i18n("All"));
+	toCombo->addItem(i18n("All"));
 	Account *account;
 	switch(transtype) {
 		case TRANSACTION_TYPE_TRANSFER: {
 			account = budget->assetsAccounts.first();
 			while(account) {
-				toCombo->insertItem(account->name());
+				toCombo->addItem(account->name());
 				tos.push_back(account);
 				account = budget->assetsAccounts.next();
 			}
@@ -392,7 +393,7 @@ void TransactionFilterWidget::updateToAccounts() {
 			account = budget->assetsAccounts.first();
 			while(account) {
 				if(account != budget->balancingAccount) {
-					toCombo->insertItem(account->name());
+					toCombo->addItem(account->name());
 					tos.push_back(account);
 				}
 				account = budget->assetsAccounts.next();
@@ -402,7 +403,7 @@ void TransactionFilterWidget::updateToAccounts() {
 		case TRANSACTION_TYPE_EXPENSE: {
 			account = budget->expensesAccounts.first();
 			while(account) {
-				toCombo->insertItem(account->name());
+				toCombo->addItem(account->name());
 				tos.push_back(account);
 				account = budget->expensesAccounts.next();
 			}
@@ -423,28 +424,28 @@ bool TransactionFilterWidget::filterTransaction(Transaction *trans, bool checkda
 		return true;
 	}
 	if(includeButton->isChecked()) {
-		if(toCombo->currentItem() > 0 && tos[toCombo->currentItem() - 1] != trans->toAccount()) {
+		if(toCombo->currentIndex() > 0 && tos[toCombo->currentIndex() - 1] != trans->toAccount()) {
 			return true;
 		}
-		if(fromCombo->currentItem() > 0 && froms[fromCombo->currentItem() - 1] != trans->fromAccount()) {
+		if(fromCombo->currentIndex() > 0 && froms[fromCombo->currentIndex() - 1] != trans->fromAccount()) {
 			return true;
 		}
 #if QT_VERSION >= 0x030200		
-		if(!descriptionEdit->text().isEmpty() && !trans->description().startsWith(descriptionEdit->text(), false)) {
+		if(!descriptionEdit->text().isEmpty() && !trans->description().startsWith(descriptionEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(!descriptionEdit->text().isEmpty() && !trans->description().startsWith(descriptionEdit->text())) {
 #endif
 			return true;
 		}
 #if QT_VERSION >= 0x030200
-		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE && !payeeEdit->text().isEmpty() && !((Expense*) trans)->payee().startsWith(payeeEdit->text(), false)) {
+		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE && !payeeEdit->text().isEmpty() && !((Expense*) trans)->payee().startsWith(payeeEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE && !payeeEdit->text().isEmpty() && !((Expense*) trans)->payee().startsWith(payeeEdit->text())) {
 #endif
 			return true;
 		}
 #if QT_VERSION >= 0x030200
-		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME && !payeeEdit->text().isEmpty() && !((Income*) trans)->payer().startsWith(payeeEdit->text(), false)) {
+		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME && !payeeEdit->text().isEmpty() && !((Income*) trans)->payer().startsWith(payeeEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME && !payeeEdit->text().isEmpty() && !((Income*) trans)->payer().startsWith(payeeEdit->text())) {
 #endif
@@ -452,28 +453,28 @@ bool TransactionFilterWidget::filterTransaction(Transaction *trans, bool checkda
 		}
 		
 	} else {
-		if(toCombo->currentItem() > 0 && tos[toCombo->currentItem() - 1] == trans->toAccount()) {
+		if(toCombo->currentIndex() > 0 && tos[toCombo->currentIndex() - 1] == trans->toAccount()) {
 			return true;
 		}
-		if(fromCombo->currentItem() > 0 && froms[fromCombo->currentItem() - 1] == trans->fromAccount()) {
+		if(fromCombo->currentIndex() > 0 && froms[fromCombo->currentIndex() - 1] == trans->fromAccount()) {
 			return true;
 		}
 #if QT_VERSION >= 0x030200
-		if(!descriptionEdit->text().isEmpty() && trans->description().startsWith(descriptionEdit->text(), false)) {
+		if(!descriptionEdit->text().isEmpty() && trans->description().startsWith(descriptionEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(!descriptionEdit->text().isEmpty() && trans->description().startsWith(descriptionEdit->text())) {
 #endif
 			return true;
 		}
 #if QT_VERSION >= 0x030200
-		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE  && !payeeEdit->text().isEmpty() && ((Expense*) trans)->payee().startsWith(payeeEdit->text(), false)) {
+		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE  && !payeeEdit->text().isEmpty() && ((Expense*) trans)->payee().startsWith(payeeEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(payeeEdit && transtype == TRANSACTION_TYPE_EXPENSE  && !payeeEdit->text().isEmpty() && ((Expense*) trans)->payee().startsWith(payeeEdit->text())) {
 #endif
 			return true;
 		}
 #if QT_VERSION >= 0x030200
-		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME  && !payeeEdit->text().isEmpty() && ((Income*) trans)->payer().startsWith(payeeEdit->text(), false)) {
+		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME  && !payeeEdit->text().isEmpty() && ((Income*) trans)->payer().startsWith(payeeEdit->text(), Qt::CaseInsensitive)) {
 #else
 		if(payeeEdit && transtype == TRANSACTION_TYPE_INCOME  && !payeeEdit->text().isEmpty() && ((Income*) trans)->payer().startsWith(payeeEdit->text())) {
 #endif
